@@ -1,13 +1,17 @@
 #include "antennaselector.h"
 
-#include "../../quality/statisticscollection.h"
-#include "../../quality/statisticsderivator.h"
+#include <utility>
 
-namespace rfiStrategy {
+#include "../quality/statisticscollection.h"
+#include "../quality/statisticsderivator.h"
+
+using std::size_t;
+
+namespace algorithms {
 
 std::vector<size_t> AntennaSelector::Run(
     const StatisticsCollection& statisticsCollection) {
-  std::map<size_t, DefaultStatistics> antStatistics =
+  const std::map<size_t, DefaultStatistics> antStatistics =
       statisticsCollection.GetAntennaStatistics();
 
   std::vector<double> stddevs;
@@ -15,8 +19,9 @@ std::vector<size_t> AntennaSelector::Run(
   for (size_t p = 0; p != 4; ++p) {
     double meanStddev = 0.0;
     stddevs.clear();
-    for (const std::pair<size_t, DefaultStatistics>& antenna : antStatistics) {
-      double stddev = StatisticsDerivator::GetStatisticAmplitude(
+    for (const std::pair<const size_t, DefaultStatistics>& antenna :
+         antStatistics) {
+      const double stddev = StatisticsDerivator::GetStatisticAmplitude(
           QualityTablesFormatter::StandardDeviationStatistic, antenna.second,
           p);
       stddevs.emplace_back(stddev);
@@ -24,14 +29,15 @@ std::vector<size_t> AntennaSelector::Run(
     }
     double stddevOfStddev = 0.0;
     meanStddev /= stddevs.size();
-    for (double& s : stddevs) {
+    for (const double& s : stddevs) {
       stddevOfStddev += (s - meanStddev) * (s - meanStddev);
     }
     stddevOfStddev = sqrt(stddevOfStddev / stddevs.size());
 
     size_t index = 0;
-    double limit = _threshold * stddevOfStddev;
-    for (const std::pair<size_t, DefaultStatistics>& antenna : antStatistics) {
+    const double limit = _threshold * stddevOfStddev;
+    for (const std::pair<const size_t, DefaultStatistics>& antenna :
+         antStatistics) {
       if (std::fabs(stddevs[index] - meanStddev) > limit ||
           stddevs[index] == 0.0) {
         if (antenna.second.count[p] != 0) badAntennas.insert(antenna.first);
@@ -42,4 +48,4 @@ std::vector<size_t> AntennaSelector::Run(
   return std::vector<size_t>(badAntennas.begin(), badAntennas.end());
 }
 
-}  // namespace rfiStrategy
+}  // namespace algorithms
