@@ -1,11 +1,14 @@
 #ifndef APPLY_BANDPASS_H
 #define APPLY_BANDPASS_H
 
-#include "../../structures/timefrequencydata.h"
+#include "../structures/timefrequencydata.h"
 
 #include "bandpassfile.h"
 
 #include <string>
+#include <utility>
+
+namespace algorithms {
 
 class ApplyBandpass {
  public:
@@ -83,4 +86,6 @@ class ApplyBandpass {
   }
 };
 
+}  // namespace algorithms
+
 #endif
