@@ -4,8 +4,10 @@
 #include <cstddef>
 #include <cstring>
 
-#include "../../structures/image2d.h"
-#include "../../structures/mask2d.h"
+#include "../structures/image2d.h"
+#include "../structures/mask2d.h"
+
+namespace algorithms {
 
 class CombinatorialThresholder {
  public:
@@ -22,4 +24,6 @@ class CombinatorialThresholder {
   CombinatorialThresholder() = delete;
 };
 
+}  // namespace algorithms
+
 #endif
