@@ -1,11 +1,13 @@
 #include "fringetestcreater.h"
 
-#include "../../structures/timefrequencydata.h"
-#include "../../structures/timefrequencymetadata.h"
+#include "../structures/timefrequencydata.h"
+#include "../structures/timefrequencymetadata.h"
 
-#include "../../imaging/uvimager.h"
+#include "../imaging/uvimager.h"
 
-void FringeTestCreater::AddStaticFringe(class TimeFrequencyData &ftData,
+namespace algorithms {
+
+void FringeTestCreater::AddStaticFringe(class TimeFrequencyData& ftData,
                                         TimeFrequencyMetaDataCPtr metaData,
                                         long double strength) {
   Image2DCPtr real = ftData.GetRealPart(),
@@ -18,7 +20,7 @@ void FringeTestCreater::AddStaticFringe(class TimeFrequencyData &ftData,
   for (size_t channelIndex = 0; channelIndex < ftData.ImageHeight();
        ++channelIndex) {
     for (size_t t = 0; t < ftData.ImageWidth(); ++t) {
-      num_t fringeRotation =
+      const num_t fringeRotation =
           2.0 * M_PIn * UVImager::GetFringeCount(0, t, channelIndex, metaData);
 
       newReal->SetValue(
@@ -32,3 +34,5 @@ void FringeTestCreater::AddStaticFringe(class TimeFrequencyData &ftData,
 
   ftData.Set(ftData.Polarizations()[0], newReal, newImaginary);
 }
+
+}  // namespace algorithms
