@@ -1,11 +1,13 @@
 #ifndef FRINGETESTCREATER_H
 #define FRINGETESTCREATER_H
 
-#include "../../structures/timefrequencymetadata.h"
+#include "../structures/timefrequencymetadata.h"
+
+namespace algorithms {
 
 class FringeTestCreater {
  public:
-  static void AddStaticFringe(class TimeFrequencyData &ftData,
+  static void AddStaticFringe(class TimeFrequencyData& ftData,
                               TimeFrequencyMetaDataCPtr metaData,
                               long double strength);
 
@@ -14,4 +16,6 @@ class FringeTestCreater {
   ~FringeTestCreater() {}
 };
 
+}  // namespace algorithms
+
 #endif
