@@ -1,13 +1,15 @@
 #ifndef HIGHPASS_FILTER_H
 #define HIGHPASS_FILTER_H
 
-#include "../../structures/image2d.h"
-#include "../../structures/mask2d.h"
+#include "../structures/image2d.h"
+#include "../structures/mask2d.h"
 
 #ifdef __SSE__
 #define USE_INTRINSICS
 #endif
 
+namespace algorithms {
+
 /**
  * This class is able to perform a Gaussian high pass filter on an
  * Image2D .
@@ -18,10 +20,10 @@ class HighPassFilter {
    * Construct a new high pass filter with default parameters
    */
   HighPassFilter()
-      : _hKernel(0),
+      : _hKernel(nullptr),
         _hWindowSize(22),
         _hKernelSigmaSq(7.5),
-        _vKernel(0),
+        _vKernel(nullptr),
         _vWindowSize(45),
         _vKernelSigmaSq(15.0) {}
 
@@ -41,13 +43,13 @@ class HighPassFilter {
    * Apply a Gaussian high-pass filter on the given image, ignoring
    * flagged samples.
    */
-  Image2DPtr ApplyHighPass(const Image2DCPtr &image, const Mask2DCPtr &mask);
+  Image2DPtr ApplyHighPass(const Image2DCPtr& image, const Mask2DCPtr& mask);
 
   /**
    * Apply a Gaussian low-pass filter on the given image, ignoring
    * flagged samples.
    */
-  Image2DPtr ApplyLowPass(const Image2DCPtr &image, const Mask2DCPtr &mask);
+  Image2DPtr ApplyLowPass(const Image2DCPtr& image, const Mask2DCPtr& mask);
 
   /**
    * Set the horizontal size of the sliding window in samples. Must be odd: if
@@ -55,7 +57,7 @@ class HighPassFilter {
    */
   void SetHWindowSize(const unsigned hWindowSize) {
     delete[] _hKernel;
-    _hKernel = 0;
+    _hKernel = nullptr;
     if ((hWindowSize % 2) == 0)
       _hWindowSize = hWindowSize + 1;
     else
@@ -74,7 +76,7 @@ class HighPassFilter {
    */
   void SetVWindowSize(const unsigned vWindowSize) {
     delete[] _vKernel;
-    _vKernel = 0;
+    _vKernel = nullptr;
     if ((vWindowSize % 2) == 0)
       _vWindowSize = vWindowSize + 1;
     else
@@ -102,7 +104,7 @@ class HighPassFilter {
    */
   void SetHKernelSigmaSq(double newSigmaSquared) {
     delete[] _hKernel;
-    _hKernel = 0;
+    _hKernel = nullptr;
     _hKernelSigmaSq = newSigmaSquared;
   }
 
@@ -121,7 +123,7 @@ class HighPassFilter {
    */
   void SetVKernelSigmaSq(double newSigmaSquared) {
     delete[] _vKernel;
-    _vKernel = 0;
+    _vKernel = nullptr;
     _vKernelSigmaSq = newSigmaSquared;
   }
 
@@ -130,22 +132,22 @@ class HighPassFilter {
    * Applies the low-pass convolution. Kernel has to be initialized
    * before calling.
    */
-  void applyLowPass(const Image2DPtr &image) {
+  void applyLowPass(const Image2DPtr& image) {
 #ifdef USE_INTRINSICS
     applyLowPassSSE(image);
 #else
     applyLowPassSimple(image);
 #endif
   }
-  void applyLowPassSimple(const Image2DPtr &image);
-  void applyLowPassSSE(const Image2DPtr &image);
+  void applyLowPassSimple(const Image2DPtr& image);
+  void applyLowPassSSE(const Image2DPtr& image);
 
   void initializeKernel();
 
-  void setFlaggedValuesToZeroAndMakeWeights(const Image2DCPtr &inputImage,
-                                            const Image2DPtr &outputImage,
-                                            const Mask2DCPtr &inputMask,
-                                            const Image2DPtr &weightsOutput) {
+  void setFlaggedValuesToZeroAndMakeWeights(const Image2DCPtr& inputImage,
+                                            const Image2DPtr& outputImage,
+                                            const Mask2DCPtr& inputMask,
+                                            const Image2DPtr& weightsOutput) {
 #ifdef USE_INTRINSICS
     setFlaggedValuesToZeroAndMakeWeightsSSE(inputImage, outputImage, inputMask,
                                             weightsOutput);
@@ -155,31 +157,31 @@ class HighPassFilter {
 #endif
   }
   void setFlaggedValuesToZeroAndMakeWeightsSimple(
-      const Image2DCPtr &inputImage, const Image2DPtr &outputImage,
-      const Mask2DCPtr &inputMask, const Image2DPtr &weightsOutput);
-  void setFlaggedValuesToZeroAndMakeWeightsSSE(const Image2DCPtr &inputImage,
-                                               const Image2DPtr &outputImage,
-                                               const Mask2DCPtr &inputMask,
-                                               const Image2DPtr &weightsOutput);
+      const Image2DCPtr& inputImage, const Image2DPtr& outputImage,
+      const Mask2DCPtr& inputMask, const Image2DPtr& weightsOutput);
+  void setFlaggedValuesToZeroAndMakeWeightsSSE(const Image2DCPtr& inputImage,
+                                               const Image2DPtr& outputImage,
+                                               const Mask2DCPtr& inputMask,
+                                               const Image2DPtr& weightsOutput);
 
-  void elementWiseDivide(const Image2DPtr &leftHand,
-                         const Image2DCPtr &rightHand) {
+  void elementWiseDivide(const Image2DPtr& leftHand,
+                         const Image2DCPtr& rightHand) {
 #ifdef USE_INTRINSICS
     elementWiseDivideSSE(leftHand, rightHand);
 #else
     elementWiseDivideSimple(leftHand, rightHand);
 #endif
   }
-  void elementWiseDivideSimple(const Image2DPtr &leftHand,
-                               const Image2DCPtr &rightHand);
-  void elementWiseDivideSSE(const Image2DPtr &leftHand,
-                            const Image2DCPtr &rightHand);
+  void elementWiseDivideSimple(const Image2DPtr& leftHand,
+                               const Image2DCPtr& rightHand);
+  void elementWiseDivideSSE(const Image2DPtr& leftHand,
+                            const Image2DCPtr& rightHand);
 
   /**
    * The values of the kernel used in the convolution. This kernel is applied
    * horizontally.
    */
-  num_t *_hKernel;
+  num_t* _hKernel;
 
   /**
    * The horizontal size of the sliding window in samples. Must be odd.
@@ -197,7 +199,7 @@ class HighPassFilter {
   /**
    * Vertical kernel values, see @ref _hKernel.
    */
-  num_t *_vKernel;
+  num_t* _vKernel;
 
   /**
    * The vertical size of the window, see @ref _hSquareSize.
@@ -212,6 +214,8 @@ class HighPassFilter {
   double _vKernelSigmaSq;
 };
 
+}  // namespace algorithms
+
 #undef USE_INTRINSICS
 
 #endif  // HIGHPASS_FILTER_H
