@@ -1,8 +1,13 @@
 #ifndef RESTORE_CHANNEL_RANGE_H
 #define RESTORE_CHANNEL_RANGE_H
 
-#include "../../structures/timefrequencydata.h"
-#include "../../structures/timefrequencymetadata.h"
+#include <utility>
+#include <vector>
+
+#include "../structures/timefrequencydata.h"
+#include "../structures/timefrequencymetadata.h"
+
+namespace algorithms {
 
 class RestoreChannelRange {
  public:
@@ -37,4 +42,6 @@ class RestoreChannelRange {
   }
 };
 
+}  // namespace algorithms
+
 #endif
