@@ -5,8 +5,10 @@
 #include <cmath>
 #include <complex>
 
-#include "../../structures/image2d.h"
-#include "../../structures/mask2d.h"
+#include "../structures/image2d.h"
+#include "../structures/mask2d.h"
+
+namespace algorithms {
 
 class ThresholdTools {
  public:
@@ -120,4 +122,6 @@ class ThresholdTools {
   }
 };
 
+}  // namespace algorithms
+
 #endif
