@@ -4,14 +4,16 @@
 #include <string>
 #include <sstream>
 
-TimeFrequencyStatistics::TimeFrequencyStatistics(const TimeFrequencyData &data)
+namespace algorithms {
+
+TimeFrequencyStatistics::TimeFrequencyStatistics(const TimeFrequencyData& data)
     : _data(data) {}
 
 num_t TimeFrequencyStatistics::GetFlaggedRatio() {
   size_t total = 0, flagged = 0;
 
   for (size_t i = 0; i < _data.MaskCount(); ++i) {
-    Mask2DCPtr mask = _data.GetMask(i);
+    const Mask2DCPtr mask = _data.GetMask(i);
     flagged += mask->GetCount<true>();
     total += mask->Width() * mask->Height();
   }
@@ -33,3 +35,5 @@ std::string TimeFrequencyStatistics::FormatRatio(num_t ratio) {
     s << (ratio * 100.0) << "%";
   return s.str();
 }
+
+}  // namespace algorithms
