@@ -4,10 +4,9 @@
 #include "../lua/scriptdata.h"
 
 #include "../structures/antennainfo.h"
-#include "../structures/system.h"
 
 #include "../util/logger.h"
-#include "../util/progresslistener.h"
+#include "../util/progress/dummyprogresslistener.h"
 #include "../util/stopwatch.h"
 
 #include "../imagesets/bhfitsimageset.h"
@@ -20,12 +19,14 @@
 
 #include "writethread.h"
 
+#include <aocommon/system.h>
+
 #include <sstream>
 #include <vector>
 
 BaselineIterator::BaselineIterator(std::mutex* ioMutex, const Options& options)
     : _options(options),
-      _baselineCount(0),
+      _sequenceCount(0),
       _nextIndex(0),
       _threadCount(4),
       _loopIndex(),
@@ -36,7 +37,7 @@ BaselineIterator::BaselineIterator(std::mutex* ioMutex, const Options& options)
 
 BaselineIterator::~BaselineIterator() {}
 
-void BaselineIterator::Run(rfiStrategy::ImageSet& imageSet, LuaThreadGroup& lua,
+void BaselineIterator::Run(imagesets::ImageSet& imageSet, LuaThreadGroup& lua,
                            ScriptData& scriptData) {
   _lua = &lua;
   _imageSet = &imageSet;
@@ -45,14 +46,15 @@ void BaselineIterator::Run(rfiStrategy::ImageSet& imageSet, LuaThreadGroup& lua,
   _writeThread.reset(new WriteThread(imageSet, _threadCount, _ioMutex));
   _globalScriptData = &scriptData;
 
-  rfiStrategy::MSImageSet* msImageSet =
-      dynamic_cast<rfiStrategy::MSImageSet*>(&imageSet);
+  imagesets::MSImageSet* msImageSet =
+      dynamic_cast<imagesets::MSImageSet*>(&imageSet);
   if (msImageSet) {
     // Check memory usage
-    rfiStrategy::ImageSetIndex tempIndex = msImageSet->StartIndex();
-    size_t timeStepCount = msImageSet->ObservationTimesVector(tempIndex).size();
-    size_t channelCount = msImageSet->GetBandInfo(0).channels.size();
-    double estMemorySizePerThread =
+    const imagesets::ImageSetIndex tempIndex = msImageSet->StartIndex();
+    const size_t timeStepCount =
+        msImageSet->ObservationTimesVector(tempIndex).size();
+    const size_t channelCount = msImageSet->GetBandInfo(0).channels.size();
+    const double estMemorySizePerThread =
         8.0 /*bp complex*/ * 4.0 /*polarizations*/ * double(timeStepCount) *
         double(channelCount) *
         3.0 /* approx copies of the data that will be made in memory*/;
@@ -61,7 +63,7 @@ void BaselineIterator::Run(rfiStrategy::ImageSet& imageSet, LuaThreadGroup& lua,
     size_t compThreadCount = _threadCount;
     if (compThreadCount > 0) --compThreadCount;
 
-    int64_t memSize = System::TotalMemory();
+    const int64_t memSize = aocommon::system::TotalMemory();
     Logger::Debug << "Detected " << memToStr(memSize) << " of system memory.\n";
 
     if (estMemorySizePerThread * double(compThreadCount) > memSize) {
@@ -79,44 +81,44 @@ void BaselineIterator::Run(rfiStrategy::ImageSet& imageSet, LuaThreadGroup& lua,
       _threadCount = maxThreads;
     }
   }
-  if (dynamic_cast<rfiStrategy::FilterBankSet*>(&imageSet) != nullptr &&
+  if (dynamic_cast<imagesets::FilterBankSet*>(&imageSet) != nullptr &&
       _threadCount != 1) {
     Logger::Info << "This is a Filterbank set -- disabling multi-threading\n";
     _threadCount = 1;
   }
   if (!_options.antennaeToSkip.empty()) {
     Logger::Debug << "The following antennas will be skipped: ";
-    for (size_t a : _options.antennaeToSkip) Logger::Debug << a << ' ';
+    for (const size_t a : _options.antennaeToSkip) Logger::Debug << a << ' ';
     Logger::Debug << '\n';
   }
   if (!_options.antennaeToInclude.empty()) {
     Logger::Debug << "Only the following antennas will be included: ";
-    for (size_t a : _options.antennaeToInclude) Logger::Debug << a << ' ';
+    for (const size_t a : _options.antennaeToInclude) Logger::Debug << a << ' ';
     Logger::Debug << '\n';
   }
 
   _finishedBaselines = false;
-  _baselineCount = 0;
+  _sequenceCount = 0;
   _baselineProgress = 0;
   _nextIndex = 0;
 
-  // Count the baselines that are to be processed
-  rfiStrategy::ImageSetIndex iteratorIndex = imageSet.StartIndex();
+  // Count the sequences that are to be processed
+  imagesets::ImageSetIndex iteratorIndex = imageSet.StartIndex();
   while (!iteratorIndex.HasWrapped()) {
-    if (IsBaselineSelected(iteratorIndex)) ++_baselineCount;
+    if (IsSequenceSelected(iteratorIndex)) ++_sequenceCount;
     iteratorIndex.Next();
   }
-  Logger::Debug << "Will process " << _baselineCount << " baselines.\n";
+  Logger::Debug << "Will process " << _sequenceCount << " sequences.\n";
 
   // Initialize thread data and threads
   _loopIndex = imageSet.StartIndex();
 
   std::vector<std::thread> threadGroup;
-  ReaderThread reader(*this);
+  const ReaderThread reader(*this);
   threadGroup.emplace_back(reader);
 
   for (unsigned i = 0; i < _threadCount; ++i) {
-    ProcessingThread function(*this, i);
+    const ProcessingThread function(*this, i);
     threadGroup.emplace_back(function);
   }
 
@@ -130,9 +132,9 @@ void BaselineIterator::Run(rfiStrategy::ImageSet& imageSet, LuaThreadGroup& lua,
         "the baselines: the RFI strategy will not continue.");
 }
 
-bool BaselineIterator::IsBaselineSelected(rfiStrategy::ImageSetIndex& index) {
-  rfiStrategy::IndexableSet* idImageSet =
-      dynamic_cast<rfiStrategy::IndexableSet*>(_imageSet);
+bool BaselineIterator::IsSequenceSelected(imagesets::ImageSetIndex& index) {
+  imagesets::IndexableSet* idImageSet =
+      dynamic_cast<imagesets::IndexableSet*>(_imageSet);
   size_t a1id, a2id;
   if (idImageSet != nullptr) {
     a1id = idImageSet->GetAntenna1(index);
@@ -160,7 +162,7 @@ bool BaselineIterator::IsBaselineSelected(rfiStrategy::ImageSetIndex& index) {
   // hold for single-"baseline" files.
   if (!_imageSet->HasCrossCorrelations()) return true;
 
-  switch (_options.baselineSelection.get_value_or(
+  switch (_options.baselineSelection.value_or(
       BaselineSelection::CrossCorrelations)) {
     case BaselineSelection::All:
       return true;
@@ -177,38 +179,33 @@ bool BaselineIterator::IsBaselineSelected(rfiStrategy::ImageSetIndex& index) {
   return false;
 }
 
-rfiStrategy::ImageSetIndex BaselineIterator::GetNextIndex() {
-  std::lock_guard<std::mutex> lock(_mutex);
+imagesets::ImageSetIndex BaselineIterator::GetNextIndex() {
+  const std::lock_guard<std::mutex> lock(_mutex);
   while (!_loopIndex.HasWrapped()) {
-    if (IsBaselineSelected(_loopIndex)) {
-      rfiStrategy::ImageSetIndex newIndex(_loopIndex);
+    if (IsSequenceSelected(_loopIndex)) {
+      imagesets::ImageSetIndex newIndex(_loopIndex);
       _loopIndex.Next();
 
       return newIndex;
     }
     _loopIndex.Next();
   }
-  return rfiStrategy::ImageSetIndex();
+  return imagesets::ImageSetIndex();
 }
 
 void BaselineIterator::SetExceptionOccured() {
-  std::lock_guard<std::mutex> lock(_mutex);
+  const std::lock_guard<std::mutex> lock(_mutex);
   _exceptionOccured = true;
   _dataProcessed.notify_all();
   _dataAvailable.notify_all();
 }
 
 void BaselineIterator::SetFinishedBaselines() {
-  std::lock_guard<std::mutex> lock(_mutex);
+  const std::lock_guard<std::mutex> lock(_mutex);
   _finishedBaselines = true;
 }
 
 void BaselineIterator::ProcessingThread::operator()() {
-  std::unique_lock<std::mutex> ioLock(*_parent._ioMutex);
-  std::unique_ptr<rfiStrategy::ImageSet> privateImageSet =
-      _parent._imageSet->Clone();
-  ioLock.unlock();
-
   ScriptData scriptData;
   const std::string executeFunctionName =
       _parent._options.executeFunctionName.empty()
@@ -216,7 +213,7 @@ void BaselineIterator::ProcessingThread::operator()() {
           : _parent._options.executeFunctionName;
 
   try {
-    std::unique_ptr<rfiStrategy::BaselineData> baseline =
+    std::unique_ptr<imagesets::BaselineData> baseline =
         _parent.GetNextBaseline();
 
     while (baseline != nullptr) {
@@ -247,9 +244,10 @@ void BaselineIterator::ProcessingThread::operator()() {
     _parent.SetExceptionOccured();
   }
 
-  ioLock.lock();
-  _parent._globalScriptData->Combine(std::move(scriptData));
-  ioLock.unlock();
+  {
+    const std::unique_lock<std::mutex> ioLock(*_parent._ioMutex);
+    _parent._globalScriptData->Combine(std::move(scriptData));
+  }
 
   Logger::Debug << "Processing thread finished.\n";
 }
@@ -257,10 +255,10 @@ void BaselineIterator::ProcessingThread::operator()() {
 void BaselineIterator::ReaderThread::operator()() {
   Stopwatch watch(true);
   bool finished = false;
-  size_t threadCount = _parent._threadCount;
+  const size_t threadCount = _parent._threadCount;
   size_t minRecommendedBufferSize, maxRecommendedBufferSize;
-  rfiStrategy::MSImageSet* msImageSet =
-      dynamic_cast<rfiStrategy::MSImageSet*>(_parent._imageSet);
+  imagesets::MSImageSet* msImageSet =
+      dynamic_cast<imagesets::MSImageSet*>(_parent._imageSet);
   if (msImageSet != nullptr) {
     minRecommendedBufferSize =
         msImageSet->Reader()->GetMinRecommendedBufferSize(threadCount);
@@ -276,7 +274,7 @@ void BaselineIterator::ReaderThread::operator()() {
     watch.Pause();
     _parent.WaitForReadBufferAvailable(minRecommendedBufferSize);
     if (!_parent._exceptionOccured) {
-      size_t wantedCount =
+      const size_t wantedCount =
           maxRecommendedBufferSize - _parent.GetBaselinesInBufferCount();
       size_t requestedCount = 0;
 
@@ -284,7 +282,7 @@ void BaselineIterator::ReaderThread::operator()() {
       watch.Start();
 
       for (size_t i = 0; i < wantedCount; ++i) {
-        rfiStrategy::ImageSetIndex index = _parent.GetNextIndex();
+        const imagesets::ImageSetIndex index = _parent.GetNextIndex();
         if (!index.Empty()) {
           _parent._imageSet->AddReadRequest(index);
           ++requestedCount;
@@ -300,10 +298,10 @@ void BaselineIterator::ReaderThread::operator()() {
         watch.Pause();
 
         for (size_t i = 0; i < requestedCount; ++i) {
-          std::unique_ptr<rfiStrategy::BaselineData> baseline =
+          std::unique_ptr<imagesets::BaselineData> baseline =
               _parent._imageSet->GetNextRequested();
 
-          std::lock_guard<std::mutex> bufferLock(_parent._mutex);
+          const std::lock_guard<std::mutex> bufferLock(_parent._mutex);
           _parent._baselineBuffer.emplace(std::move(baseline));
         }
       }
