@@ -5,23 +5,26 @@
 
 #include "../imagesets/imageset.h"
 
-#include <stack>
-#include <set>
-#include <mutex>
 #include <condition_variable>
+#include <memory>
+#include <mutex>
+#include <set>
+#include <stack>
+#include <string>
 #include <thread>
+#include <utility>
 
 class BaselineIterator {
  public:
   BaselineIterator(std::mutex* ioMutex, const Options& options);
   ~BaselineIterator();
 
-  void Run(rfiStrategy::ImageSet& imageSet, class LuaThreadGroup& lua,
+  void Run(imagesets::ImageSet& imageSet, class LuaThreadGroup& lua,
            class ScriptData& scriptData);
 
  private:
-  bool IsBaselineSelected(rfiStrategy::ImageSetIndex& index);
-  rfiStrategy::ImageSetIndex GetNextIndex();
+  bool IsSequenceSelected(imagesets::ImageSetIndex& index);
+  imagesets::ImageSetIndex GetNextIndex();
   static std::string memToStr(double memSize);
 
   void SetExceptionOccured();
@@ -44,16 +47,16 @@ class BaselineIterator {
       _dataProcessed.wait(lock);
   }
 
-  std::unique_ptr<rfiStrategy::BaselineData> GetNextBaseline() {
+  std::unique_ptr<imagesets::BaselineData> GetNextBaseline() {
     std::unique_lock<std::mutex> lock(_mutex);
     while (_baselineBuffer.size() == 0 && !_exceptionOccured &&
            !_finishedBaselines)
       _dataAvailable.wait(lock);
     if ((_finishedBaselines && _baselineBuffer.size() == 0) ||
-        _exceptionOccured)
+        _exceptionOccured) {
       return nullptr;
-    else {
-      std::unique_ptr<rfiStrategy::BaselineData> next =
+    } else {
+      std::unique_ptr<imagesets::BaselineData> next =
           std::move(_baselineBuffer.top());
       _baselineBuffer.pop();
       _dataProcessed.notify_one();
@@ -83,17 +86,17 @@ class BaselineIterator {
 
   const Options& _options;
   LuaThreadGroup* _lua;
-  rfiStrategy::ImageSet* _imageSet;
-  size_t _baselineCount, _nextIndex;
+  imagesets::ImageSet* _imageSet;
+  size_t _sequenceCount, _nextIndex;
   size_t _threadCount;
 
-  rfiStrategy::ImageSetIndex _loopIndex;
+  imagesets::ImageSetIndex _loopIndex;
 
   std::unique_ptr<class WriteThread> _writeThread;
 
   std::mutex _mutex, *_ioMutex;
   std::condition_variable _dataAvailable, _dataProcessed;
-  std::stack<std::unique_ptr<rfiStrategy::BaselineData>> _baselineBuffer;
+  std::stack<std::unique_ptr<imagesets::BaselineData>> _baselineBuffer;
   bool _finishedBaselines;
 
   bool _exceptionOccured;
