@@ -1,10 +1,10 @@
 #include "options.h"
 
-#include "../structures/system.h"
+#include <aocommon/system.h>
 
 size_t Options::CalculateThreadCount() const {
   if (threadCount)
     return threadCount;
   else
-    return System::ProcessorCount();
+    return aocommon::system::ProcessorCount();
 }
