@@ -6,22 +6,20 @@
 #include <gtkmm/frame.h>
 #include <gtkmm/radiobutton.h>
 
-#include "../rfigui/heatmapwidget.h"
-
 #include "../quality/qualitytablesformatter.h"
 
 #include "grayscaleplotpage.h"
 
 class BaselinePlotPage : public GrayScalePlotPage {
  public:
-  BaselinePlotPage(class BaselinePageController* controller);
+  explicit BaselinePlotPage(class BaselinePageController* controller);
   virtual ~BaselinePlotPage();
 
  protected:
  private:
   class BaselinePageController* _controller;
 
-  void onMouseMoved(size_t x, size_t y);
+  void onMouseMoved(double x, double y);
 };
 
 #endif
