@@ -1,12 +1,14 @@
 #ifndef AOQ_PLOT_PAGE_CONTROLLER
 #define AOQ_PLOT_PAGE_CONTROLLER
 
-#include <set>
 #include <map>
+#include <set>
+#include <string>
+#include <vector>
 
 #include "../../quality/qualitytablesformatter.h"
 
-#include "../../plot/plot2d.h"
+#include "../../plot/xyplot.h"
 
 #include "aoqpagecontroller.h"
 
@@ -17,18 +19,18 @@ class AOQPlotPageController : public AOQPageController {
 
   void Attach(class TwoDimensionalPlotPage* page) { _page = page; }
 
-  virtual void SetStatistics(
+  void SetStatistics(
       const StatisticsCollection* statCollection,
       const std::vector<class AntennaInfo>& antennas) override final;
 
-  virtual void CloseStatistics() override final { _statCollection = 0; }
+  void CloseStatistics() override final { _statCollection = nullptr; }
 
-  bool HasStatistics() const { return _statCollection != 0; }
+  bool HasStatistics() const { return _statCollection != nullptr; }
 
   void SavePdf(const std::string& filename,
                QualityTablesFormatter::StatisticKind kind);
 
-  Plot2D& Plot() { return _plot; }
+  XYPlot& Plot() { return _plot; }
 
   void UpdatePlot();
 
@@ -46,10 +48,10 @@ class AOQPlotPageController : public AOQPageController {
   virtual const std::map<double, class DefaultStatistics>& getStatistics()
       const = 0;
 
-  virtual void startLine(Plot2D& plot, const std::string& name, int lineIndex,
-                         const std::string& yAxisDesc) = 0;
+  virtual void startLine(XYPlot& plot, const std::string& name, int lineIndex,
+                         const std::string& yAxisDesc, bool second_axis) = 0;
 
-  virtual void processPlot(Plot2D& plot) {}
+  virtual void processPlot(XYPlot& plot) {}
 
   const StatisticsCollection* getStatCollection() const {
     return _statCollection;
@@ -63,18 +65,16 @@ class AOQPlotPageController : public AOQPageController {
   class TwoDimensionalPlotPage* _page;
 
   void updatePlotForSettings(
-      const std::set<QualityTablesFormatter::StatisticKind>& kinds,
+      const std::vector<QualityTablesFormatter::StatisticKind>& kinds,
       const std::set<SelectedPol>& pols, const std::set<PhaseType>& phases);
 
   double getValue(enum PhaseType Phase, const std::complex<long double>& val);
 
   void plotStatistic(QualityTablesFormatter::StatisticKind kind,
                      SelectedPol pol, PhaseType phase, int lineIndex,
-                     const std::string& yDesc);
+                     const std::string& yDesc, bool second_axis);
   const StatisticsCollection* _statCollection;
-  Plot2D _plot;
-  std::string getYDesc(
-      const std::set<QualityTablesFormatter::StatisticKind>& kinds) const;
+  XYPlot _plot;
 };
 
 #endif
