@@ -10,24 +10,24 @@
 HeatMapPageController::HeatMapPageController()
     : _page(nullptr),
       _statisticKind(QualityTablesFormatter::StandardDeviationStatistic),
-      _polarization(Polarization::StokesI),
+      _polarization(aocommon::Polarization::StokesI),
       _phase(TimeFrequencyData::AmplitudePart) {
   _heatMap.SetCairoFilter(Cairo::FILTER_NEAREST);
   _heatMap.SetColorMap(ColorMap::HotCold);
-  _heatMap.SetRange(HeatMapPlot::MinMax);
-  _heatMap.SetScaleOption(HeatMapPlot::LogScale);
+  _heatMap.SetZRange(FullRange());
+  _heatMap.SetLogZScale(true);
   _heatMap.SetZAxisDescription("Statistical value");
   _heatMap.SetManualZAxisDescription(true);
 }
 
 void HeatMapPageController::updateImageImpl(
     QualityTablesFormatter::StatisticKind statisticKind,
-    PolarizationEnum polarisation,
+    aocommon::PolarizationEnum polarisation,
     enum TimeFrequencyData::ComplexRepresentation phase) {
   std::pair<TimeFrequencyData, TimeFrequencyMetaDataCPtr> pair =
       constructImage(statisticKind);
 
-  TimeFrequencyData &data = pair.first;
+  TimeFrequencyData& data = pair.first;
 
   if (!data.IsEmpty()) {
     setToPolarization(data, polarisation);
@@ -44,18 +44,18 @@ void HeatMapPageController::updateImageImpl(
 
     _heatMap.SetZAxisDescription(
         StatisticsDerivator::GetDescWithUnits(statisticKind));
-    _heatMap.SetImage(image);
+    _heatMap.SetImage(std::unique_ptr<PlotImage>(new PlotImage(image)));
     _heatMap.SetOriginalMask(data.GetSingleMask());
-    if (pair.second != 0) _heatMap.SetMetaData(pair.second);
+    if (pair.second != nullptr) _heatMap.SetMetaData(pair.second);
 
     if (_page != nullptr) _page->Redraw();
   }
 }
 
-Image2D HeatMapPageController::normalizeXAxis(const Image2D &input) {
+Image2D HeatMapPageController::normalizeXAxis(const Image2D& input) {
   Image2D output = Image2D::MakeUnsetImage(input.Width(), input.Height());
   for (size_t x = 0; x < input.Width(); ++x) {
-    SampleRow row = SampleRow::MakeFromColumn(&input, x);
+    const SampleRow row = SampleRow::MakeFromColumn(&input, x);
     num_t norm;
     if (_normalization == Mean)
       norm = 1.0 / row.MeanWithMissings();
@@ -69,10 +69,10 @@ Image2D HeatMapPageController::normalizeXAxis(const Image2D &input) {
   return output;
 }
 
-Image2D HeatMapPageController::normalizeYAxis(const Image2D &input) {
+Image2D HeatMapPageController::normalizeYAxis(const Image2D& input) {
   Image2D output = Image2D::MakeUnsetImage(input.Width(), input.Height());
   for (size_t y = 0; y < input.Height(); ++y) {
-    SampleRow row = SampleRow::MakeFromRow(&input, y);
+    const SampleRow row = SampleRow::MakeFromRow(&input, y);
     num_t norm;
     if (_normalization == Mean)
       norm = 1.0 / row.MeanWithMissings();
@@ -86,22 +86,23 @@ Image2D HeatMapPageController::normalizeYAxis(const Image2D &input) {
   return output;
 }
 
-void HeatMapPageController::setToPolarization(TimeFrequencyData &data,
-                                              PolarizationEnum polarisation) {
-  if ((polarisation == Polarization::StokesI &&
-       data.HasPolarization(Polarization::XX) &&
-       data.HasPolarization(Polarization::YY)) ||
-      (polarisation != Polarization::StokesI &&
+void HeatMapPageController::setToPolarization(
+    TimeFrequencyData& data, aocommon::PolarizationEnum polarisation) {
+  if ((polarisation == aocommon::Polarization::StokesI &&
+       data.HasPolarization(aocommon::Polarization::XX) &&
+       data.HasPolarization(aocommon::Polarization::YY)) ||
+      (polarisation != aocommon::Polarization::StokesI &&
        data.HasPolarization(polarisation))) {
     data = data.Make(polarisation);
-    if (polarisation == Polarization::StokesI) data.MultiplyImages(0.5);
+    if (polarisation == aocommon::Polarization::StokesI)
+      data.MultiplyImages(0.5);
   } else {
     data.SetImagesToZero();
   }
 }
 
 void HeatMapPageController::setToPhase(
-    TimeFrequencyData &data,
+    TimeFrequencyData& data,
     enum TimeFrequencyData::ComplexRepresentation phase) {
   data = data.Make(phase);
 }
