@@ -23,7 +23,7 @@ void HistogramPageController::readFromFile() {
   CloseStatistics();
   HistogramTablesFormatter histogramTables(_statFilename);
   if (histogramTables.HistogramsExist()) {
-    MSMetaData set(_statFilename);
+    const MSMetaData set(_statFilename);
 
     const unsigned polarizationCount = set.PolarizationCount();
 
@@ -39,7 +39,7 @@ void HistogramPageController::CloseStatistics() {
 }
 
 void HistogramPageController::SetHistograms(
-    const HistogramCollection *histograms) {
+    const HistogramCollection* histograms) {
   CloseStatistics();
   _histograms.reset(new HistogramCollection(*histograms));
   _summedPolarizationHistograms.reset(
@@ -65,7 +65,7 @@ void HistogramPageController::updatePlot() {
 }
 
 void HistogramPageController::plotPolarization(
-    const HistogramCollection &histogramCollection, unsigned polarization) {
+    const HistogramCollection& histogramCollection, unsigned polarization) {
   LogHistogram totalHistogram, rfiHistogram;
   histogramCollection.GetTotalHistogramForCrossCorrelations(polarization,
                                                             totalHistogram);
@@ -74,7 +74,7 @@ void HistogramPageController::plotPolarization(
   plotPolarization(totalHistogram, rfiHistogram);
 }
 
-std::string HistogramPageController::SlopeText(const LogHistogram &histogram) {
+std::string HistogramPageController::SlopeText(const LogHistogram& histogram) {
   if (_automaticSlopeRange) {
     histogram.GetRFIRegion(_slopeStart, _slopeEnd);
   }
@@ -107,8 +107,8 @@ std::string HistogramPageController::SlopeText(const LogHistogram &histogram) {
   return str.str();
 }
 
-void HistogramPageController::plotSlope(const LogHistogram &histogram,
-                                        const std::string &title,
+void HistogramPageController::plotSlope(const LogHistogram& histogram,
+                                        const std::string& title,
                                         bool useLowerLimit2) {
   double start, end;
   if (_automaticSlopeRange) {
@@ -146,7 +146,7 @@ void HistogramPageController::plotSlope(const LogHistogram &histogram,
 }
 
 void HistogramPageController::plotPolarization(
-    const LogHistogram &totalHistogram, const LogHistogram &rfiHistogram) {
+    const LogHistogram& totalHistogram, const LogHistogram& rfiHistogram) {
   if (_totalHistogram) {
     _plot.StartLine("Total histogram", "Amplitude in arbitrary units (log)",
                     "Frequency (log)");
@@ -161,7 +161,7 @@ void HistogramPageController::plotPolarization(
     if (_drawSlope2) {
       plotSlope(totalHistogram, "Fitted slope", true);
     }
-    std::string str = SlopeText(totalHistogram);
+    const std::string str = SlopeText(totalHistogram);
     _page->SetSlopeFrame(str);
   }
 
@@ -173,7 +173,7 @@ void HistogramPageController::plotPolarization(
     if (_fit || _subtractFit) {
       plotFit(rfiHistogram, "Fit to RFI");
     }
-    std::string str = SlopeText(rfiHistogram);
+    const std::string str = SlopeText(rfiHistogram);
     _page->SetSlopeFrame(str);
     if (_drawSlope) {
       plotSlope(rfiHistogram, "Fitted slope", false);
@@ -196,8 +196,8 @@ void HistogramPageController::plotPolarization(
   }
 }
 
-void HistogramPageController::plotFit(const LogHistogram &histogram,
-                                      const std::string &title) {
+void HistogramPageController::plotFit(const LogHistogram& histogram,
+                                      const std::string& title) {
   double sigmaEstimate;
   sigmaEstimate = RayleighFitter::SigmaEstimate(histogram);
   if (_automaticFitRange) {
@@ -229,7 +229,7 @@ void HistogramPageController::plotFit(const LogHistogram &histogram,
   _page->SetFitText(str.str());
 }
 
-void HistogramPageController::addRayleighToPlot(const LogHistogram &histogram,
+void HistogramPageController::addRayleighToPlot(const LogHistogram& histogram,
                                                 double sigma, double n) {
   const bool derivative = _derivative;
   double x = histogram.MinPositiveAmplitude();
@@ -252,15 +252,15 @@ void HistogramPageController::addRayleighToPlot(const LogHistogram &histogram,
 }
 
 void HistogramPageController::addRayleighDifferenceToPlot(
-    const LogHistogram &histogram, double sigma, double n) {
+    const LogHistogram& histogram, double sigma, double n) {
   const double sigmaP2 = sigma * sigma;
-  double minCount = histogram.MinPosNormalizedCount();
+  const double minCount = histogram.MinPosNormalizedCount();
   for (LogHistogram::iterator i = histogram.begin(); i != histogram.end();
        ++i) {
     const double x = i.value();
 
     const double c = n * x / (sigmaP2)*exp(-x * x / (2 * sigmaP2));
-    double diff = fabs(i.normalizedCount() - c);
+    const double diff = fabs(i.normalizedCount() - c);
     if (diff >= minCount) {
       const double logx = log10(x);
       const double logc = log10(diff);
@@ -271,7 +271,7 @@ void HistogramPageController::addRayleighDifferenceToPlot(
 }
 
 void HistogramPageController::addHistogramToPlot(
-    const LogHistogram &histogram) {
+    const LogHistogram& histogram) {
   const bool derivative = _derivative;
   const bool staircase = _staircaseFunction;
   const bool normalize = _normalize;
@@ -285,6 +285,7 @@ void HistogramPageController::addHistogramToPlot(
       logxEnd = log10(i.binEnd());
     } else {
       logxStart = log10(x);
+      logxEnd = 0.0;  // unused, but to avoid warning
     }
     if (derivative) {
       const double cslope = histogram.NormalizedSlope(x / deltaS, x * deltaS);
