@@ -4,8 +4,10 @@
 #include "../../quality/statisticsderivator.h"
 
 TFPageController::TFPageController() : _statCollection(nullptr) {
-  Plot().SetXAxisDescription("Time index");
-  Plot().SetYAxisDescription("Frequency index");
+  HeatMap& map = Plot();
+  map.SetXAxisDescription("Time index");
+  map.SetXAxisType(AxisType::kTime);
+  map.SetYAxisDescription("Frequency index");
 }
 
 std::pair<TimeFrequencyData, TimeFrequencyMetaDataCPtr>
@@ -15,7 +17,7 @@ TFPageController::constructImage(QualityTablesFormatter::StatisticKind kind) {
 
     std::pair<TimeFrequencyData, TimeFrequencyMetaDataCPtr> data =
         derivator.CreateTFData(kind);
-    if (data.second == 0) {
+    if (data.second == nullptr) {
       Plot().SetXAxisDescription("Time index");
       Plot().SetYAxisDescription("Frequency index");
     } else {
