@@ -6,7 +6,7 @@
 #include <gtkmm/toolbutton.h>
 #include <gtkmm/separatortoolitem.h>
 
-#include "../rfigui/heatmapwidget.h"
+#include "../plot/plotwidget.h"
 
 #include "../quality/qualitytablesformatter.h"
 
@@ -15,14 +15,12 @@
 
 #include "plotsheet.h"
 
-using namespace aocommon;
-
 class GrayScalePlotPage : public PlotSheet {
  public:
-  GrayScalePlotPage(class HeatMapPageController* controller);
+  explicit GrayScalePlotPage(class HeatMapPageController* controller);
   virtual ~GrayScalePlotPage();
 
-  virtual void InitializeToolbar(Gtk::Toolbar& toolbar) override final;
+  void InitializeToolbar(Gtk::Toolbar& toolbar) override final;
 
   bool NormalizeXAxis() const { return _normalizeXAxisButton.get_active(); }
   bool NormalizeYAxis() const { return _normalizeYAxisButton.get_active(); }
@@ -36,7 +34,7 @@ class GrayScalePlotPage : public PlotSheet {
 
   void updateImage();
 
-  HeatMapWidget& grayScaleWidget() { return _imageWidget; }
+  PlotWidget& grayScaleWidget() { return _imageWidget; }
 
  private:
   void initStatisticKinds(Gtk::Toolbar& toolbar);
@@ -44,7 +42,7 @@ class GrayScalePlotPage : public PlotSheet {
   void initPhaseButtons(Gtk::Toolbar& toolbar);
   void initPlotOptions(Gtk::Toolbar& toolbar);
 
-  PolarizationEnum getSelectedPolarization() const;
+  aocommon::PolarizationEnum getSelectedPolarization() const;
   enum TimeFrequencyData::ComplexRepresentation getSelectedPhase() const;
 
   void onSelectCount() {
@@ -81,25 +79,10 @@ class GrayScalePlotPage : public PlotSheet {
   }
   void onPropertiesClicked();
 
-  void onSelectMinMaxRange() {
-    _imageWidget.Plot().SetRange(HeatMapPlot::MinMax);
-    _imageWidget.Update();
-  }
-  void onSelectWinsorizedRange() {
-    _imageWidget.Plot().SetRange(HeatMapPlot::Winsorized);
-    _imageWidget.Update();
-  }
-  void onSelectSpecifiedRange() {
-    _imageWidget.Plot().SetRange(HeatMapPlot::Specified);
-    _imageWidget.Update();
-  }
-  void onLogarithmicScaleClicked() {
-    if (_logarithmicScaleButton.get_active())
-      _imageWidget.Plot().SetScaleOption(HeatMapPlot::LogScale);
-    else
-      _imageWidget.Plot().SetScaleOption(HeatMapPlot::NormalScale);
-    _imageWidget.Update();
-  }
+  void onSelectMinMaxRange();
+  void onSelectWinsorizedRange();
+  void onSelectSpecifiedRange();
+  void onLogarithmicScaleClicked();
   void onNormalizeAxesButtonClicked() { updateImage(); }
   void onChangeNormMethod() {
     if (_normalizeYAxisButton.get_active()) updateImage();
@@ -132,7 +115,7 @@ class GrayScalePlotPage : public PlotSheet {
   Gtk::ToolButton _plotPropertiesButton;
 
   QualityTablesFormatter::StatisticKind _selectStatisticKind;
-  HeatMapWidget _imageWidget;
+  PlotWidget _imageWidget;
 
   class ImagePropertiesWindow* _imagePropertiesWindow;
 };
