@@ -6,18 +6,19 @@
 #include <gtkmm/box.h>
 #include <gtkmm/toolbar.h>
 
+#include <string>
 #include <vector>
 
 class PlotSheet : public Gtk::HBox {
  public:
-  sigc::signal<void, const std::string &> SignalStatusChange() {
+  sigc::signal<void, const std::string&> SignalStatusChange() {
     return _signalStatusChange;
   }
 
-  virtual void InitializeToolbar(Gtk::Toolbar &toolbar){};
+  virtual void InitializeToolbar(Gtk::Toolbar& toolbar) {}
 
  protected:
-  sigc::signal<void, const std::string &> _signalStatusChange;
+  sigc::signal<void, const std::string&> _signalStatusChange;
 };
 
 #endif
