@@ -8,13 +8,19 @@ TimeFrequencyPlotPage::TimeFrequencyPlotPage(TFPageController* controller)
       sigc::mem_fun(*this, &TimeFrequencyPlotPage::onMouseMoved));
 }
 
-void TimeFrequencyPlotPage::onMouseMoved(size_t x, size_t y) {
+void TimeFrequencyPlotPage::onMouseMoved(double x, double y) {
   std::stringstream text;
 
   const QualityTablesFormatter::StatisticKind kind = getSelectedStatisticKind();
   const std::string& kindName = QualityTablesFormatter::KindToName(kind);
 
-  text << kindName << " = " << grayScaleWidget().Plot().Image()->Value(x, y)
-       << " (" << x << ", " << y << ")";
+  const MaskedHeatMap& map =
+      static_cast<MaskedHeatMap&>(grayScaleWidget().Plot());
+  size_t image_x;
+  size_t image_y;
+  if (map.UnitToImage(x, y, image_x, image_y)) {
+    text << kindName << " = " << map.GetImage2D()->Value(image_x, image_y)
+         << " (" << image_x << ", " << image_y << ")";
+  }
   _signalStatusChange(text.str());
 }
