@@ -18,17 +18,20 @@
 
 #include <iostream>
 
+using algorithms::AntennaSelector;
+using algorithms::BaselineSelector;
+
 StatisticsCollection load(const std::string& filename,
                           std::vector<AntennaInfo>& antennae) {
   StatisticsCollection statisticsCollection;
-  HistogramCollection histogramCollection;
-  MSMetaData ms(filename);
+  const HistogramCollection histogramCollection;
+  const MSMetaData ms(filename);
   const unsigned polarizationCount = ms.PolarizationCount();
 
   statisticsCollection.SetPolarizationCount(polarizationCount);
   QualityTablesFormatter qualityData(filename);
   statisticsCollection.Load(qualityData);
-  unsigned antennaCount = ms.AntennaCount();
+  const unsigned antennaCount = ms.AntennaCount();
   for (unsigned a = 0; a < antennaCount; ++a)
     antennae.push_back(ms.GetAntennaInfo(a));
   return statisticsCollection;
@@ -38,15 +41,15 @@ std::set<size_t> detectRFIPercentage(const char* filename) {
   std::vector<AntennaInfo> antennae;
   StatisticsCollection statisticsCollection = load(filename, antennae);
 
-  rfiStrategy::BaselineSelector selector;
+  BaselineSelector selector;
   selector.SetUseLog(true);
 
   statisticsCollection.IntegrateBaselinesToOneChannel();
   const BaselineStatisticsMap& baselineMap =
       statisticsCollection.BaselineStatistics();
-  const std::vector<std::pair<unsigned, unsigned> > list =
+  const std::vector<std::pair<unsigned, unsigned>> list =
       baselineMap.BaselineList();
-  for (std::vector<std::pair<unsigned, unsigned> >::const_iterator i =
+  for (std::vector<std::pair<unsigned, unsigned>>::const_iterator i =
            list.begin();
        i != list.end(); ++i) {
     const unsigned a1 = i->first, a2 = i->second;
@@ -54,15 +57,14 @@ std::set<size_t> detectRFIPercentage(const char* filename) {
     DefaultStatistics statistic = baselineMap.GetStatistics(a1, a2);
     selector.Add(statistic, antennae[a1], antennae[a2]);
   }
-  std::vector<rfiStrategy::BaselineSelector::SingleBaselineInfo>
-      markedBaselines;
+  std::vector<BaselineSelector::SingleBaselineInfo> markedBaselines;
   std::set<unsigned> badStations;
 
   selector.Search(markedBaselines);
   selector.ImplyStations(markedBaselines, 0.3, badStations);
 
   std::cout << "List of " << badStations.size() << " bad stations:\n";
-  for (size_t ant : badStations) {
+  for (const size_t ant : badStations) {
     std::cout << antennae[ant].name << " (" << ant << ")\n";
   }
   return std::set<size_t>(badStations.begin(), badStations.end());
@@ -70,12 +72,12 @@ std::set<size_t> detectRFIPercentage(const char* filename) {
 
 std::set<size_t> detectStddev(const char* filename) {
   std::vector<AntennaInfo> antennae;
-  StatisticsCollection statisticsCollection = load(filename, antennae);
-  rfiStrategy::AntennaSelector selector;
+  const StatisticsCollection statisticsCollection = load(filename, antennae);
+  AntennaSelector selector;
   std::vector<size_t> badStations = selector.Run(statisticsCollection);
 
   std::cout << "List of " << badStations.size() << " bad stations:\n";
-  for (size_t ant : badStations) {
+  for (const size_t ant : badStations) {
     std::cout << antennae[ant].name << " (" << ant << ")\n";
   }
   return std::set<size_t>(badStations.begin(), badStations.end());
@@ -87,28 +89,28 @@ void flagAntennas(const char* filename, const std::set<size_t>& antennae) {
   /**
    * Read some meta data from the measurement set
    */
-  casacore::MSSpectralWindow spwTable = ms.spectralWindow();
-  size_t spwCount = spwTable.nrow();
+  const casacore::MSSpectralWindow spwTable = ms.spectralWindow();
+  const size_t spwCount = spwTable.nrow();
   if (spwCount != 1)
     throw std::runtime_error("Set should have exactly one spectral window");
 
-  casacore::ScalarColumn<int> numChanCol(
+  const casacore::ScalarColumn<int> numChanCol(
       spwTable, casacore::MSSpectralWindow::columnName(
                     casacore::MSSpectralWindowEnums::NUM_CHAN));
-  size_t channelCount = numChanCol.get(0);
+  const size_t channelCount = numChanCol.get(0);
   if (channelCount == 0) throw std::runtime_error("No channels in set");
 
-  casacore::ScalarColumn<int> ant1Column(
+  const casacore::ScalarColumn<int> ant1Column(
       ms, ms.columnName(casacore::MSMainEnums::ANTENNA1));
-  casacore::ScalarColumn<int> ant2Column(
+  const casacore::ScalarColumn<int> ant2Column(
       ms, ms.columnName(casacore::MSMainEnums::ANTENNA2));
   casacore::ArrayColumn<bool> flagsColumn(
       ms, ms.columnName(casacore::MSMainEnums::FLAG));
 
   if (ms.nrow() == 0) throw std::runtime_error("Table has no rows (no data)");
-  casacore::IPosition flagsShape = flagsColumn.shape(0);
+  const casacore::IPosition flagsShape = flagsColumn.shape(0);
 
-  casacore::Array<bool> flags(flagsShape, true);
+  const casacore::Array<bool> flags(flagsShape, true);
 
   std::cout << "Flagging... " << std::flush;
 
@@ -167,20 +169,21 @@ int main(int argc, char* argv[]) {
   bool doFlag = false;
   enum Method { StddevMethod, RFIPercentangeMethod } method = StddevMethod;
   while (argi < argc && argv[argi][0] == '-') {
-    std::string p(argv[argi] + 1);
-    if (p == "flag")
+    const std::string p(argv[argi] + 1);
+    if (p == "flag") {
       doFlag = true;
-    else if (p == "method") {
+    } else if (p == "method") {
       ++argi;
-      std::string m = argv[argi];
+      const std::string m = argv[argi];
       if (m == "stddev")
         method = StddevMethod;
       else if (m == "percentage")
         method = RFIPercentangeMethod;
       else
         throw std::runtime_error("Unknown method given");
-    } else
+    } else {
       throw std::runtime_error("Unknown parameter");
+    }
     ++argi;
   }
   if (argi >= argc) {
