@@ -4,17 +4,17 @@
 #include "../rfigui/controllers/rfiguicontroller.h"
 
 #include "../util/logger.h"
+#include "../util/progress/stdoutreporter.h"
 
 #include "../imagesets/msimageset.h"
 #include "../imagesets/msoptions.h"
 
 #include <version.h>
 
-#include <boost/tuple/tuple.hpp>
-#include <boost/tuple/tuple_comparison.hpp>
-
 #include <gtkmm/application.h>
 
+#include <pangomm/init.h>
+
 #include <glibmm/error.h>
 #include <glibmm/wrap.h>
 
@@ -27,9 +27,9 @@ struct SavedBaseline {
   size_t a1Index, a2Index, bandIndex, sequenceIndex;
   std::string filename;
   bool operator<(const SavedBaseline& rhs) const {
-    return boost::tie(a1Index, a2Index, bandIndex, sequenceIndex, filename) <
-           boost::tie(rhs.a1Index, rhs.a2Index, rhs.bandIndex,
-                      rhs.sequenceIndex, rhs.filename);
+    return std::tie(a1Index, a2Index, bandIndex, sequenceIndex, filename) <
+           std::tie(rhs.a1Index, rhs.a2Index, rhs.bandIndex, rhs.sequenceIndex,
+                    rhs.filename);
   }
 };
 
@@ -41,7 +41,7 @@ static void run(int argc, char* argv[]) {
   bool interactive = true;
   std::string dataColumnName = "DATA";
   bool plotFlags = true;
-  boost::optional<size_t> intervalStart, intervalEnd;
+  std::optional<size_t> intervalStart, intervalEnd;
 
   while (argi < argc) {
     if (argv[argi][0] == '-') {
@@ -126,20 +126,20 @@ static void run(int argc, char* argv[]) {
   if (interactive) {
     app = Gtk::Application::create(altArgc, argv, "",
                                    Gio::APPLICATION_HANDLES_OPEN);
-    window.reset(new RFIGuiWindow(&controller, argv[0]));
+    window = std::make_unique<RFIGuiWindow>(&controller, argv[0]);
     window->present();
   }
 
   try {
     if (!filenames.empty()) {
-      if (interactive)
+      if (interactive) {
         window->OpenPaths(filenames);
-      else {
+      } else {
+        Pango::init();
         MSOptions options;
         options.ioMode = DirectReadMode;
         options.dataColumnName = dataColumnName;
         options.combineSPWs = false;
-        options.subtractModel = false;
         options.intervalStart = intervalStart;
         options.intervalEnd = intervalEnd;
         options.baselineIntegration.enable = false;
@@ -148,21 +148,24 @@ static void run(int argc, char* argv[]) {
     }
 
     if (!savedBaselines.empty()) {
-      rfiStrategy::IndexableSet* imageSet =
-          dynamic_cast<rfiStrategy::IndexableSet*>(&controller.GetImageSet());
+      imagesets::IndexableSet* imageSet =
+          dynamic_cast<imagesets::IndexableSet*>(&controller.GetImageSet());
       if (imageSet == nullptr)
         throw std::runtime_error(
             "Option -save-baseline can only be used for measurement sets.\n");
-      HeatMapPlot& plot = controller.TFController().Plot();
-      plot.SetShowOriginalMask(plotFlags);
-      plot.SetShowXAxisDescription(true);
-      plot.SetShowYAxisDescription(true);
-      plot.SetShowZAxisDescription(true);
       for (const SavedBaseline& b : savedBaselines) {
         auto index =
             imageSet->Index(b.a1Index, b.a2Index, b.bandIndex, b.sequenceIndex);
         if (!index) throw std::runtime_error("Baseline not found!");
         controller.SetImageSetIndex(*index);
+        StdOutReporter reporter;
+        controller.LoadCurrentTFDataAsync(reporter);
+        controller.LoadCurrentTFDataFinish(true);
+        MaskedHeatMap& plot = controller.TFController().Plot();
+        plot.SetShowOriginalMask(plotFlags);
+        plot.SetShowXAxisDescription(true);
+        plot.SetShowYAxisDescription(true);
+        plot.SetShowZAxisDescription(true);
         plot.SaveByExtension(b.filename, 800, 480);
       }
     }
