@@ -4,7 +4,7 @@ import sys
 
 nch = 256
 ntimes = 1000
-count = 50       # number of trials in the false-positives test
+count = 50  # number of trials in the false-positives test
 
 flagger = aoflagger.AOFlagger()
 path = flagger.find_strategy_file(aoflagger.TelescopeId.Generic)
@@ -18,18 +18,25 @@ for repeat in range(count):
         # Initialize data with random numbers
         values = numpy.random.normal(0, 1, [nch, ntimes])
         data.set_image_buffer(imgindex, values)
-        
+
     flags = strategy.run(data)
     flagvalues = flags.get_buffer()
-    ratio = float(sum(sum(flagvalues))) / (nch*ntimes)
+    ratio = float(sum(sum(flagvalues))) / (nch * ntimes)
     ratiosum += ratio
-    ratiosumsq += ratio*ratio
-    sys.stdout.write('.')
+    ratiosumsq += ratio * ratio
+    sys.stdout.write(".")
     sys.stdout.flush()
 
-print('')
-    
-print("Percentage flags (false-positive rate) on Gaussian data: " +
-      str(ratiosum * 100.0 / count) + "% +/- " +
-      str(numpy.sqrt((ratiosumsq/count - ratiosum*ratiosum / (count*count))) * 100.0)
-     )
+print("")
+
+print(
+    "Percentage flags (false-positive rate) on Gaussian data: "
+    + str(ratiosum * 100.0 / count)
+    + "% +/- "
+    + str(
+        numpy.sqrt(
+            (ratiosumsq / count - ratiosum * ratiosum / (count * count))
+        )
+        * 100.0
+    )
+)
