@@ -1,19 +1,19 @@
 #include "bhfitsimageset.h"
 
-#include "../../msio/fitsfile.h"
-#include "../../structures/image2d.h"
-#include "../../structures/timefrequencydata.h"
+#include "../msio/fitsfile.h"
+#include "../structures/image2d.h"
+#include "../structures/timefrequencydata.h"
 
-#include "../../util/logger.h"
+#include "../util/logger.h"
 
-namespace rfiStrategy {
+namespace imagesets {
 
-BHFitsImageSet::BHFitsImageSet(const std::string &file)
+BHFitsImageSet::BHFitsImageSet(const std::string& file)
     : ImageSet(), _file(new FitsFile(file)), _width(0), _height(0) {
   Logger::Debug << "Opening bhfits file: '" << file << "'\n";
   try {
     _file->Open(FitsFile::ReadWriteMode);
-  } catch (FitsIOException &exception) {
+  } catch (FitsIOException& exception) {
     Logger::Error
         << "CFitsio failed to open file in RW mode with the following error:\n"
         << exception.what()
@@ -23,7 +23,7 @@ BHFitsImageSet::BHFitsImageSet(const std::string &file)
   }
 }
 
-BHFitsImageSet::BHFitsImageSet(const BHFitsImageSet &source)
+BHFitsImageSet::BHFitsImageSet(const BHFitsImageSet& source)
     : ImageSet(),
       _file(source._file),
       _baselineData(source._baselineData),
@@ -31,7 +31,7 @@ BHFitsImageSet::BHFitsImageSet(const BHFitsImageSet &source)
       _width(source._width),
       _height(source._height) {}
 
-BHFitsImageSet::~BHFitsImageSet() {}
+BHFitsImageSet::~BHFitsImageSet() = default;
 
 std::unique_ptr<ImageSet> BHFitsImageSet::Clone() {
   return std::unique_ptr<BHFitsImageSet>(new BHFitsImageSet(*this));
@@ -69,7 +69,7 @@ void BHFitsImageSet::Initialize() {
     termKey << keyIndex;
     std::string antRangeStr, termRangeStr;
     if (_file->GetKeywordValue(antKey.str(), antRangeStr)) {
-      std::pair<int, int> range = getRangeFromString(antRangeStr);
+      const std::pair<int, int> range = getRangeFromString(antRangeStr);
       TimeRange timeRange;
       // As commented by Marcin below, the ranges in the fits headers are given
       // like 'start - end', where the indices start counting at 1, and the end
@@ -87,7 +87,7 @@ void BHFitsImageSet::Initialize() {
       searchOn = true;
     }
     if (_file->GetKeywordValue(termKey.str(), termRangeStr)) {
-      std::pair<int, int> range = getRangeFromString(termRangeStr);
+      const std::pair<int, int> range = getRangeFromString(termRangeStr);
       TimeRange timeRange;
       // (see earlier comment by Marcin Sokolowski)
       timeRange.start = range.first - 1;
@@ -114,22 +114,22 @@ void BHFitsImageSet::Initialize() {
   }
 }
 
-BaselineData BHFitsImageSet::loadData(const ImageSetIndex &index) {
-  TimeFrequencyMetaDataPtr metaData(new TimeFrequencyMetaData());
+BaselineData BHFitsImageSet::loadData(const ImageSetIndex& index) {
+  const TimeFrequencyMetaDataPtr metaData(new TimeFrequencyMetaData());
   TimeFrequencyData data;
   loadImageData(data, metaData, index);
   return BaselineData(data, metaData, index);
 }
 
-void BHFitsImageSet::loadImageData(TimeFrequencyData &data,
-                                   const TimeFrequencyMetaDataPtr &metaData,
-                                   const ImageSetIndex &index) {
+void BHFitsImageSet::loadImageData(TimeFrequencyData& data,
+                                   const TimeFrequencyMetaDataPtr& metaData,
+                                   const ImageSetIndex& index) {
   std::vector<num_t> buffer(_width * _height);
   _file->ReadCurrentImageData(0, &buffer[0], _width * _height);
 
   int rangeStart = _timeRanges[index.Value()].start,
       rangeEnd = _timeRanges[index.Value()].end;
-  Image2DPtr image =
+  const Image2DPtr image =
       Image2D::CreateZeroImagePtr(rangeEnd - rangeStart, _height);
 
   std::vector<num_t>::const_iterator bufferPtr =
@@ -148,7 +148,8 @@ void BHFitsImageSet::loadImageData(TimeFrequencyData &data,
     flagFile.Open(FitsFile::ReadOnlyMode);
     flagFile.ReadCurrentImageData(0, &buffer[0], _width * _height);
     bufferPtr = buffer.begin() + _height * rangeStart;
-    Mask2DPtr mask = Mask2D::CreateUnsetMaskPtr(rangeEnd - rangeStart, _height);
+    const Mask2DPtr mask =
+        Mask2D::CreateUnsetMaskPtr(rangeEnd - rangeStart, _height);
     for (int x = rangeStart; x != rangeEnd; ++x) {
       for (int y = 0; y != _height; ++y) {
         bool flag = false;
@@ -165,7 +166,7 @@ void BHFitsImageSet::loadImageData(TimeFrequencyData &data,
       }
     }
     data.SetGlobalMask(mask);
-  } catch (std::exception &) {
+  } catch (std::exception&) {
     // Flag file could not be read; probably does not exist. Ignore this, flags
     // will be initialized to false.
   }
@@ -197,9 +198,9 @@ void BHFitsImageSet::loadImageData(TimeFrequencyData &data,
 }
 
 std::pair<int, int> BHFitsImageSet::getRangeFromString(
-    const std::string &rangeStr) {
+    const std::string& rangeStr) {
   std::pair<int, int> value;
-  size_t partA = rangeStr.find(' ');
+  const size_t partA = rangeStr.find(' ');
   value.first = atoi(rangeStr.substr(0, partA).c_str());
   size_t partB = rangeStr.find('-');
   if (rangeStr[partB + 1] == ' ') ++partB;
@@ -216,12 +217,12 @@ std::string BHFitsImageSet::flagFilePath() const {
   return flagFilePath;
 }
 
-void BHFitsImageSet::AddWriteFlagsTask(const ImageSetIndex &index,
-                                       std::vector<Mask2DCPtr> &flags) {
+void BHFitsImageSet::AddWriteFlagsTask(const ImageSetIndex& index,
+                                       std::vector<Mask2DCPtr>& flags) {
   if (flags.size() != 1)
     throw std::runtime_error(
         "BHFitsImageSet::AddWriteFlagsTask() called with multiple flags");
-  std::string flagFilename = flagFilePath();
+  const std::string flagFilename = flagFilePath();
   Logger::Debug << "Writing to " << flagFilename << '\n';
   FitsFile flagFile(flagFilename);
   bool newFile = true;
@@ -229,7 +230,7 @@ void BHFitsImageSet::AddWriteFlagsTask(const ImageSetIndex &index,
   try {
     flagFile.Open(FitsFile::ReadWriteMode);
     newFile = false;
-  } catch (std::exception &) {
+  } catch (std::exception&) {
     Logger::Debug << "File did not exist yet, creating new.\n";
     flagFile.Create();
     flagFile.AppendImageHUD(FitsFile::Float32ImageType, _height, _width);
@@ -259,7 +260,7 @@ void BHFitsImageSet::PerformWriteFlagsTask() {
   // Nothing to do; already written
 }
 
-std::string BHFitsImageSet::Description(const ImageSetIndex &index) const {
+std::string BHFitsImageSet::Description(const ImageSetIndex& index) const {
   std::ostringstream str;
   str << "Time range " << RangeName(index.Value());
   return str.str();
@@ -268,4 +269,4 @@ std::string BHFitsImageSet::Description(const ImageSetIndex &index) const {
 std::vector<std::string> BHFitsImageSet::Files() const {
   return std::vector<std::string>{_file->Filename()};
 }
-}  // namespace rfiStrategy
+}  // namespace imagesets
