@@ -4,14 +4,17 @@
 #include "imageset.h"
 #include "msimageset.h"
 
-#include "../../structures/msmetadata.h"
-#include "../../util/logger.h"
+#include "../structures/msmetadata.h"
+#include "../util/logger.h"
 
-#include <vector>
 #include <list>
 #include <map>
+#include <memory>
+#include <string>
+#include <utility>
+#include <vector>
 
-namespace rfiStrategy {
+namespace imagesets {
 
 using Sequence = MSMetaData::Sequence;
 
@@ -42,7 +45,7 @@ class CoaddedImageSet final : public IndexableSet {
       newSet->_msImageSets.emplace_back(
           std::unique_ptr<MSImageSet>(new MSImageSet(*imageSet)));
     }
-    return std::move(newSet);
+    return newSet;
   }
   size_t Size() const override { return _msImageSets[0]->Size(); }
   std::string Description(const ImageSetIndex& index) const override;
@@ -154,9 +157,9 @@ class CoaddedImageSet final : public IndexableSet {
     return _msImageSets.front()->SequenceCount();
   }
 
-  boost::optional<ImageSetIndex> Index(size_t antenna1, size_t antenna2,
-                                       size_t bandIndex,
-                                       size_t sequenceId) const override {
+  std::optional<ImageSetIndex> Index(size_t antenna1, size_t antenna2,
+                                     size_t bandIndex,
+                                     size_t sequenceId) const override {
     return _msImageSets[0]->Index(antenna1, antenna2, bandIndex, sequenceId);
   }
 
@@ -177,6 +180,6 @@ class CoaddedImageSet final : public IndexableSet {
 std::string CoaddedImageSet::Description(const ImageSetIndex& index) const {
   return _msImageSets[0]->Description(index) + " (coadded)";
 }
-}  // namespace rfiStrategy
+}  // namespace imagesets
 
 #endif
