@@ -4,19 +4,22 @@
 #include <vector>
 #include <set>
 #include <map>
+#include <memory>
+#include <string>
+#include <utility>
 
 #include "imageset.h"
 
-#include "../../structures/antennainfo.h"
-#include "../../structures/types.h"
+#include "../structures/antennainfo.h"
+#include "../structures/types.h"
 
-#include "../../util/progresslistener.h"
+#include "../util/progress/progresslistener.h"
 
-namespace rfiStrategy {
+namespace imagesets {
 
 class FitsImageSet final : public ImageSet {
  public:
-  explicit FitsImageSet(const std::string &file);
+  explicit FitsImageSet(const std::string& file);
   ~FitsImageSet();
 
   void Initialize() override;
@@ -25,16 +28,16 @@ class FitsImageSet final : public ImageSet {
 
   size_t Size() const override { return _baselines.size() * _bandCount; }
 
-  std::string Description(const ImageSetIndex &index) const override;
+  std::string Description(const ImageSetIndex& index) const override;
 
   std::string Name() const override { return Files().front(); }
   std::vector<std::string> Files() const override;
 
-  void AddReadRequest(const ImageSetIndex &index) override {
+  void AddReadRequest(const ImageSetIndex& index) override {
     _readRequests.emplace_back(index);
   }
 
-  void PerformReadRequests(ProgressListener &progress) override {
+  void PerformReadRequests(ProgressListener& progress) override {
     // Immediately clear the _readRequests, to have it empty in case of
     // exceptions
     const std::vector<ImageSetIndex> requests = std::move(_readRequests);
@@ -51,52 +54,52 @@ class FitsImageSet final : public ImageSet {
     _baselineData.resize(_baselineData.size() - 1);
     return data;
   }
-  void AddWriteFlagsTask(const ImageSetIndex &index,
-                         std::vector<Mask2DCPtr> &flags) override;
+  void AddWriteFlagsTask(const ImageSetIndex& index,
+                         std::vector<Mask2DCPtr>& flags) override;
   void PerformWriteFlagsTask() override;
-  void PerformWriteDataTask(const ImageSetIndex &, std::vector<Image2DCPtr>,
+  void PerformWriteDataTask(const ImageSetIndex&, std::vector<Image2DCPtr>,
                             std::vector<Image2DCPtr>) override {
     throw std::runtime_error("Not implemented");
   }
-  std::string TelescopeName() final override;
-  bool HasCrossCorrelations() const final override { return false; }
-  const std::vector<std::pair<size_t, size_t> > &Baselines() const {
+  std::string TelescopeName() override;
+  bool HasCrossCorrelations() const override { return false; }
+  const std::vector<std::pair<size_t, size_t>>& Baselines() const {
     return _baselines;
   }
   size_t BandCount() const { return _bandCount; }
   class AntennaInfo GetAntennaInfo(unsigned antennaIndex) const {
     return _antennaInfos[antennaIndex];
   }
-  const std::string &SourceName() const { return _sourceName; }
+  const std::string& SourceName() const { return _sourceName; }
   bool IsDynSpectrumType() const { return _fitsType == DynSpectrumType; }
 
  private:
-  FitsImageSet(const FitsImageSet &source);
-  BaselineData loadData(const ImageSetIndex &index);
+  FitsImageSet(const FitsImageSet& source);
+  BaselineData loadData(const ImageSetIndex& index);
 
-  void ReadPrimarySingleTable(TimeFrequencyData &data,
-                              TimeFrequencyMetaData &metaData);
-  void ReadTable(TimeFrequencyData &data, TimeFrequencyMetaData &metaData,
+  void ReadPrimarySingleTable(TimeFrequencyData& data,
+                              TimeFrequencyMetaData& metaData);
+  void ReadTable(TimeFrequencyData& data, TimeFrequencyMetaData& metaData,
                  size_t bandIndex);
-  void ReadAntennaTable(TimeFrequencyMetaData &metaData);
-  void ReadFrequencyTable(TimeFrequencyData &data,
-                          TimeFrequencyMetaData &metaData);
+  void ReadAntennaTable(TimeFrequencyMetaData& metaData);
+  void ReadFrequencyTable(TimeFrequencyData& data,
+                          TimeFrequencyMetaData& metaData);
   void ReadCalibrationTable();
-  void ReadSingleDishTable(TimeFrequencyData &data,
-                           TimeFrequencyMetaData &metaData, size_t ifIndex);
-  void ReadDynSpectrum(TimeFrequencyData &data,
-                       TimeFrequencyMetaData &metaData);
+  void ReadSingleDishTable(TimeFrequencyData& data,
+                           TimeFrequencyMetaData& metaData, size_t ifIndex);
+  void ReadDynSpectrum(TimeFrequencyData& data,
+                       TimeFrequencyMetaData& metaData);
 
   TimeFrequencyData ReadPrimaryGroupTable(size_t baselineIndex, int band,
                                           int stokes,
-                                          TimeFrequencyMetaData &metaData);
+                                          TimeFrequencyMetaData& metaData);
 
-  void saveSingleDishFlags(const std::vector<Mask2DCPtr> &flags,
+  void saveSingleDishFlags(const std::vector<Mask2DCPtr>& flags,
                            size_t ifIndex);
-  void saveDynSpectrumFlags(const std::vector<Mask2DCPtr> &flags);
+  void saveDynSpectrumFlags(const std::vector<Mask2DCPtr>& flags);
 
   std::shared_ptr<class FitsFile> _file;
-  std::vector<std::pair<size_t, size_t> > _baselines;
+  std::vector<std::pair<size_t, size_t>> _baselines;
   size_t _bandCount;
   std::vector<AntennaInfo> _antennaInfos;
   std::map<int, BandInfo> _bandInfos;
@@ -110,6 +113,6 @@ class FitsImageSet final : public ImageSet {
   enum { UVFitsType, SDFitsType, DynSpectrumType } _fitsType;
 };
 
-}  // namespace rfiStrategy
+}  // namespace imagesets
 
 #endif
