@@ -2,19 +2,19 @@
 
 #include <png.h>
 
-std::unique_ptr<rfiStrategy::BaselineData> rfiStrategy::PngReader::Read(
+std::unique_ptr<imagesets::BaselineData> imagesets::PngReader::Read(
     class ProgressListener& progress) {
   FILE* fp = fopen(_path.c_str(), "rb");
-  if (fp == 0) throw std::runtime_error("Could not open file");
+  if (fp == nullptr) throw std::runtime_error("Could not open file");
 
   png_structp png_ptr =
-      png_create_read_struct(PNG_LIBPNG_VER_STRING, (png_voidp)0, 0, 0);
+      png_create_read_struct(PNG_LIBPNG_VER_STRING, nullptr, nullptr, nullptr);
 
   if (!png_ptr) throw std::runtime_error("Error creating png struct");
 
   png_infop info_ptr = png_create_info_struct(png_ptr);
   if (!info_ptr) {
-    png_destroy_read_struct(&png_ptr, (png_infopp)0, (png_infopp)0);
+    png_destroy_read_struct(&png_ptr, nullptr, nullptr);
     throw std::runtime_error("Error creating png read struct");
   }
 
@@ -22,10 +22,10 @@ std::unique_ptr<rfiStrategy::BaselineData> rfiStrategy::PngReader::Read(
 
   png_read_info(png_ptr, info_ptr);
 
-  unsigned width = png_get_image_width(png_ptr, info_ptr);
-  unsigned height = png_get_image_height(png_ptr, info_ptr);
-  unsigned color_type = png_get_color_type(png_ptr, info_ptr);
-  unsigned bit_depth = png_get_bit_depth(png_ptr, info_ptr);
+  const unsigned width = png_get_image_width(png_ptr, info_ptr);
+  const unsigned height = png_get_image_height(png_ptr, info_ptr);
+  const unsigned color_type = png_get_color_type(png_ptr, info_ptr);
+  const unsigned bit_depth = png_get_bit_depth(png_ptr, info_ptr);
   Logger::Debug << "Png file: " << width << 'x' << height
                 << " colortype=" << color_type << ", bit_depth=" << bit_depth
                 << '\n';
@@ -43,8 +43,8 @@ std::unique_ptr<rfiStrategy::BaselineData> rfiStrategy::PngReader::Read(
 
   fclose(fp);
 
-  Image2DPtr image = Image2D::CreateZeroImagePtr(width, height);
-  size_t bytesPerSample = 4;
+  const Image2DPtr image = Image2D::CreateZeroImagePtr(width, height);
+  const size_t bytesPerSample = 4;
   for (size_t f = 0; f < height; ++f) {
     for (size_t t = 0; t < width; ++t) {
       int r = row_pointers[f][t * bytesPerSample],
@@ -54,8 +54,8 @@ std::unique_ptr<rfiStrategy::BaselineData> rfiStrategy::PngReader::Read(
     }
   }
 
-  TimeFrequencyData tfData(TimeFrequencyData::AmplitudePart,
-                           aocommon::Polarization::StokesI, image);
-  return std::unique_ptr<rfiStrategy::BaselineData>(
+  const TimeFrequencyData tfData(TimeFrequencyData::AmplitudePart,
+                                 aocommon::Polarization::StokesI, image);
+  return std::unique_ptr<imagesets::BaselineData>(
       new BaselineData(tfData, TimeFrequencyMetaDataCPtr()));
 }
