@@ -1,11 +1,13 @@
 #include "rfibaselineset.h"
 
-#include "../../msio/singlebaselinefile.h"
+#include "../msio/singlebaselinefile.h"
 
 #include <fstream>
 #include <sstream>
 
-namespace rfiStrategy {
+#include "../util/progress/dummyprogresslistener.h"
+
+namespace imagesets {
 
 RFIBaselineSet::RFIBaselineSet(const std::string& path)
     : SingleImageSet(), _path(path) {}
@@ -34,8 +36,9 @@ std::string RFIBaselineSet::BaselineDescription() {
             << " x " << _metaData.Antenna2().station << ' '
             << _metaData.Antenna2().name;
     return sstream.str();
-  } else
+  } else {
     return Files().front();
+  }
 }
 
 void RFIBaselineSet::Write(const std::vector<Mask2DCPtr>& masks) {
@@ -53,4 +56,4 @@ void RFIBaselineSet::Write(const std::vector<Mask2DCPtr>& masks) {
   file.Write(outstr);
 }
 
-}  // namespace rfiStrategy
+}  // namespace imagesets
