@@ -1,11 +1,15 @@
 #ifndef RFI_BASELINE_SET_H
 #define RFI_BASELINE_SET_H
 
-#include "../../structures/types.h"
+#include "../structures/types.h"
 
 #include "singleimageset.h"
 
-namespace rfiStrategy {
+#include <memory>
+#include <string>
+#include <vector>
+
+namespace imagesets {
 
 class RFIBaselineSet final : public SingleImageSet {
  public:
@@ -40,6 +44,6 @@ class RFIBaselineSet final : public SingleImageSet {
   RFIBaselineSet(const RFIBaselineSet& source) = default;
 };
 
-}  // namespace rfiStrategy
+}  // namespace imagesets
 
 #endif
