@@ -1,14 +1,16 @@
 #ifndef SINGLEIMAGESET_H
 #define SINGLEIMAGESET_H
 
+#include <memory>
 #include <string>
 #include <stdexcept>
+#include <vector>
 
-#include "../../structures/types.h"
+#include "../structures/types.h"
 
 #include "imageset.h"
 
-namespace rfiStrategy {
+namespace imagesets {
 
 class SingleImageSet : public ImageSet {
  public:
@@ -82,6 +84,6 @@ class SingleImageSet : public ImageSet {
   std::vector<Mask2DCPtr> _writeFlagsMasks;
 };
 
-}  // namespace rfiStrategy
+}  // namespace imagesets
 
 #endif
