@@ -1,27 +1,27 @@
 #ifndef DEFAULTMODELS_H
 #define DEFAULTMODELS_H
 
+#include <utility>
+
 #include "model.h"
 #include "observatorium.h"
 
+enum class SourceSet {
+  NoDistortion,
+  ConstantDistortion,
+  StrongVariableDistortion,
+  FaintVariableDistortion
+};
+
 class DefaultModels {
  public:
-  enum SetLocation { EmptySet, NCPSet, B1834Set };
-  enum Distortion {
-    NoDistortion,
-    ConstantDistortion,
-    VariableDistortion,
-    FaintDistortion,
-    MislocatedDistortion,
-    OnAxisSource
-  };
-
+  enum SetLocation { EmptySet, NCPSet };
   static double DistortionRA() { return 4.940; }
 
   static double DistortionDec() { return 0.571; }
 
   static std::pair<TimeFrequencyData, TimeFrequencyMetaDataPtr> LoadSet(
-      enum SetLocation setLocation, enum Distortion distortion,
+      enum SetLocation setLocation, enum SourceSet distortion,
       double noiseSigma, size_t channelCount = 64,
       double bandwidth = 2500000.0 * 16.0, unsigned a1 = 0, unsigned a2 = 5) {
     double ra, dec, factor;
@@ -30,26 +30,19 @@ class DefaultModels {
     model.SetNoiseSigma(noiseSigma);
     if (setLocation != EmptySet) model.loadUrsaMajor(ra, dec, factor);
     switch (distortion) {
-      case NoDistortion:
+      case SourceSet::NoDistortion:
         break;
-      case ConstantDistortion:
+      case SourceSet::ConstantDistortion:
         model.loadUrsaMajorDistortingSource(ra, dec, factor, true);
         break;
-      case VariableDistortion:
+      case SourceSet::StrongVariableDistortion:
         model.loadUrsaMajorDistortingVariableSource(ra, dec, factor, false,
                                                     false);
         break;
-      case FaintDistortion:
+      case SourceSet::FaintVariableDistortion:
         model.loadUrsaMajorDistortingVariableSource(ra, dec, factor, true,
                                                     false);
         break;
-      case MislocatedDistortion:
-        model.loadUrsaMajorDistortingVariableSource(ra, dec, factor, false,
-                                                    true);
-        break;
-      case OnAxisSource:
-        model.loadOnAxisSource(ra, dec, factor);
-        break;
     }
     WSRTObservatorium wsrtObservatorium(channelCount, bandwidth);
     return model.SimulateObservation(12 * 60 * 60 / 15, wsrtObservatorium, dec,
@@ -57,8 +50,8 @@ class DefaultModels {
   }
 
  private:
-  static void getSetData(enum SetLocation setLocation, double &ra, double &dec,
-                         double &factor) {
+  static void getSetData(enum SetLocation setLocation, double& ra, double& dec,
+                         double& factor) {
     if (setLocation == NCPSet) {
       dec = 0.5 * M_PI + 0.12800;
       ra = -0.03000;
