@@ -12,15 +12,16 @@
 Model::Model() : _noiseSigma(1.0), _sourceSigma(0.0), _integrationTime(15.0) {}
 
 template <typename T>
-void Model::SimulateObservation(struct OutputReceiver<T> &receiver,
-                                Observatorium &observatorium,
+void Model::SimulateObservation(struct OutputReceiver<T>& receiver,
+                                Observatorium& observatorium,
                                 num_t delayDirectionDEC,
                                 num_t delayDirectionRA) {
   const size_t channelCount = observatorium.BandInfo().channels.size();
   const double frequency = observatorium.BandInfo().channels[0].frequencyHz;
 
   for (size_t f = 0; f < channelCount; ++f) {
-    double channelFrequency = frequency + observatorium.ChannelWidthHz() * f;
+    const double channelFrequency =
+        frequency + observatorium.ChannelWidthHz() * f;
     receiver.SetY(f);
     for (size_t i = 0; i < observatorium.AntennaCount(); ++i) {
       for (size_t j = i + 1; j < observatorium.AntennaCount(); ++j) {
@@ -40,15 +41,15 @@ void Model::SimulateObservation(struct OutputReceiver<T> &receiver,
 }
 
 template void Model::SimulateObservation(
-    struct OutputReceiver<UVImager> &receiver, Observatorium &observatorium,
+    struct OutputReceiver<UVImager>& receiver, Observatorium& observatorium,
     num_t delayDirectionDEC, num_t delayDirectionRA);
 template void Model::SimulateObservation(
-    struct OutputReceiver<TimeFrequencyData> &receiver,
-    Observatorium &observatorium, num_t delayDirectionDEC,
+    struct OutputReceiver<TimeFrequencyData>& receiver,
+    Observatorium& observatorium, num_t delayDirectionDEC,
     num_t delayDirectionRA);
 
 std::pair<TimeFrequencyData, TimeFrequencyMetaDataPtr>
-Model::SimulateObservation(size_t nTimes, class Observatorium &observatorium,
+Model::SimulateObservation(size_t nTimes, class Observatorium& observatorium,
                            num_t delayDirectionDEC, num_t delayDirectionRA,
                            size_t a1, size_t a2) {
   const size_t channelCount = observatorium.BandInfo().channels.size();
@@ -58,7 +59,7 @@ Model::SimulateObservation(size_t nTimes, class Observatorium &observatorium,
   tfOutputter._real = Image2D::CreateZeroImagePtr(nTimes, channelCount);
   tfOutputter._imaginary = Image2D::CreateZeroImagePtr(nTimes, channelCount);
 
-  TimeFrequencyMetaDataPtr metaData(new TimeFrequencyMetaData());
+  const TimeFrequencyMetaDataPtr metaData(new TimeFrequencyMetaData());
   metaData->SetAntenna1(observatorium.GetAntenna(a1));
   metaData->SetAntenna2(observatorium.GetAntenna(a2));
   metaData->SetBand(observatorium.BandInfo());
@@ -67,7 +68,8 @@ Model::SimulateObservation(size_t nTimes, class Observatorium &observatorium,
          dz = metaData->Antenna1().position.z - metaData->Antenna2().position.z;
 
   for (size_t f = 0; f < channelCount; ++f) {
-    double channelFrequency = frequency + observatorium.ChannelWidthHz() * f;
+    const double channelFrequency =
+        frequency + observatorium.ChannelWidthHz() * f;
     tfOutputter.SetY(f);
     SimulateCorrelation(tfOutputter, delayDirectionDEC, delayDirectionRA, dx,
                         dy, dz, channelFrequency,
@@ -77,11 +79,11 @@ Model::SimulateObservation(size_t nTimes, class Observatorium &observatorium,
 
   std::vector<double> times;
   std::vector<UVW> uvws;
-  num_t wavelength = 1.0L / frequency;
+  const num_t wavelength = 1.0L / frequency;
   for (size_t i = 0; i != nTimes; ++i) {
-    double t = _integrationTime * i;
+    const double t = _integrationTime * i;
     times.push_back(t);
-    num_t earthLattitudeApprox = t * M_PIn / (12.0 * 60.0 * 60.0);
+    const num_t earthLattitudeApprox = t * M_PIn / (12.0 * 60.0 * 60.0);
     UVW uvw;
     GetUVPosition(uvw.u, uvw.v, earthLattitudeApprox, delayDirectionDEC,
                   delayDirectionRA, dx, dy, dz, wavelength);
@@ -102,23 +104,24 @@ Model::SimulateObservation(size_t nTimes, class Observatorium &observatorium,
   field.delayDirectionRA = delayDirectionRA;
   metaData->SetField(field);
 
-  TimeFrequencyData tfData(aocommon::Polarization::StokesI, tfOutputter._real,
-                           tfOutputter._imaginary);
+  const TimeFrequencyData tfData(aocommon::Polarization::StokesI,
+                                 tfOutputter._real, tfOutputter._imaginary);
   return std::pair<TimeFrequencyData, TimeFrequencyMetaDataPtr>(tfData,
                                                                 metaData);
 }
 
 template <typename T>
-void Model::SimulateCorrelation(struct OutputReceiver<T> &receiver,
+void Model::SimulateCorrelation(struct OutputReceiver<T>& receiver,
                                 num_t delayDirectionDEC, num_t delayDirectionRA,
                                 num_t dx, num_t dy, num_t dz, num_t frequency,
                                 num_t channelWidth, size_t nTimes,
                                 double integrationTime) {
-  double sampleGain = integrationTime / (12.0 * 60.0 * 60.0) * channelWidth;
-  num_t wavelength = 1.0L / frequency;
+  const double sampleGain =
+      integrationTime / (12.0 * 60.0 * 60.0) * channelWidth;
+  const num_t wavelength = 1.0L / frequency;
   size_t index = 0;
   for (size_t ti = 0; ti != nTimes; ++ti) {
-    double t = ti * integrationTime;
+    const double t = ti * integrationTime;
     const double timeInDays = t / (12.0 * 60.0 * 60.0);
     const num_t earthLattitudeApprox = timeInDays * M_PIn;
     num_t u, v, r1, i1, r2, i2;
@@ -135,24 +138,24 @@ void Model::SimulateCorrelation(struct OutputReceiver<T> &receiver,
 }
 
 template void Model::SimulateCorrelation(
-    struct OutputReceiver<UVImager> &receiver, num_t delayDirectionDEC,
+    struct OutputReceiver<UVImager>& receiver, num_t delayDirectionDEC,
     num_t delayDirectionRA, num_t dx, num_t dy, num_t dz, num_t frequency,
     num_t channelWidth, size_t nTimes, double integrationTime);
 
 void Model::SimulateAntenna(double time, num_t delayDirectionDEC,
                             num_t delayDirectionRA, num_t dx, num_t dy,
-                            num_t frequency, num_t earthLattitude, num_t &r,
-                            num_t &i) {
+                            num_t frequency, num_t earthLattitude, num_t& r,
+                            num_t& i) {
   r = 0.0;
   i = 0.0;
-  num_t delayW = GetWPosition(delayDirectionDEC, delayDirectionRA, frequency,
-                              earthLattitude, dx, dy);
-  for (std::vector<Source *>::const_iterator iter = _sources.begin();
+  const num_t delayW = GetWPosition(delayDirectionDEC, delayDirectionRA,
+                                    frequency, earthLattitude, dx, dy);
+  for (std::vector<Source*>::const_iterator iter = _sources.begin();
        iter != _sources.end(); ++iter) {
-    Source &source = **iter;
-    num_t w = GetWPosition(source.Dec(time), source.Ra(time), frequency,
-                           earthLattitude, dx, dy);
-    num_t fieldStrength =
+    const Source& source = **iter;
+    const num_t w = GetWPosition(source.Dec(time), source.Ra(time), frequency,
+                                 earthLattitude, dx, dy);
+    const num_t fieldStrength =
         source.SqrtFluxIntensity(time) + RNG::Gaussian() * _sourceSigma;
     num_t noiser, noisei;
     RNG::ComplexGaussianAmplitude(noiser, noisei);
@@ -166,10 +169,10 @@ void Model::SimulateAntenna(double time, num_t delayDirectionDEC,
 void Model::SimulateUncoherentAntenna(double time, num_t delayDirectionDEC,
                                       num_t delayDirectionRA, num_t dx,
                                       num_t dy, num_t frequency,
-                                      num_t earthLattitude, num_t &r, num_t &i,
+                                      num_t earthLattitude, num_t& r, num_t& i,
                                       size_t index) {
-  num_t delayW = GetWPosition(delayDirectionDEC, delayDirectionRA, frequency,
-                              earthLattitude, dx, dy);
+  const num_t delayW = GetWPosition(delayDirectionDEC, delayDirectionRA,
+                                    frequency, earthLattitude, dx, dy);
 
   // if(index%(_sources.size()+1) == _sources.size())
   //{
@@ -179,32 +182,32 @@ void Model::SimulateUncoherentAntenna(double time, num_t delayDirectionDEC,
   noisei *= _noiseSigma;
   //}
   // else {
-  Source &source = *_sources[index % _sources.size()];
-  num_t w = GetWPosition(source.Dec(time), source.Ra(time), frequency,
-                         earthLattitude, dx, dy);
-  num_t fieldStrength =
+  const Source& source = *_sources[index % _sources.size()];
+  const num_t w = GetWPosition(source.Dec(time), source.Ra(time), frequency,
+                               earthLattitude, dx, dy);
+  const num_t fieldStrength =
       source.SqrtFluxIntensity(time) + RNG::Gaussian() * _sourceSigma;
   r = fieldStrength * cosn((w - delayW) * M_PIn * 2.0) + noiser;
   i = fieldStrength * sinn((w - delayW) * M_PIn * 2.0) + noisei;
   //}
 }
 
-void Model::GetUVPosition(num_t &u, num_t &v, num_t earthLattitudeAngle,
+void Model::GetUVPosition(num_t& u, num_t& v, num_t earthLattitudeAngle,
                           num_t delayDirectionDEC, num_t delayDirectionRA,
                           num_t dx, num_t dy, num_t dz, num_t wavelength) {
   // Rotate baseline plane towards phase center, first rotate around z axis,
   // then around x axis
-  long double raRotation =
+  const long double raRotation =
       -earthLattitudeAngle + delayDirectionRA + M_PIn * 0.5L;
   long double tmpCos = cosn(raRotation);
   long double tmpSin = sinn(raRotation);
 
-  long double dxProjected = tmpCos * dx - tmpSin * dy;
-  long double tmpdy = tmpSin * dx + tmpCos * dy;
+  const long double dxProjected = tmpCos * dx - tmpSin * dy;
+  const long double tmpdy = tmpSin * dx + tmpCos * dy;
 
   tmpCos = cosn(-delayDirectionDEC);
   tmpSin = sinn(-delayDirectionDEC);
-  long double dyProjected = tmpCos * tmpdy - tmpSin * dz;
+  const long double dyProjected = tmpCos * tmpdy - tmpSin * dz;
 
   // Now, the newly projected positive z axis of the baseline points to the
   // phase center
@@ -212,9 +215,9 @@ void Model::GetUVPosition(num_t &u, num_t &v, num_t earthLattitudeAngle,
       sqrtn(dxProjected * dxProjected + dyProjected * dyProjected);
 
   long double baselineAngle;
-  if (baselineLength == 0.0)
+  if (baselineLength == 0.0) {
     baselineAngle = 0.0;
-  else {
+  } else {
     baselineLength /= 299792458.0L * wavelength;
     if (dxProjected > 0.0L)
       baselineAngle = atann(dyProjected / dxProjected);
@@ -229,7 +232,7 @@ void Model::GetUVPosition(num_t &u, num_t &v, num_t earthLattitudeAngle,
 void Model::loadUrsaMajor(double ra, double dec, double factor) {
   double s = 0.00005 * factor,  // scale
       rs = 6.0 + 2.0 * factor;  // stretch in dec
-  double fluxoffset = 0.0;
+  const double fluxoffset = 0.0;
 
   AddSource(dec + s * rs * 40, ra + s * 72, 8.0 / 8.0 + fluxoffset);   // Dubhe
   AddSource(dec + s * rs * -16, ra + s * 81, 4.0 / 8.0 + fluxoffset);  // Beta
@@ -252,10 +255,6 @@ void Model::loadUrsaMajorDistortingSource(double ra, double dec, double factor,
   AddSource(dec - 0.12800 * factor, ra + 0.015 + 0.015 * factor, 4.0);
 }
 
-void Model::loadOnAxisSource(double ra, double dec, double factor) {
-  AddSource(dec - 0.01280 * factor, ra + 0.0015 + 0.0015 * factor, 4.0);
-}
-
 void Model::loadUrsaMajorDistortingVariableSource(double ra, double dec,
                                                   double factor, bool weak,
                                                   bool slightlyMiss) {
