@@ -5,6 +5,8 @@
 
 #include "../algorithms/restorechannelrange.h"
 
+using algorithms::RestoreChannelRange;
+
 int Data::clear_mask(lua_State* L) {
   aoflagger_lua::Data* data = reinterpret_cast<aoflagger_lua::Data*>(
       luaL_checkudata(L, 1, "AOFlaggerData"));
@@ -15,21 +17,21 @@ int Data::clear_mask(lua_State* L) {
 int Data::convert_to_complex(lua_State* L) {
   aoflagger_lua::Data* data = reinterpret_cast<aoflagger_lua::Data*>(
       luaL_checkudata(L, 1, "AOFlaggerData"));
-  std::string reprStr = luaL_checklstring(L, 2, nullptr);
+  const std::string reprStr = luaL_checklstring(L, 2, nullptr);
   try {
     enum TimeFrequencyData::ComplexRepresentation complexRepresentation;
     // PhasePart, AmplitudePart, RealPart, ImaginaryPart, ComplexParts
-    if (reprStr == "phase")
+    if (reprStr == "phase") {
       complexRepresentation = TimeFrequencyData::PhasePart;
-    else if (reprStr == "amplitude")
+    } else if (reprStr == "amplitude") {
       complexRepresentation = TimeFrequencyData::AmplitudePart;
-    else if (reprStr == "real")
+    } else if (reprStr == "real") {
       complexRepresentation = TimeFrequencyData::RealPart;
-    else if (reprStr == "imaginary")
+    } else if (reprStr == "imaginary") {
       complexRepresentation = TimeFrequencyData::ImaginaryPart;
-    else if (reprStr == "complex")
+    } else if (reprStr == "complex") {
       complexRepresentation = TimeFrequencyData::ComplexParts;
-    else {
+    } else {
       return luaL_error(
           L,
           "Unknown complex representation specified in convert_to_complex(): "
@@ -47,9 +49,9 @@ int Data::convert_to_complex(lua_State* L) {
 int Data::convert_to_polarization(lua_State* L) {
   aoflagger_lua::Data* data = reinterpret_cast<aoflagger_lua::Data*>(
       luaL_checkudata(L, 1, "AOFlaggerData"));
-  std::string polStr = luaL_checklstring(L, 2, nullptr);
+  const std::string polStr = luaL_checklstring(L, 2, nullptr);
   try {
-    aocommon::PolarizationEnum polarization =
+    const aocommon::PolarizationEnum polarization =
         aocommon::Polarization::ParseString(polStr);
     Tools::NewData(L, data->TFData().Make(polarization), data->MetaData(),
                    data->GetContext());
@@ -70,8 +72,8 @@ int Data::copy(lua_State* L) {
 int Data::flag_zeros(lua_State* L) {
   aoflagger_lua::Data* data = reinterpret_cast<aoflagger_lua::Data*>(
       luaL_checkudata(L, 1, "AOFlaggerData"));
-  Mask2DPtr mask(new Mask2D(*data->TFData().GetSingleMask()));
-  Image2DCPtr image = data->TFData().GetSingleImage();
+  const Mask2DPtr mask(new Mask2D(*data->TFData().GetSingleMask()));
+  const Image2DCPtr image = data->TFData().GetSingleImage();
   for (unsigned y = 0; y < image->Height(); ++y) {
     for (unsigned x = 0; x < image->Width(); ++x) {
       if (image->Value(x, y) == 0.0) mask->SetValue(x, y, true);
@@ -89,7 +91,7 @@ int Data::flag_nans(lua_State* L) {
     TimeFrequencyData singlePol = newData.MakeFromPolarizationIndex(p);
     Mask2DPtr mask = Mask2D::MakePtr(*singlePol.GetSingleMask());
     for (size_t i = 0; i != singlePol.ImageCount(); ++i) {
-      Image2DCPtr image = singlePol.GetImage(i);
+      const Image2DCPtr image = singlePol.GetImage(i);
       for (unsigned y = 0; y < image->Height(); ++y) {
         for (unsigned x = 0; x < image->Width(); ++x) {
           if (!std::isfinite(image->Value(x, y))) mask->SetValue(x, y, true);
@@ -206,14 +208,19 @@ int Data::get_complex_state(lua_State* L) {
   switch (data->TFData().ComplexRepresentation()) {
     case TimeFrequencyData::PhasePart:
       lua_pushstring(L, "phase");
+      break;
     case TimeFrequencyData::AmplitudePart:
       lua_pushstring(L, "amplitude");
+      break;
     case TimeFrequencyData::RealPart:
       lua_pushstring(L, "real");
+      break;
     case TimeFrequencyData::ImaginaryPart:
       lua_pushstring(L, "imaginary");
+      break;
     case TimeFrequencyData::ComplexParts:
       lua_pushstring(L, "complex");
+      break;
   }
   return 1;
 }
@@ -244,7 +251,7 @@ int Data::get_polarizations(lua_State* L) {
       data->TFData().Polarizations();
   lua_createtable(L, pols.size(), 0);
   for (size_t i = 0; i != pols.size(); ++i) {
-    aocommon::PolarizationEnum p = pols[i];
+    const aocommon::PolarizationEnum p = pols[i];
     lua_pushstring(L, aocommon::Polarization::TypeToShortString(p).c_str());
     lua_rawseti(L, -2, i + 1);
   }
@@ -284,10 +291,21 @@ int Data::has_metadata(lua_State* L) {
   return 1;
 }
 
+int Data::invert_mask(lua_State* L) {
+  aoflagger_lua::Data* data = reinterpret_cast<aoflagger_lua::Data*>(
+      luaL_checkudata(L, 1, "AOFlaggerData"));
+  for (size_t i = 0; i != data->TFData().MaskCount(); ++i) {
+    Mask2DPtr mask = Mask2D::MakePtr(*data->TFData().GetMask(i));
+    mask->Invert();
+    data->TFData().SetMask(i, std::move(mask));
+  }
+  return 0;
+}
+
 int Data::is_auto_correlation(lua_State* L) {
   aoflagger_lua::Data* data = reinterpret_cast<aoflagger_lua::Data*>(
       luaL_checkudata(L, 1, "AOFlaggerData"));
-  bool isAuto =
+  const bool isAuto =
       data->MetaData() && data->MetaData()->HasAntenna1() &&
       data->MetaData()->HasAntenna2() &&
       data->MetaData()->Antenna1().id == data->MetaData()->Antenna2().id;
@@ -298,7 +316,7 @@ int Data::is_auto_correlation(lua_State* L) {
 int Data::is_complex(lua_State* L) {
   aoflagger_lua::Data* data = reinterpret_cast<aoflagger_lua::Data*>(
       luaL_checkudata(L, 1, "AOFlaggerData"));
-  bool isComplex =
+  const bool isComplex =
       data->TFData().ComplexRepresentation() == TimeFrequencyData::ComplexParts;
   lua_pushboolean(L, isComplex);
   return 1;
@@ -351,16 +369,51 @@ int Data::set_mask_for_channel_range(lua_State* L) {
   return 0;
 }
 
+int Data::set_masked_visibilities(lua_State* L) {
+  aoflagger_lua::Data* lhs = reinterpret_cast<aoflagger_lua::Data*>(
+      luaL_checkudata(L, 1, "AOFlaggerData"));
+  aoflagger_lua::Data* rhs = reinterpret_cast<aoflagger_lua::Data*>(
+      luaL_checkudata(L, 2, "AOFlaggerData"));
+  if (rhs->TFData().ImageCount() != lhs->TFData().ImageCount() ||
+      rhs->TFData().PolarizationCount() != lhs->TFData().PolarizationCount()) {
+    const std::string err =
+        "set_masked_visibilities() was executed with inconsistent data types: "
+        "right "
+        "hand side had " +
+        std::to_string(rhs->TFData().ImageCount()) + ", destination had " +
+        std::to_string(lhs->TFData().ImageCount());
+    return luaL_error(L, err.c_str());
+  }
+  for (size_t p = 0; p != rhs->TFData().PolarizationCount(); ++p) {
+    TimeFrequencyData lPolData = lhs->TFData().MakeFromPolarizationIndex(p);
+    const TimeFrequencyData rPolData =
+        rhs->TFData().MakeFromPolarizationIndex(p);
+    const Mask2DCPtr mask(lPolData.GetSingleMask());
+    for (size_t i = 0; i != rhs->TFData().ImageCount(); ++i) {
+      const Image2DCPtr source(rhs->TFData().GetImage(i));
+      Image2DPtr dest(Image2D::MakePtr(*lhs->TFData().GetImage(i)));
+      for (size_t y = 0; y != source->Height(); ++y) {
+        for (size_t x = 0; x != source->Width(); ++x) {
+          if (mask->Value(x, y)) dest->SetValue(x, y, source->Value(x, y));
+        }
+      }
+      lPolData.SetImage(i, std::move(dest));
+    }
+    lhs->TFData().SetPolarizationData(p, std::move(lPolData));
+  }
+  return 0;
+}
+
 int Data::set_polarization_data(lua_State* L) {
   aoflagger_lua::Data* lhs = reinterpret_cast<aoflagger_lua::Data*>(
       luaL_checkudata(L, 1, "AOFlaggerData"));
-  std::string polStr = luaL_checklstring(L, 2, nullptr);
+  const std::string polStr = luaL_checklstring(L, 2, nullptr);
   aoflagger_lua::Data* rhs = reinterpret_cast<aoflagger_lua::Data*>(
       luaL_checkudata(L, 3, "AOFlaggerData"));
   try {
-    aocommon::PolarizationEnum polarization =
+    const aocommon::PolarizationEnum polarization =
         aocommon::Polarization::ParseString(polStr);
-    size_t polIndex = lhs->TFData().GetPolarizationIndex(polarization);
+    const size_t polIndex = lhs->TFData().GetPolarizationIndex(polarization);
     lhs->TFData().SetPolarizationData(polIndex, rhs->TFData());
   } catch (std::exception& e) {
     return luaL_error(
@@ -375,7 +428,7 @@ int Data::set_visibilities(lua_State* L) {
   aoflagger_lua::Data* rhs = reinterpret_cast<aoflagger_lua::Data*>(
       luaL_checkudata(L, 2, "AOFlaggerData"));
   if (rhs->TFData().ImageCount() != lhs->TFData().ImageCount()) {
-    std::string err =
+    const std::string err =
         "set_visibilities() was executed with inconsistent data types: right "
         "hand side had " +
         std::to_string(rhs->TFData().ImageCount()) + ", destination had " +
@@ -404,3 +457,13 @@ int Data::sub(lua_State* L) {
                  lhs->MetaData(), lhs->GetContext());
   return 1;
 }
+
+int Data::div(lua_State* L) {
+  aoflagger_lua::Data* lhs = reinterpret_cast<aoflagger_lua::Data*>(
+      luaL_checkudata(L, 1, "AOFlaggerData"));
+  aoflagger_lua::Data* rhs = reinterpret_cast<aoflagger_lua::Data*>(
+      luaL_checkudata(L, 2, "AOFlaggerData"));
+  Tools::NewData(L, ElementWiseDivide(lhs->TFData(), rhs->TFData()),
+                 lhs->MetaData(), lhs->GetContext());
+  return 1;
+}
