@@ -7,6 +7,8 @@ extern "C" {
 #include <lauxlib.h>
 }
 
+#include <algorithm>
+
 class Data {
  public:
   static int clear_mask(lua_State* L);
@@ -27,14 +29,17 @@ class Data {
   static int get_polarizations(lua_State* L);
   static int get_times(lua_State* L);
   static int has_metadata(lua_State* L);
+  static int invert_mask(lua_State* L);
   static int is_auto_correlation(lua_State* L);
   static int is_complex(lua_State* L);
   static int join_mask(lua_State* L);
   static int set_mask(lua_State* L);
   static int set_mask_for_channel_range(lua_State* L);
+  static int set_masked_visibilities(lua_State* L);
   static int set_visibilities(lua_State* L);
   static int set_polarization_data(lua_State* L);
   static int gc(lua_State* L);
+  static int div(lua_State* L);
   static int sub(lua_State* L);
 
  private:
