@@ -25,8 +25,11 @@ Data downsample(const Data& data, size_t horizontalFactor,
 Data downsample_masked(const Data& data, size_t horizontalFactor,
                        size_t verticalFactor);
 
-void upsample(const Data& input, Data& destination, size_t horizontalFactor,
-              size_t verticalFactor);
+void upsample_image(const Data& input, Data& destination,
+                    size_t horizontalFactor, size_t verticalFactor);
+
+void upsample_mask(const Data& input, Data& destination,
+                   size_t horizontalFactor, size_t verticalFactor);
 
 void high_pass_filter(Data& data, size_t kernelWidth, size_t kernelHeight,
                       double horizontalSigmaSquared,
@@ -36,6 +39,8 @@ void low_pass_filter(Data& data, size_t kernelWidth, size_t kernelHeight,
                      double horizontalSigmaSquared,
                      double verticalSigmaSquared);
 
+Data norm(const Data& data);
+
 // TODO this function should collect the statistics and print
 // them later on (and be renamed).
 void print_polarization_statistics(const Data& data);
@@ -47,7 +52,10 @@ void scale_invariant_rank_operator(Data& data, double level_horizontal,
 
 void scale_invariant_rank_operator_masked(Data& data, const Data& missing,
                                           double level_horizontal,
-                                          double level_vertical);
+                                          double level_vertical,
+                                          double penalty);
+
+Data sqrt(const Data& data);
 
 void sumthreshold(Data& data, double hThresholdFactor, double vThresholdFactor,
                   bool horizontal, bool vertical);
