@@ -28,7 +28,7 @@ void LuaStrategy::check(lua_State* state, int error) {
   if (error) {
     const char* msg = lua_tostring(state, -1);
     if (msg) {
-      std::string str(msg);
+      const std::string str(msg);
       lua_pop(state, 1);  // pop error
       throw std::runtime_error(str);
     } else {
@@ -65,16 +65,19 @@ void LuaStrategy::loadaoflagger() {
       {"get_polarizations", Data::get_polarizations},
       {"get_times", Data::get_times},
       {"has_metadata", Data::has_metadata},
+      {"invert_mask", Data::invert_mask},
       {"is_auto_correlation", Data::is_auto_correlation},
       {"is_complex", Data::is_complex},
       {"join_mask", Data::join_mask},
       {"set_mask", Data::set_mask},
       {"set_mask_for_channel_range", Data::set_mask_for_channel_range},
+      {"set_masked_visibilities", Data::set_masked_visibilities},
       {"set_polarization_data", Data::set_polarization_data},
       {"set_visibilities", Data::set_visibilities},
+      {"__div", Data::div},
       {"__gc", Data::gc},
       {"__sub", Data::sub},
-      {NULL, NULL}};
+      {nullptr, nullptr}};
   luaL_setfuncs(_state, aofdatamembers, 0);
 
   // New table for package
@@ -88,6 +91,7 @@ void LuaStrategy::loadaoflagger() {
       {"downsample", Functions::downsample},
       {"high_pass_filter", Functions::high_pass_filter},
       {"low_pass_filter", Functions::low_pass_filter},
+      {"norm", Functions::norm},
       {"normalize_bandpass", Functions::normalize_bandpass},
       {"normalize_subbands", Functions::normalize_subbands},
       {"print_polarization_statistics",
@@ -101,15 +105,18 @@ void LuaStrategy::loadaoflagger() {
        Functions::scale_invariant_rank_operator_masked},
       {"set_progress", Functions::set_progress},
       {"set_progress_text", Functions::set_progress_text},
+      {"sqrt", Functions::sqrt},
       {"sumthreshold", Functions::sumthreshold},
       {"sumthreshold_masked", Functions::sumthreshold_masked},
       {"threshold_channel_rms", Functions::threshold_channel_rms},
       {"threshold_timestep_rms", Functions::threshold_timestep_rms},
       {"trim_channels", Functions::trim_channels},
       {"trim_frequencies", Functions::trim_frequencies},
-      {"upsample", Functions::upsample},
+      {"upsample", Functions::upsample_image},  // DEPRECATED
+      {"upsample_image", Functions::upsample_image},
+      {"upsample_mask", Functions::upsample_mask},
       {"visualize", Functions::visualize},
-      {NULL, NULL}};
+      {nullptr, nullptr}};
   luaL_setfuncs(_state, aoflib, 0);
 
   // Name the package (which pops the table)
