@@ -1,17 +1,17 @@
 #include "telescopefile.h"
 
+#include <dlfcn.h>
+#include <filesystem>
+
+#include <boost/algorithm/string/case_conv.hpp>
+
 #include "../imagesets/bhfitsimageset.h"
 #include "../imagesets/filterbankset.h"
 #include "../imagesets/fitsimageset.h"
 #include "../imagesets/imageset.h"
 #include "../imagesets/msimageset.h"
 
-#include "../../structures/msmetadata.h"
-
-#include <boost/algorithm/string/case_conv.hpp>
-
-#include <boost/filesystem/path.hpp>
-#include <boost/filesystem/operations.hpp>
+#include "../structures/msmetadata.h"
 
 #include <version.h>
 
@@ -85,6 +85,8 @@ TelescopeFile::TelescopeId TelescopeFile::TelescopeIdFromName(
     return APERTIF_TELESCOPE;
   else if (nameUpper == "ARECIBO" || nameUpper == "ARECIBO 305M")
     return ARECIBO_TELESCOPE;
+  else if (nameUpper == "ATCA")
+    return ATCA_TELESCOPE;
   else if (nameUpper == "BIGHORNS")
     return BIGHORNS_TELESCOPE;
   else if (nameUpper == "EVLA" || nameUpper == "JVLA")
@@ -104,8 +106,7 @@ TelescopeFile::TelescopeId TelescopeFile::TelescopeIdFromName(
     return GENERIC_TELESCOPE;
 }
 
-std::string TelescopeFile::FindStrategy(const std::string& argv0,
-                                        enum TelescopeId telescopeId,
+std::string TelescopeFile::FindStrategy(enum TelescopeId telescopeId,
                                         const std::string& scenario) {
   std::string filename = boost::to_lower_copy(TelescopeName(telescopeId));
   if (scenario.empty())
@@ -113,29 +114,29 @@ std::string TelescopeFile::FindStrategy(const std::string& argv0,
   else
     filename = filename + "-" + boost::to_lower_copy(scenario) + ".lua";
 
-  boost::filesystem::path search;
+  std::filesystem::path search;
 
-  search = boost::filesystem::path(AOFLAGGER_INSTALL_PATH) /
+  search = std::filesystem::path(AOFLAGGER_INSTALL_PATH) /
            "share/aoflagger/strategies" / filename;
-  if (boost::filesystem::exists(search)) return search.string();
+  if (std::filesystem::exists(search)) return search.string();
 
-  if (!argv0.empty()) {
-    boost::filesystem::path root = boost::filesystem::path(argv0).remove_leaf();
-
-    search = root / "../share/aoflagger/strategies" / filename;
-    if (boost::filesystem::exists(search)) return search.string();
-
-    search = root / "../data/strategies" / filename;
-    if (boost::filesystem::exists(search)) return search.string();
+  // Try using the directory of the AOFlagger library.
+  // When bundled as a python binary wheel, the strategies are there.
+  Dl_info dl_info;
+  if (dladdr(reinterpret_cast<const void*>(&TelescopeFile::FindStrategy),
+             &dl_info)) {
+    std::filesystem::path aoflagger_library_path(dl_info.dli_fname);
+    search = aoflagger_library_path.remove_filename() / "aoflagger/strategies" /
+             filename;
+    if (std::filesystem::exists(search)) return search.string();
   }
 
-  search =
-      boost::filesystem::path("/usr/share/aoflagger/strategies") / filename;
-  if (boost::filesystem::exists(search)) return search.string();
+  search = std::filesystem::path("/usr/share/aoflagger/strategies") / filename;
+  if (std::filesystem::exists(search)) return search.string();
 
-  search = boost::filesystem::path("/usr/local/share/aoflagger/strategies") /
-           filename;
-  if (boost::filesystem::exists(search)) return search.string();
+  search =
+      std::filesystem::path("/usr/local/share/aoflagger/strategies") / filename;
+  if (std::filesystem::exists(search)) return search.string();
 
   return std::string();
 }
