@@ -5,6 +5,7 @@
 #include "../structures/timefrequencydata.h"
 
 #include "../util/logger.h"
+#include "../util/progress/dummyprogresslistener.h"
 #include "../util/stopwatch.h"
 
 #include <casacore/tables/DataMan/TiledStManAccessor.h>
@@ -14,11 +15,9 @@
 #include <set>
 #include <stdexcept>
 
-DirectBaselineReader::DirectBaselineReader(const std::string &msFile)
+DirectBaselineReader::DirectBaselineReader(const std::string& msFile)
     : BaselineReader(msFile), _ms(OpenMS()) {}
 
-DirectBaselineReader::~DirectBaselineReader() { ShowStatistics(); }
-
 void DirectBaselineReader::initBaselineCache() {
   // Pass one time through the entire measurement set and store the rownumbers
   // of the baselines.
@@ -38,22 +37,24 @@ void DirectBaselineReader::initBaselineCache() {
         int antenna1 = antenna1Column(rowIndex),
             antenna2 = antenna2Column(rowIndex),
             dataDescId = dataDescIdColumn(rowIndex);
-        int spectralWindow = dataIdToSpw[dataDescId];
+        const int spectralWindow = dataIdToSpw[dataDescId];
         addRowToBaselineCache(antenna1, antenna2, spectralWindow, sequenceId,
                               rowIndex);
       });
 }
 
-void DirectBaselineReader::addRowToBaselineCache(int antenna1, int antenna2,
-                                                 int spectralWindow,
-                                                 int sequenceId, size_t row) {
+void DirectBaselineReader::addRowToBaselineCache(size_t antenna1,
+                                                 size_t antenna2,
+                                                 size_t spectralWindow,
+                                                 size_t sequenceId,
+                                                 size_t row) {
   BaselineCacheIndex searchItem;
   searchItem.antenna1 = antenna1;
   searchItem.antenna2 = antenna2;
   searchItem.spectralWindow = spectralWindow;
   searchItem.sequenceId = sequenceId;
-  std::map<BaselineCacheIndex, BaselineCacheValue>::iterator cacheItemIter =
-      _baselineCache.find(searchItem);
+  const std::map<BaselineCacheIndex, BaselineCacheValue>::iterator
+      cacheItemIter = _baselineCache.find(searchItem);
   if (cacheItemIter == _baselineCache.end()) {
     BaselineCacheValue cacheValue;
     cacheValue.rows.push_back(row);
@@ -65,44 +66,37 @@ void DirectBaselineReader::addRowToBaselineCache(int antenna1, int antenna2,
 
 void DirectBaselineReader::addRequestRows(
     ReadRequest request, size_t requestIndex,
-    std::vector<std::pair<size_t, size_t>> &rows) {
+    std::vector<std::pair<size_t, size_t>>& rows) {
   BaselineCacheIndex searchItem;
   searchItem.antenna1 = request.antenna1;
   searchItem.antenna2 = request.antenna2;
   searchItem.spectralWindow = request.spectralWindow;
   searchItem.sequenceId = request.sequenceId;
-  std::map<BaselineCacheIndex, BaselineCacheValue>::iterator cacheItemIter =
-      _baselineCache.find(searchItem);
+  auto cacheItemIter = _baselineCache.find(searchItem);
   if (cacheItemIter != _baselineCache.end()) {
-    const std::vector<size_t> &cacheRows = cacheItemIter->second.rows;
-    for (std::vector<size_t>::const_iterator j = cacheRows.begin();
-         j != cacheRows.end(); ++j)
-      rows.push_back(std::pair<size_t, size_t>(*j, requestIndex));
+    const std::vector<size_t>& cacheRows = cacheItemIter->second.rows;
+    for (const size_t j : cacheRows) rows.emplace_back(j, requestIndex);
   }
 }
 
 void DirectBaselineReader::addRequestRows(
     FlagWriteRequest request, size_t requestIndex,
-    std::vector<std::pair<size_t, size_t>> &rows) {
+    std::vector<std::pair<size_t, size_t>>& rows) {
   BaselineCacheIndex searchItem;
   searchItem.antenna1 = request.antenna1;
   searchItem.antenna2 = request.antenna2;
   searchItem.spectralWindow = request.spectralWindow;
   searchItem.sequenceId = request.sequenceId;
-  std::map<BaselineCacheIndex, BaselineCacheValue>::iterator cacheItemIter =
-      _baselineCache.find(searchItem);
+  auto cacheItemIter = _baselineCache.find(searchItem);
   if (cacheItemIter != _baselineCache.end()) {
-    const std::vector<size_t> &cacheRows = cacheItemIter->second.rows;
-    for (std::vector<size_t>::const_iterator j = cacheRows.begin();
-         j != cacheRows.end(); ++j)
-      rows.push_back(std::pair<size_t, size_t>(*j, requestIndex));
+    const std::vector<size_t>& cacheRows = cacheItemIter->second.rows;
+    for (const size_t j : cacheRows) rows.emplace_back(j, requestIndex);
   }
 }
 
-void DirectBaselineReader::PerformReadRequests(
-    class ProgressListener &progress) {
+void DirectBaselineReader::PerformReadRequests(ProgressListener& progress) {
   progress.OnStartTask("Reading measurement set");
-  Stopwatch stopwatch(true);
+  const Stopwatch stopwatch(true);
 
   initializeMeta();
   if (_baselineCache.empty()) initBaselineCache();
@@ -116,13 +110,13 @@ void DirectBaselineReader::PerformReadRequests(
 
   _results.resize(_readRequests.size());
   for (size_t reqIndex = 0; reqIndex != _readRequests.size(); ++reqIndex) {
-    const ReadRequest &request = _readRequests[reqIndex];
-    Result &result = _results[reqIndex];
+    const ReadRequest& request = _readRequests[reqIndex];
+    Result& result = _results[reqIndex];
     size_t startIndex = request.startIndex, endIndex = request.endIndex,
            band = request.spectralWindow,
            channelCount = MetaData().FrequencyCount(band);
 
-    size_t width = endIndex - startIndex;
+    const size_t width = endIndex - startIndex;
     for (size_t p = 0; p < Polarizations().size(); ++p) {
       if (ReadData()) {
         result._realImages.emplace_back(
@@ -141,48 +135,34 @@ void DirectBaselineReader::PerformReadRequests(
     result._uvw.resize(width);
   }
 
-  casacore::ScalarColumn<double> timeColumn(_ms, "TIME");
-  casacore::ArrayColumn<float> weightColumn(_ms, "WEIGHT");
-  casacore::ArrayColumn<double> uvwColumn(_ms, "UVW");
-  casacore::ArrayColumn<bool> flagColumn(_ms, "FLAG");
-  std::unique_ptr<casacore::ArrayColumn<casacore::Complex>> modelColumn,
-      dataColumn;
+  const casacore::ScalarColumn<double> timeColumn(_ms, "TIME");
+  const casacore::ArrayColumn<float> weightColumn(_ms, "WEIGHT");
+  const casacore::ArrayColumn<double> uvwColumn(_ms, "UVW");
+  const casacore::ArrayColumn<bool> flagColumn(_ms, "FLAG");
+  std::unique_ptr<casacore::ArrayColumn<casacore::Complex>> dataColumn;
 
   if (ReadData())
     dataColumn.reset(
         new casacore::ArrayColumn<casacore::Complex>(_ms, DataColumnName()));
 
-  if (SubtractModel())
-    modelColumn.reset(
-        new casacore::ArrayColumn<casacore::Complex>(_ms, "MODEL_DATA"));
-
   for (size_t i = 0; i != rows.size(); ++i) {
     progress.OnProgress(i, rows.size());
-    std::pair<size_t, size_t> p = rows[i];
-    size_t rowIndex = p.first;
-    size_t requestIndex = p.second;
+    const std::pair<size_t, size_t> p = rows[i];
+    const size_t rowIndex = p.first;
+    const size_t requestIndex = p.second;
 
-    double time = timeColumn(rowIndex);
-    const ReadRequest &request = _readRequests[requestIndex];
+    const double time = timeColumn(rowIndex);
+    const ReadRequest& request = _readRequests[requestIndex];
     size_t timeIndex = ObservationTimes(request.sequenceId).find(time)->second,
            startIndex = request.startIndex, endIndex = request.endIndex,
            band = request.spectralWindow;
-    bool timeIsSelected = timeIndex >= startIndex && timeIndex < endIndex;
+    const bool timeIsSelected = timeIndex >= startIndex && timeIndex < endIndex;
     if (ReadData() && timeIsSelected) {
       // if(BaselineReader::DataKind() == WeightData)
       //	readWeights(requestIndex, timeIndex-startIndex,
       // MetaData().FrequencyCount(band), weightColumn(rowIndex)); else
-      if (modelColumn == nullptr)
-        readTimeData(requestIndex, timeIndex - startIndex,
-                     MetaData().FrequencyCount(band), (*dataColumn)(rowIndex),
-                     0);
-      else {
-        const casacore::Array<casacore::Complex> model =
-            (*modelColumn)(rowIndex);
-        readTimeData(requestIndex, timeIndex - startIndex,
-                     MetaData().FrequencyCount(band), (*dataColumn)(rowIndex),
-                     &model);
-      }
+      readTimeData(requestIndex, timeIndex - startIndex,
+                   MetaData().FrequencyCount(band), (*dataColumn)(rowIndex));
     }
     if (ReadFlags() && timeIsSelected) {
       readTimeFlags(requestIndex, timeIndex - startIndex,
@@ -190,7 +170,7 @@ void DirectBaselineReader::PerformReadRequests(
     }
     if (timeIsSelected) {
       casacore::Array<double> arr = uvwColumn(rowIndex);
-      casacore::Array<double>::const_iterator i = arr.begin();
+      casacore::Array<double>::const_contiter i = arr.cbegin();
       _results[requestIndex]._uvw[timeIndex - startIndex].u = *i;
       ++i;
       _results[requestIndex]._uvw[timeIndex - startIndex].v = *i;
@@ -207,12 +187,12 @@ std::vector<UVW> DirectBaselineReader::ReadUVW(unsigned antenna1,
                                                unsigned antenna2,
                                                unsigned spectralWindow,
                                                unsigned sequenceId) {
-  Stopwatch stopwatch(true);
+  const Stopwatch stopwatch(true);
 
   initializeMeta();
   if (_baselineCache.empty()) initBaselineCache();
 
-  const std::map<double, size_t> &observationTimes =
+  const std::map<double, size_t>& observationTimes =
       ObservationTimes(sequenceId);
 
   // Each element contains (row number, corresponding request index)
@@ -227,24 +207,24 @@ std::vector<UVW> DirectBaselineReader::ReadUVW(unsigned antenna1,
   addRequestRows(request, 0, rows);
   std::sort(rows.begin(), rows.end());
 
-  size_t width = observationTimes.size();
+  const size_t width = observationTimes.size();
 
-  casacore::ScalarColumn<double> timeColumn(_ms, "TIME");
-  casacore::ArrayColumn<double> uvwColumn(_ms, "UVW");
+  const casacore::ScalarColumn<double> timeColumn(_ms, "TIME");
+  const casacore::ArrayColumn<double> uvwColumn(_ms, "UVW");
 
   std::vector<UVW> uvws;
   uvws.resize(width);
 
   for (std::vector<std::pair<size_t, size_t>>::const_iterator i = rows.begin();
        i != rows.end(); ++i) {
-    size_t rowIndex = i->first;
+    const size_t rowIndex = i->first;
 
-    double time = timeColumn(rowIndex);
-    size_t timeIndex = observationTimes.find(time)->second;
+    const double time = timeColumn(rowIndex);
+    const size_t timeIndex = observationTimes.find(time)->second;
 
     casacore::Array<double> arr = uvwColumn(rowIndex);
-    casacore::Array<double>::const_iterator j = arr.begin();
-    UVW &uvw = uvws[timeIndex];
+    casacore::Array<double>::const_contiter j = arr.cbegin();
+    UVW& uvw = uvws[timeIndex];
     uvw.u = *j;
     ++j;
     uvw.v = *j;
@@ -257,7 +237,7 @@ std::vector<UVW> DirectBaselineReader::ReadUVW(unsigned antenna1,
 }
 
 void DirectBaselineReader::PerformFlagWriteRequests() {
-  Stopwatch stopwatch(true);
+  const Stopwatch stopwatch(true);
 
   initializeMeta();
 
@@ -271,33 +251,32 @@ void DirectBaselineReader::PerformFlagWriteRequests() {
   std::sort(rows.begin(), rows.end());
 
   _ms.reopenRW();
-  casacore::ScalarColumn<double> timeColumn(_ms, "TIME");
+  const casacore::ScalarColumn<double> timeColumn(_ms, "TIME");
   casacore::ArrayColumn<bool> flagColumn(_ms, "FLAG");
 
-  for (std::vector<FlagWriteRequest>::iterator i = _writeRequests.begin();
-       i != _writeRequests.end(); ++i) {
-    size_t band = i->spectralWindow;
-    if (MetaData().FrequencyCount(band) != i->flags[0]->Height()) {
+  for (const FlagWriteRequest& request : _writeRequests) {
+    const size_t band = request.spectralWindow;
+    if (MetaData().FrequencyCount(band) != request.flags[0]->Height()) {
       std::cerr << "The frequency count in the measurement set ("
                 << MetaData().FrequencyCount(band)
-                << ") does not match the image!" << std::endl;
+                << ") does not match the image!\n";
     }
-    if (i->endIndex - i->startIndex != i->flags[0]->Width()) {
+    if (request.endIndex - request.startIndex != request.flags[0]->Width()) {
       std::cerr << "The number of time scans to write in the measurement set ("
-                << (i->endIndex - i->startIndex)
-                << ") does not match the image (" << i->flags[0]->Width()
-                << ") !" << std::endl;
+                << (request.endIndex - request.startIndex)
+                << ") does not match the image (" << request.flags[0]->Width()
+                << ") !\n";
     }
   }
 
   size_t rowsWritten = 0;
 
-  for (std::vector<std::pair<size_t, size_t>>::const_iterator i = rows.begin();
-       i != rows.end(); ++i) {
-    size_t rowIndex = i->first;
-    FlagWriteRequest &request = _writeRequests[i->second];
-    double time = timeColumn(rowIndex);
-    size_t timeIndex = ObservationTimes(request.sequenceId).find(time)->second;
+  for (const std::pair<size_t, size_t>& row : rows) {
+    const size_t rowIndex = row.first;
+    FlagWriteRequest& request = _writeRequests[row.second];
+    const double time = timeColumn(rowIndex);
+    const size_t timeIndex =
+        ObservationTimes(request.sequenceId).find(time)->second;
     if (timeIndex >= request.startIndex + request.leftBorder &&
         timeIndex < request.endIndex - request.rightBorder) {
       casacore::Array<bool> flag = flagColumn(rowIndex);
@@ -320,34 +299,21 @@ void DirectBaselineReader::PerformFlagWriteRequests() {
 }
 
 void DirectBaselineReader::readTimeData(
-    size_t requestIndex, size_t xOffset, int frequencyCount,
-    const casacore::Array<casacore::Complex> data,
-    const casacore::Array<casacore::Complex> *model) {
-  casacore::Array<casacore::Complex>::const_iterator i = data.begin();
-  casacore::Array<casacore::Complex>::const_iterator m;
-  if (DataKind() == ResidualData) m = model->begin();
+    size_t requestIndex, size_t xOffset, size_t frequencyCount,
+    const casacore::Array<casacore::Complex>& data) {
+  casacore::Array<casacore::Complex>::const_contiter i = data.cbegin();
 
-  size_t polarizationCount = Polarizations().size();
+  const size_t polarizationCount = Polarizations().size();
 
   for (size_t f = 0; f < (size_t)frequencyCount; ++f) {
     num_t rv, iv;
 
     for (size_t p = 0; p < polarizationCount; ++p) {
-      if (DataKind() == ResidualData) {
-        const casacore::Complex &iData = *i;
-        const casacore::Complex &iModel = *m;
-        ++i;
-        ++m;
+      const casacore::Complex& complex = *i;
+      ++i;
 
-        rv = iData.real() - iModel.real();
-        iv = iData.imag() - iModel.imag();
-      } else {
-        const casacore::Complex &complex = *i;
-        ++i;
-
-        rv = complex.real();
-        iv = complex.imag();
-      }
+      rv = complex.real();
+      iv = complex.imag();
       _results[requestIndex]._realImages[p]->SetValue(xOffset, f, rv);
       _results[requestIndex]._imaginaryImages[p]->SetValue(xOffset, f, iv);
     }
@@ -355,14 +321,14 @@ void DirectBaselineReader::readTimeData(
 }
 
 void DirectBaselineReader::readTimeFlags(size_t requestIndex, size_t xOffset,
-                                         int frequencyCount,
-                                         const casacore::Array<bool> flag) {
-  size_t polarizationCount = Polarizations().size();
+                                         size_t frequencyCount,
+                                         const casacore::Array<bool>& flag) {
+  const size_t polarizationCount = Polarizations().size();
 
   casacore::Array<bool>::const_iterator j = flag.begin();
   for (size_t f = 0; f < (size_t)frequencyCount; ++f) {
     for (size_t p = 0; p < polarizationCount; ++p) {
-      bool v = *j;
+      const bool v = *j;
       ++j;
       _results[requestIndex]._flags[p]->SetValue(xOffset, f, v);
     }
@@ -370,9 +336,9 @@ void DirectBaselineReader::readTimeFlags(size_t requestIndex, size_t xOffset,
 }
 
 void DirectBaselineReader::readWeights(size_t requestIndex, size_t xOffset,
-                                       int frequencyCount,
-                                       const casacore::Array<float> weight) {
-  size_t polarizationCount = Polarizations().size();
+                                       size_t frequencyCount,
+                                       const casacore::Array<float>& weight) {
+  const size_t polarizationCount = Polarizations().size();
 
   casacore::Array<float>::const_iterator j = weight.begin();
   std::vector<float> values(polarizationCount);
@@ -387,13 +353,3 @@ void DirectBaselineReader::readWeights(size_t requestIndex, size_t xOffset,
     }
   }
 }
-
-void DirectBaselineReader::ShowStatistics() {
-  try {
-    casacore::ROTiledStManAccessor accessor(_ms, "LofarStMan");
-    std::stringstream s;
-    accessor.showCacheStatistics(s);
-    Logger::Debug << s.str();
-  } catch (std::exception &e) {
-  }
-}
