@@ -2,32 +2,34 @@
 
 #include "msselection.h"
 
-#include "../structures/system.h"
-
 #include "../util/logger.h"
-#include "../util/progresslistener.h"
+#include "../util/progress/dummyprogresslistener.h"
 #include "../util/stopwatch.h"
 
+#include <aocommon/system.h>
+
 #include <casacore/ms/MeasurementSets/MeasurementSet.h>
 #include <casacore/tables/Tables/ArrayColumn.h>
 #include <casacore/tables/Tables/ScalarColumn.h>
 
 #include <vector>
 
-using namespace casacore;
-
-void MemoryBaselineReader::PerformReadRequests(ProgressListener& progress) {
+void MemoryBaselineReader::PrepareReadWrite(ProgressListener& progress) {
   if (!_isRead) {
     progress.OnStartTask("Reading measurement set into memory");
     readSet(progress);
     _isRead = true;
   }
+}
+
+void MemoryBaselineReader::PerformReadRequests(ProgressListener& progress) {
+  PrepareReadWrite(progress);
 
   for (size_t i = 0; i != _readRequests.size(); ++i) {
     const ReadRequest& request = _readRequests[i];
-    BaselineID id(request.antenna1, request.antenna2, request.spectralWindow,
-                  request.sequenceId);
-    std::map<BaselineID, std::unique_ptr<Result>>::const_iterator
+    const BaselineID id(request.antenna1, request.antenna2,
+                        request.spectralWindow, request.sequenceId);
+    const std::map<BaselineID, std::unique_ptr<Result>>::const_iterator
         requestedBaselineIter = _baselines.find(id);
     if (requestedBaselineIter == _baselines.end()) {
       std::ostringstream errorStr;
@@ -40,8 +42,9 @@ void MemoryBaselineReader::PerformReadRequests(ProgressListener& progress) {
                << request.spectralWindow
                << ", sequenceId=" << request.sequenceId << ")";
       throw std::runtime_error(errorStr.str());
-    } else
+    } else {
       _results.push_back(*requestedBaselineIter->second);
+    }
   }
 
   _readRequests.clear();
@@ -49,23 +52,24 @@ void MemoryBaselineReader::PerformReadRequests(ProgressListener& progress) {
 }
 
 void MemoryBaselineReader::readSet(ProgressListener& progress) {
-  Stopwatch watch(true);
+  const Stopwatch watch(true);
 
   initializeMeta();
 
-  casacore::MeasurementSet table(OpenMS());
+  const casacore::MeasurementSet table(OpenMS());
 
-  ScalarColumn<int> ant1Column(
-      table, casacore::MeasurementSet::columnName(MSMainEnums::ANTENNA1)),
-      ant2Column(table,
-                 casacore::MeasurementSet::columnName(MSMainEnums::ANTENNA2)),
+  casacore::ScalarColumn<int> ant1Column(
+      table,
+      casacore::MeasurementSet::columnName(casacore::MSMainEnums::ANTENNA1)),
+      ant2Column(table, casacore::MeasurementSet::columnName(
+                            casacore::MSMainEnums::ANTENNA2)),
       dataDescIdColumn(table, casacore::MeasurementSet::columnName(
-                                  MSMainEnums::DATA_DESC_ID));
-  ArrayColumn<casacore::Complex> dataColumn(table, DataColumnName());
-  ArrayColumn<bool> flagColumn(
-      table, casacore::MeasurementSet::columnName(MSMainEnums::FLAG));
-  ArrayColumn<double> uvwColumn(
-      table, casacore::MeasurementSet::columnName(MSMainEnums::UVW));
+                                  casacore::MSMainEnums::DATA_DESC_ID));
+  casacore::ArrayColumn<casacore::Complex> dataColumn(table, DataColumnName());
+  casacore::ArrayColumn<bool> flagColumn(
+      table, casacore::MeasurementSet::columnName(casacore::MSMainEnums::FLAG));
+  casacore::ArrayColumn<double> uvwColumn(
+      table, casacore::MeasurementSet::columnName(casacore::MSMainEnums::UVW));
 
   size_t antennaCount = MetaData().AntennaCount(),
          polarizationCount = Polarizations().size(),
@@ -94,10 +98,9 @@ void MemoryBaselineReader::readSet(ProgressListener& progress) {
       BaselineMatrix& matrix = baselineCube[s * bandCount + b];
       matrix.resize(antennaCount);
 
-      BandInfo band = MetaData().GetBandInfo(0);
       for (size_t a1 = 0; a1 != antennaCount; ++a1) {
         matrix[a1].resize(antennaCount);
-        for (size_t a2 = 0; a2 != antennaCount; ++a2) matrix[a1][a2] = 0;
+        for (size_t a2 = 0; a2 != antennaCount; ++a2) matrix[a1][a2] = nullptr;
       }
     }
   }
@@ -115,8 +118,8 @@ void MemoryBaselineReader::readSet(ProgressListener& progress) {
                           size_t timeIndexInSequence) {
     size_t ant1 = ant1Column(rowIndex);
     size_t ant2 = ant2Column(rowIndex);
-    size_t spw = dataDescIdToSpw[dataDescIdColumn(rowIndex)];
-    size_t spwFieldIndex = spw + sequenceId * bandCount;
+    const size_t spw = dataDescIdToSpw[dataDescIdColumn(rowIndex)];
+    const size_t spwFieldIndex = spw + sequenceId * bandCount;
     if (ant1 > ant2) std::swap(ant1, ant2);
     std::unique_ptr<Result>& result = baselineCube[spwFieldIndex][ant1][ant2];
     if (result == nullptr) {
@@ -138,8 +141,8 @@ void MemoryBaselineReader::readSet(ProgressListener& progress) {
     dataArray = dataColumn.get(rowIndex);
     flagArray = flagColumn.get(rowIndex);
 
-    Array<double> uvwArray = uvwColumn.get(rowIndex);
-    Array<double>::const_iterator uvwPtr = uvwArray.begin();
+    casacore::Array<double> uvwArray = uvwColumn.get(rowIndex);
+    casacore::Array<double>::const_contiter uvwPtr = uvwArray.cbegin();
     UVW uvw;
     uvw.u = *uvwPtr;
     ++uvwPtr;
@@ -149,8 +152,9 @@ void MemoryBaselineReader::readSet(ProgressListener& progress) {
     result->_uvw[timeIndexInSequence] = uvw;
 
     for (size_t p = 0; p != polarizationCount; ++p) {
-      Array<Complex>::const_contiter dataPtr = dataArray.cbegin();
-      Array<bool>::const_contiter flagPtr = flagArray.cbegin();
+      casacore::Array<casacore::Complex>::const_contiter dataPtr =
+          dataArray.cbegin();
+      casacore::Array<bool>::const_contiter flagPtr = flagArray.cbegin();
 
       Image2D& real = *result->_realImages[p];
       Image2D& imag = *result->_imaginaryImages[p];
@@ -165,7 +169,7 @@ void MemoryBaselineReader::readSet(ProgressListener& progress) {
         ++dataPtr;
         ++flagPtr;
       }
-      size_t frequencyCount = bandInfos[spw].channels.size();
+      const size_t frequencyCount = bandInfos[spw].channels.size();
       for (size_t ch = 0; ch != frequencyCount; ++ch) {
         *realOutPtr = dataPtr->real();
         *imagOutPtr = dataPtr->imag();
@@ -186,7 +190,7 @@ void MemoryBaselineReader::readSet(ProgressListener& progress) {
   // Move elements from matrix into the baseline map.
   for (size_t s = 0; s != sequenceCount; ++s) {
     for (size_t b = 0; b != bandCount; ++b) {
-      size_t fbIndex = s * bandCount + b;
+      const size_t fbIndex = s * bandCount + b;
       for (size_t a1 = 0; a1 != antennaCount; ++a1) {
         for (size_t a2 = a1; a2 != antennaCount; ++a2) {
           std::unique_ptr<Result>& result = baselineCube[fbIndex][a1][a2];
@@ -199,20 +203,16 @@ void MemoryBaselineReader::readSet(ProgressListener& progress) {
   }
   _areFlagsChanged = false;
 
-  Logger::Debug << "Reading toke " << watch.ToString() << ".\n";
+  Logger::Debug << "Reading took " << watch.ToString() << ".\n";
 }
 
 void MemoryBaselineReader::PerformFlagWriteRequests() {
-  if (!_isRead) {
-    DummyProgressListener dummy;
-    readSet(dummy);
-    _isRead = true;
-  }
+  PrepareReadWrite(dummy_progress_);
 
   for (size_t i = 0; i != _writeRequests.size(); ++i) {
     const FlagWriteRequest& request = _writeRequests[i];
-    BaselineID id(request.antenna1, request.antenna2, request.spectralWindow,
-                  request.sequenceId);
+    const BaselineID id(request.antenna1, request.antenna2,
+                        request.spectralWindow, request.sequenceId);
     std::unique_ptr<Result>& result = _baselines[id];
     if (result->_flags.size() != request.flags.size())
       throw std::runtime_error("Polarizations do not match");
@@ -224,17 +224,18 @@ void MemoryBaselineReader::PerformFlagWriteRequests() {
   _writeRequests.clear();
 }
 
-void MemoryBaselineReader::writeFlags() {
+void MemoryBaselineReader::WriteToMs() {
   casacore::MeasurementSet ms(OpenMS(true));
 
-  ScalarColumn<int> ant1Column(
-      ms, casacore::MeasurementSet::columnName(MSMainEnums::ANTENNA1)),
-      ant2Column(ms,
-                 casacore::MeasurementSet::columnName(MSMainEnums::ANTENNA2)),
-      dataDescIdColumn(
-          ms, casacore::MeasurementSet::columnName(MSMainEnums::DATA_DESC_ID));
-  ArrayColumn<bool> flagColumn(
-      ms, casacore::MeasurementSet::columnName(MSMainEnums::FLAG));
+  casacore::ScalarColumn<int> ant1Column(
+      ms,
+      casacore::MeasurementSet::columnName(casacore::MSMainEnums::ANTENNA1)),
+      ant2Column(ms, casacore::MeasurementSet::columnName(
+                         casacore::MSMainEnums::ANTENNA2)),
+      dataDescIdColumn(ms, casacore::MeasurementSet::columnName(
+                               casacore::MSMainEnums::DATA_DESC_ID));
+  casacore::ArrayColumn<bool> flagColumn(
+      ms, casacore::MeasurementSet::columnName(casacore::MSMainEnums::FLAG));
   std::vector<size_t> dataIdToSpw;
   MetaData().GetDataDescToBandVector(dataIdToSpw);
 
@@ -244,54 +245,52 @@ void MemoryBaselineReader::writeFlags() {
 
   DummyProgressListener dummy;
   MSSelection msSelection(ms, ObservationTimesPerSequence(), dummy);
-  msSelection.Process(
-      [&](size_t rowIndex, size_t sequenceId, size_t timeIndexInSequence) {
-        size_t ant1 = ant1Column(rowIndex);
-        size_t ant2 = ant2Column(rowIndex);
-        size_t spw = dataIdToSpw[dataDescIdColumn(rowIndex)];
-        if (ant1 > ant2) std::swap(ant1, ant2);
+  msSelection.Process([&](size_t rowIndex, size_t sequenceId,
+                          size_t timeIndexInSequence) {
+    size_t ant1 = ant1Column(rowIndex);
+    size_t ant2 = ant2Column(rowIndex);
+    const size_t spw = dataIdToSpw[dataDescIdColumn(rowIndex)];
+    if (ant1 > ant2) std::swap(ant1, ant2);
 
-        size_t frequencyCount = MetaData().FrequencyCount(spw);
-        IPosition flagShape = IPosition(2);
-        flagShape[0] = polarizationCount;
-        flagShape[1] = frequencyCount;
-        casacore::Array<bool> flagArray(flagShape);
+    const size_t frequencyCount = MetaData().FrequencyCount(spw);
+    casacore::IPosition flagShape = casacore::IPosition(2);
+    flagShape[0] = polarizationCount;
+    flagShape[1] = frequencyCount;
+    casacore::Array<bool> flagArray(flagShape);
 
-        BaselineID baselineID(ant1, ant2, spw, sequenceId);
-        std::map<BaselineID, std::unique_ptr<Result>>::iterator resultIter =
-            _baselines.find(baselineID);
-        std::unique_ptr<Result>& result = resultIter->second;
+    const BaselineID baselineID(ant1, ant2, spw, sequenceId);
+    const std::map<BaselineID, std::unique_ptr<Result>>::iterator resultIter =
+        _baselines.find(baselineID);
+    std::unique_ptr<Result>& result = resultIter->second;
 
-        Array<bool>::contiter flagPtr = flagArray.cbegin();
+    casacore::Array<bool>::contiter flagPtr = flagArray.cbegin();
 
-        std::vector<Mask2D*> masks(polarizationCount);
-        for (size_t p = 0; p != polarizationCount; ++p)
-          masks[p] = result->_flags[p].get();
+    std::vector<Mask2D*> masks(polarizationCount);
+    for (size_t p = 0; p != polarizationCount; ++p)
+      masks[p] = result->_flags[p].get();
 
-        for (size_t ch = 0; ch != frequencyCount; ++ch) {
-          for (size_t p = 0; p != polarizationCount; ++p) {
-            *flagPtr = masks[p]->Value(timeIndexInSequence, ch);
-            ++flagPtr;
-          }
-        }
+    for (size_t ch = 0; ch != frequencyCount; ++ch) {
+      for (size_t p = 0; p != polarizationCount; ++p) {
+        *flagPtr = masks[p]->Value(timeIndexInSequence, ch);
+        ++flagPtr;
+      }
+    }
 
-        flagColumn.put(rowIndex, flagArray);
-      });
+    flagColumn.put(rowIndex, flagArray);
+  });
 
   _areFlagsChanged = false;
 }
 
-bool MemoryBaselineReader::IsEnoughMemoryAvailable(
-    const std::string& filename) {
-  uint64_t size = MeasurementSetDataSize(filename);
-  uint64_t totalMem = System::TotalMemory();
+bool MemoryBaselineReader::IsEnoughMemoryAvailable(uint64_t size) {
+  const uint64_t totalMem = aocommon::system::TotalMemory();
 
   if (size * 2 >= totalMem) {
-    Logger::Warn << (size / 1000000) << " MB required, but "
-                 << (totalMem / 1000000)
-                 << " MB available.\n"
-                    "Because this is not at least twice as much, direct read "
-                    "mode (slower!) will be used.\n";
+    Logger::Warn
+        << (size / 1000000) << " MB required, but " << (totalMem / 1000000)
+        << " MB available.\n"
+           "Because this is not at least twice as much, the reordering "
+           "mode (slower!) will be used.\n";
     return false;
   } else {
     Logger::Debug << (size / 1000000) << " MB required, "
