@@ -1,7 +1,7 @@
 #include "legend.h"
 
-#include "plot2d.h"
-#include "plot2dpointset.h"
+#include "xyplot.h"
+#include "xypointset.h"
 
 Legend::Legend()
     : _sizeOfM(0.0),
@@ -14,7 +14,7 @@ Legend::Legend()
       _height(0.0) {}
 
 void Legend::Initialize(const Cairo::RefPtr<Cairo::Context>& cairo,
-                        const Plot2D& plot) {
+                        const XYPlot& plot) {
   _width = 0.0;
   _height = 0.0;
   _textAdvance = 0.0;
@@ -23,7 +23,7 @@ void Legend::Initialize(const Cairo::RefPtr<Cairo::Context>& cairo,
   cairo->get_text_extents("M", extents);
   _sizeOfM = extents.width;
   for (size_t i = 0; i != plot.PointSetCount(); ++i) {
-    const Plot2DPointSet& pointSet = plot.GetPointSet(i);
+    const XYPointSet& pointSet = plot.GetPointSet(i);
     const std::string& label = pointSet.Label();
     cairo->get_text_extents(label, extents);
     _width = std::max(_width, extents.width - extents.x_bearing);
@@ -37,7 +37,7 @@ void Legend::Initialize(const Cairo::RefPtr<Cairo::Context>& cairo,
 }
 
 void Legend::Draw(const Cairo::RefPtr<Cairo::Context>& cairo,
-                  const Plot2D& plot) const {
+                  const XYPlot& plot) const {
   cairo->rectangle(_x, _y, _width, _height);
   cairo->set_source_rgb(0.0, 0.0, 0.0);
   cairo->stroke_preserve();
@@ -49,25 +49,25 @@ void Legend::Draw(const Cairo::RefPtr<Cairo::Context>& cairo,
   cairo->set_font_size(14);
   cairo->set_line_width(2);
   for (size_t i = 0; i != plot.PointSetCount(); ++i) {
-    const Plot2DPointSet& pointSet = plot.GetPointSet(i);
+    const XYPointSet& pointSet = plot.GetPointSet(i);
     const std::string& label = pointSet.Label();
     cairo->set_source_rgb(0.0, 0.0, 0.0);
     cairo->move_to(textLeft, curY);
     cairo->show_text(label);
     auto color = pointSet.GetColor();
     cairo->set_source_rgba(color.r, color.g, color.b, color.a);
-    switch (pointSet.DrawingStyle()) {
-      case Plot2DPointSet::DrawColumns:
+    switch (pointSet.GetDrawingStyle()) {
+      case XYPointSet::DrawColumns:
         cairo->rectangle(symbolLeft + 0.1 * _sizeOfM, curY - _textAdvance * 0.9,
                          0.9 * _sizeOfM, 0.9 * _sizeOfM);
         cairo->fill();
         break;
-      case Plot2DPointSet::DrawLines:
+      case XYPointSet::DrawLines:
         cairo->move_to(symbolLeft, curY - _textAdvance * 0.5);
         cairo->rel_line_to(_sizeOfM, 0.0);
         cairo->stroke();
         break;
-      case Plot2DPointSet::DrawPoints:
+      case XYPointSet::DrawPoints:
         cairo->move_to(symbolLeft + 2.0 + _sizeOfM * 0.5,
                        curY - _textAdvance - 0.5);
         cairo->arc(symbolLeft + _sizeOfM * 0.5, curY - _textAdvance * 0.5, 2.0,
