@@ -5,12 +5,12 @@
 #include <set>
 #include <vector>
 
-#include "plot2d.h"
+#include "xyplot.h"
 
 class PlotManager {
  public:
   ~PlotManager() { clear(); }
-  Plot2D &NewPlot2D(const std::string &plotTitle) {
+  XYPlot& NewPlot2D(const std::string& plotTitle) {
     std::string title = plotTitle;
     if (_plotTitles.find(title) != _plotTitles.end()) {
       char addChar = 'B';
@@ -23,7 +23,7 @@ class PlotManager {
       if (addChar > 'Z') tryTitle = title + " (..)";
       title = tryTitle;
     }
-    std::unique_ptr<Plot2D> plot(new Plot2D());
+    std::unique_ptr<XYPlot> plot(new XYPlot());
     plot->SetTitle(title);
     _plotTitles.insert(title);
     _items.push_back(std::move(plot));
@@ -32,9 +32,9 @@ class PlotManager {
 
   void Update() { _onUpdate(); }
 
-  std::function<void()> &OnUpdate() { return _onUpdate; }
+  std::function<void()>& OnUpdate() { return _onUpdate; }
 
-  const std::vector<std::unique_ptr<Plot2D>> &Items() const { return _items; }
+  const std::vector<std::unique_ptr<XYPlot>>& Items() const { return _items; }
 
   void Clear() {
     clear();
@@ -43,7 +43,7 @@ class PlotManager {
 
  private:
   void clear() { _items.clear(); }
-  std::vector<std::unique_ptr<Plot2D>> _items;
+  std::vector<std::unique_ptr<XYPlot>> _items;
   std::set<std::string> _plotTitles;
 
   std::function<void()> _onUpdate;
