@@ -2,8 +2,9 @@
 #define HISTOGRAM_TABLES_FORMATTER_H
 
 #include <casacore/ms/MeasurementSets/MeasurementSet.h>
-#include <casacore/tables/Tables/TableRecord.h>
 
+#include <cassert>
+#include <memory>
 #include <vector>
 
 class HistogramTablesFormatter {
@@ -18,23 +19,17 @@ class HistogramTablesFormatter {
 
   enum HistogramType { TotalHistogram, RFIHistogram };
 
-  explicit HistogramTablesFormatter(const std::string &measurementSetName)
-      : _measurementSet(0),
+  explicit HistogramTablesFormatter(const std::string& measurementSetName)
+      : _measurementSet(nullptr),
         _measurementSetName(measurementSetName),
-        _typeTable(0),
-        _countTable(0) {}
+        _typeTable(nullptr),
+        _countTable(nullptr) {}
 
   ~HistogramTablesFormatter() { Close(); }
 
   void Close() {
-    if (_countTable != 0) {
-      delete _countTable;
-      _countTable = 0;
-    }
-    if (_typeTable != 0) {
-      delete _typeTable;
-      _typeTable = 0;
-    }
+    _countTable.reset();
+    _typeTable.reset();
     closeMainTable();
   }
 
@@ -78,38 +73,19 @@ class HistogramTablesFormatter {
     return hasOneEntry(typeIndex);
   }
 
-  void InitializeEmptyTables() {
-    if (TableExists(HistogramCountTable))
-      removeEntries(HistogramCountTable);
-    else
-      createCountTable();
+  void InitializeEmptyTables();
 
-    if (TableExists(HistogramTypeTable))
-      removeEntries(HistogramTypeTable);
-    else
-      createTypeTable();
-  }
-
-  void RemoveTable(enum TableKind table) {
-    if (TableExists(table)) {
-      Close();
-      openMainTable(true);
-      if (_measurementSet->keywordSet().isDefined(TableName(table)))
-        _measurementSet->rwKeywordSet().removeField(TableName(table));
-      if (_measurementSet->isReadable(TableFilename(table)))
-        casacore::Table::deleteTable(TableFilename(table));
-    }
-  }
+  void RemoveTable(enum TableKind table);
 
   void StoreValue(unsigned typeIndex, double binStart, double binEnd,
                   double count);
 
   void QueryHistogram(unsigned typeIndex,
-                      std::vector<HistogramItem> &histogram);
+                      std::vector<HistogramItem>& histogram);
 
   unsigned QueryTypeIndex(enum HistogramType type, unsigned polarizationIndex);
   bool QueryTypeIndex(enum HistogramType type, unsigned polarizationIndex,
-                      unsigned &destTypeIndex);
+                      unsigned& destTypeIndex);
   unsigned StoreOrQueryTypeIndex(enum HistogramType type,
                                  unsigned polarizationIndex) {
     unsigned typeIndex;
@@ -128,32 +104,32 @@ class HistogramTablesFormatter {
   }
 
  private:
-  HistogramTablesFormatter(const HistogramTablesFormatter &) =
+  HistogramTablesFormatter(const HistogramTablesFormatter&) =
       delete;  // don't allow copies
-  void operator=(const HistogramTablesFormatter &) =
+  void operator=(const HistogramTablesFormatter&) =
       delete;  // don't allow assignment
 
-  const static std::string ColumnNameType;
-  const static std::string ColumnNameName;
-  const static std::string ColumnNamePolarization;
+  static const std::string ColumnNameType;
+  static const std::string ColumnNameName;
+  static const std::string ColumnNamePolarization;
 
-  const static std::string ColumnNameBinStart;
-  const static std::string ColumnNameBinEnd;
-  const static std::string ColumnNameCount;
+  static const std::string ColumnNameBinStart;
+  static const std::string ColumnNameBinEnd;
+  static const std::string ColumnNameCount;
 
-  casacore::Table *_measurementSet;
+  std::unique_ptr<casacore::Table> _measurementSet;
   const std::string _measurementSetName;
 
-  casacore::Table *_typeTable;
-  casacore::Table *_countTable;
+  std::unique_ptr<casacore::Table> _typeTable;
+  std::unique_ptr<casacore::Table> _countTable;
 
   bool hasOneEntry(unsigned typeIndex);
   void removeTypeEntry(enum HistogramType type, unsigned polarizationIndex);
   void removeEntries(enum TableKind table);
 
-  void addTimeColumn(casacore::TableDesc &tableDesc);
-  void addFrequencyColumn(casacore::TableDesc &tableDesc);
-  void addValueColumn(casacore::TableDesc &tableDesc);
+  void addTimeColumn(casacore::TableDesc& tableDesc);
+  void addFrequencyColumn(casacore::TableDesc& tableDesc);
+  void addValueColumn(casacore::TableDesc& tableDesc);
 
   void createTable(enum TableKind table) {
     switch (table) {
@@ -170,25 +146,21 @@ class HistogramTablesFormatter {
 
   void createTypeTable();
   void createCountTable();
-  unsigned findFreeTypeIndex(casacore::Table &typeTable);
+  unsigned findFreeTypeIndex(casacore::Table& typeTable);
 
   void openMainTable(bool needWrite);
-  void closeMainTable() {
-    if (_measurementSet != 0) {
-      delete _measurementSet;
-      _measurementSet = 0;
-    }
-  }
+  void closeMainTable() { _measurementSet.reset(); }
 
-  void openTable(TableKind table, bool needWrite, casacore::Table **tablePtr);
+  void openTable(TableKind table, bool needWrite,
+                 std::unique_ptr<casacore::Table>& tablePtr);
   void openTypeTable(bool needWrite) {
-    openTable(HistogramTypeTable, needWrite, &_typeTable);
+    openTable(HistogramTypeTable, needWrite, _typeTable);
   }
   void openCountTable(bool needWrite) {
-    openTable(HistogramCountTable, needWrite, &_countTable);
+    openTable(HistogramCountTable, needWrite, _countTable);
   }
-  casacore::Table &getTable(TableKind table, bool needWrite) {
-    casacore::Table **tablePtr = 0;
+  casacore::Table& getTable(TableKind table, bool needWrite) {
+    std::unique_ptr<casacore::Table>* tablePtr = nullptr;
     switch (table) {
       case HistogramTypeTable:
         tablePtr = &_typeTable;
@@ -197,7 +169,8 @@ class HistogramTablesFormatter {
         tablePtr = &_countTable;
         break;
     }
-    openTable(table, needWrite, tablePtr);
+    assert(tablePtr);
+    openTable(table, needWrite, *tablePtr);
     return **tablePtr;
   }
 };
