@@ -8,6 +8,7 @@
 #include <casacore/tables/Tables/ArrColDesc.h>
 #include <casacore/tables/Tables/ScaColDesc.h>
 #include <casacore/tables/Tables/SetupNewTab.h>
+#include <casacore/tables/Tables/TableRecord.h>
 
 #include <casacore/measures/TableMeasures/TableMeasDesc.h>
 
@@ -73,7 +74,7 @@ const std::string QualityTablesFormatter::ColumnNameTime = "TIME";
 const std::string QualityTablesFormatter::ColumnNameValue = "VALUE";
 
 enum QualityTablesFormatter::StatisticKind QualityTablesFormatter::NameToKind(
-    const std::string &kindName) {
+    const std::string& kindName) {
   for (unsigned i = 0; i < 37; ++i) {
     if (kindName == _kindToNameTable[i])
       return (QualityTablesFormatter::StatisticKind)i;
@@ -90,11 +91,12 @@ unsigned QualityTablesFormatter::QueryKindIndex(enum StatisticKind kind) {
 }
 
 bool QualityTablesFormatter::QueryKindIndex(enum StatisticKind kind,
-                                            unsigned &destKindIndex) {
+                                            unsigned& destKindIndex) {
   openKindNameTable(false);
-  casacore::ROScalarColumn<int> kindColumn(*_kindNameTable, ColumnNameKind);
-  casacore::ROScalarColumn<casacore::String> nameColumn(*_kindNameTable,
-                                                        ColumnNameName);
+  const casacore::ROScalarColumn<int> kindColumn(*_kindNameTable,
+                                                 ColumnNameKind);
+  const casacore::ROScalarColumn<casacore::String> nameColumn(*_kindNameTable,
+                                                              ColumnNameName);
   const casacore::String nameToFind(KindToName(kind));
 
   const unsigned nrRow = _kindNameTable->nrow();
@@ -108,10 +110,51 @@ bool QualityTablesFormatter::QueryKindIndex(enum StatisticKind kind,
   return false;
 }
 
+bool QualityTablesFormatter::IsStatisticAvailable(
+    enum StatisticDimension dimension, enum StatisticKind kind) {
+  const QualityTable table = DimensionToTable(dimension);
+  if (!TableExists(KindNameTable) || !TableExists(table)) return false;
+  unsigned kindIndex;
+  if (!QueryKindIndex(kind, kindIndex)) return false;
+  return hasOneEntry(table, kindIndex);
+}
+
+void QualityTablesFormatter::InitializeEmptyStatistic(
+    enum StatisticDimension dimension, enum StatisticKind kind,
+    unsigned polarizationCount) {
+  if (!TableExists(KindNameTable)) createKindNameTable();
+
+  const QualityTable table = DimensionToTable(dimension);
+  if (!TableExists(table)) {
+    InitializeEmptyTable(table, polarizationCount);
+  } else {
+    removeStatisticFromStatTable(table, kind);
+  }
+}
+
+void QualityTablesFormatter::InitializeEmptyTable(enum QualityTable table,
+                                                  unsigned polarizationCount) {
+  if (TableExists(table))
+    removeEntries(table);
+  else
+    createTable(table, polarizationCount);
+}
+
+void QualityTablesFormatter::RemoveTable(enum QualityTable table) {
+  if (TableExists(table)) {
+    Close();
+    openMainTable(true);
+    if (_measurementSet->keywordSet().isDefined(TableToName(table)))
+      _measurementSet->rwKeywordSet().removeField(TableToName(table));
+    if (_measurementSet->isReadable(TableToFilename(table)))
+      casacore::Table::deleteTable(TableToFilename(table));
+  }
+}
+
 bool QualityTablesFormatter::hasOneEntry(enum QualityTable table,
                                          unsigned kindIndex) {
-  casacore::Table &casaTable = getTable(table, false);
-  casacore::ROScalarColumn<int> kindColumn(casaTable, ColumnNameKind);
+  const casacore::Table& casaTable = getTable(table, false);
+  const casacore::ROScalarColumn<int> kindColumn(casaTable, ColumnNameKind);
 
   const unsigned nrRow = casaTable.nrow();
 
@@ -141,7 +184,7 @@ void QualityTablesFormatter::createKindNameTable() {
 
   casacore::SetupNewTable newTableSetup(TableToFilename(KindNameTable),
                                         tableDesc, casacore::Table::New);
-  casacore::Table newTable(newTableSetup);
+  const casacore::Table newTable(newTableSetup);
   openMainTable(true);
   _measurementSet->rwKeywordSet().defineTable(TableToName(KindNameTable),
                                               newTable);
@@ -152,13 +195,13 @@ void QualityTablesFormatter::createKindNameTable() {
  * It holds "Measure"s of time, which is what casacore defines as a value
  * including a unit and a reference frame.
  */
-void QualityTablesFormatter::addTimeColumn(casacore::TableDesc &tableDesc) {
-  casacore::ScalarColumnDesc<double> timeDesc(ColumnNameTime,
-                                              "Central time of statistic");
+void QualityTablesFormatter::addTimeColumn(casacore::TableDesc& tableDesc) {
+  const casacore::ScalarColumnDesc<double> timeDesc(
+      ColumnNameTime, "Central time of statistic");
   tableDesc.addColumn(timeDesc);
 
-  casacore::TableMeasRefDesc measRef(casacore::MEpoch::UTC);
-  casacore::TableMeasValueDesc measVal(tableDesc, ColumnNameTime);
+  const casacore::TableMeasRefDesc measRef(casacore::MEpoch::UTC);
+  const casacore::TableMeasValueDesc measVal(tableDesc, ColumnNameTime);
   casacore::TableMeasDesc<casacore::MEpoch> mepochCol(measVal, measRef);
   mepochCol.write(tableDesc);
 }
@@ -169,12 +212,12 @@ void QualityTablesFormatter::addTimeColumn(casacore::TableDesc &tableDesc) {
  * a value including a unit (Hertz).
  */
 void QualityTablesFormatter::addFrequencyColumn(
-    casacore::TableDesc &tableDesc) {
-  casacore::ScalarColumnDesc<double> freqDesc(
+    casacore::TableDesc& tableDesc) {
+  const casacore::ScalarColumnDesc<double> freqDesc(
       ColumnNameFrequency, "Central frequency of statistic bin");
   tableDesc.addColumn(freqDesc);
 
-  casacore::Unit hertzUnit("Hz");
+  const casacore::Unit hertzUnit("Hz");
 
   casacore::TableQuantumDesc quantDesc(tableDesc, ColumnNameFrequency,
                                        hertzUnit);
@@ -185,11 +228,11 @@ void QualityTablesFormatter::addFrequencyColumn(
  * Add value column to the table descriptor. Used by create..Table() methods.
  * It consist of an array of statistics, each element holds a polarization.
  */
-void QualityTablesFormatter::addValueColumn(casacore::TableDesc &tableDesc,
+void QualityTablesFormatter::addValueColumn(casacore::TableDesc& tableDesc,
                                             unsigned polarizationCount) {
   casacore::IPosition shape(1);
   shape[0] = polarizationCount;
-  casacore::ArrayColumnDesc<casacore::Complex> valDesc(
+  const casacore::ArrayColumnDesc<casacore::Complex> valDesc(
       ColumnNameValue, "Value of statistic", shape,
       casacore::ColumnDesc::Direct);
   tableDesc.addColumn(valDesc);
@@ -217,7 +260,7 @@ void QualityTablesFormatter::createTimeStatisticTable(
 
   casacore::SetupNewTable newTableSetup(TableToFilename(TimeStatisticTable),
                                         tableDesc, casacore::Table::New);
-  casacore::Table newTable(newTableSetup);
+  const casacore::Table newTable(newTableSetup);
   openMainTable(true);
   _measurementSet->rwKeywordSet().defineTable(TableToName(TimeStatisticTable),
                                               newTable);
@@ -245,7 +288,7 @@ void QualityTablesFormatter::createFrequencyStatisticTable(
   casacore::SetupNewTable newTableSetup(
       TableToFilename(FrequencyStatisticTable), tableDesc,
       casacore::Table::New);
-  casacore::Table newTable(newTableSetup);
+  const casacore::Table newTable(newTableSetup);
   openMainTable(true);
   _measurementSet->rwKeywordSet().defineTable(
       TableToName(FrequencyStatisticTable), newTable);
@@ -276,7 +319,7 @@ void QualityTablesFormatter::createBaselineStatisticTable(
 
   casacore::SetupNewTable newTableSetup(TableToFilename(BaselineStatisticTable),
                                         tableDesc, casacore::Table::New);
-  casacore::Table newTable(newTableSetup);
+  const casacore::Table newTable(newTableSetup);
   openMainTable(true);
   _measurementSet->rwKeywordSet().defineTable(
       TableToName(BaselineStatisticTable), newTable);
@@ -302,22 +345,22 @@ void QualityTablesFormatter::createBaselineTimeStatisticTable(
   casacore::SetupNewTable newTableSetup(
       TableToFilename(BaselineTimeStatisticTable), tableDesc,
       casacore::Table::New);
-  casacore::Table newTable(newTableSetup);
+  const casacore::Table newTable(newTableSetup);
   openMainTable(true);
   _measurementSet->rwKeywordSet().defineTable(
       TableToName(BaselineTimeStatisticTable), newTable);
 }
 
-unsigned QualityTablesFormatter::StoreKindName(const std::string &name) {
+unsigned QualityTablesFormatter::StoreKindName(const std::string& name) {
   // This should be done atomically, but two quality writers in the same table
   // would be a weird thing to do anyway, plus I don't know how the casa tables
   // can be made atomic (and still have good performance).
 
   openKindNameTable(true);
 
-  unsigned kindIndex = findFreeKindIndex(*_kindNameTable);
+  const unsigned kindIndex = findFreeKindIndex(*_kindNameTable);
 
-  unsigned newRow = _kindNameTable->nrow();
+  const unsigned newRow = _kindNameTable->nrow();
   _kindNameTable->addRow();
   casacore::ScalarColumn<int> kindColumn(*_kindNameTable, ColumnNameKind);
   casacore::ScalarColumn<casacore::String> nameColumn(*_kindNameTable,
@@ -327,10 +370,10 @@ unsigned QualityTablesFormatter::StoreKindName(const std::string &name) {
   return kindIndex;
 }
 
-unsigned QualityTablesFormatter::findFreeKindIndex(casacore::Table &kindTable) {
+unsigned QualityTablesFormatter::findFreeKindIndex(casacore::Table& kindTable) {
   int maxIndex = 0;
 
-  casacore::ROScalarColumn<int> kindColumn(kindTable, ColumnNameKind);
+  const casacore::ROScalarColumn<int> kindColumn(kindTable, ColumnNameKind);
 
   const unsigned nrRow = kindTable.nrow();
 
@@ -342,7 +385,7 @@ unsigned QualityTablesFormatter::findFreeKindIndex(casacore::Table &kindTable) {
 
 void QualityTablesFormatter::openTable(
     QualityTable table, bool needWrite,
-    std::unique_ptr<casacore::Table> &tablePtr) {
+    std::unique_ptr<casacore::Table>& tablePtr) {
   if (tablePtr == nullptr) {
     openMainTable(false);
     tablePtr.reset(new casacore::Table(
@@ -354,10 +397,10 @@ void QualityTablesFormatter::openTable(
 }
 
 void QualityTablesFormatter::StoreTimeValue(double time, double frequency,
-                                            const StatisticalValue &value) {
+                                            const StatisticalValue& value) {
   openTimeTable(true);
 
-  unsigned newRow = _timeTable->nrow();
+  const unsigned newRow = _timeTable->nrow();
   _timeTable->addRow();
 
   // TODO maybe the columns need to be cached to avoid having to look them up
@@ -379,10 +422,10 @@ void QualityTablesFormatter::StoreTimeValue(double time, double frequency,
 }
 
 void QualityTablesFormatter::StoreFrequencyValue(
-    double frequency, const StatisticalValue &value) {
+    double frequency, const StatisticalValue& value) {
   openFrequencyTable(true);
 
-  unsigned newRow = _frequencyTable->nrow();
+  const unsigned newRow = _frequencyTable->nrow();
   _frequencyTable->addRow();
 
   casacore::ScalarColumn<double> frequencyColumn(*_frequencyTable,
@@ -402,10 +445,10 @@ void QualityTablesFormatter::StoreFrequencyValue(
 void QualityTablesFormatter::StoreBaselineValue(unsigned antenna1,
                                                 unsigned antenna2,
                                                 double frequency,
-                                                const StatisticalValue &value) {
+                                                const StatisticalValue& value) {
   openBaselineTable(true);
 
-  unsigned newRow = _baselineTable->nrow();
+  const unsigned newRow = _baselineTable->nrow();
   _baselineTable->addRow();
 
   casacore::ScalarColumn<int> antenna1Column(*_baselineTable,
@@ -430,10 +473,10 @@ void QualityTablesFormatter::StoreBaselineValue(unsigned antenna1,
 
 void QualityTablesFormatter::StoreBaselineTimeValue(
     unsigned antenna1, unsigned antenna2, double time, double frequency,
-    const StatisticalValue &value) {
+    const StatisticalValue& value) {
   openBaselineTimeTable(true);
 
-  unsigned newRow = _baselineTimeTable->nrow();
+  const unsigned newRow = _baselineTimeTable->nrow();
   _baselineTimeTable->addRow();
 
   casacore::ScalarColumn<double> timeColumn(*_baselineTimeTable,
@@ -463,8 +506,8 @@ void QualityTablesFormatter::removeStatisticFromStatTable(
     enum QualityTable qualityTable, enum StatisticKind kind) {
   unsigned kindIndex;
   if (QueryKindIndex(kind, kindIndex)) {
-    casacore::Table &table = getTable(qualityTable, true);
-    casacore::ScalarColumn<int> kindColumn(table, ColumnNameKind);
+    casacore::Table& table = getTable(qualityTable, true);
+    const casacore::ScalarColumn<int> kindColumn(table, ColumnNameKind);
 
     unsigned nrRow = table.nrow();
 
@@ -479,8 +522,8 @@ void QualityTablesFormatter::removeStatisticFromStatTable(
 
 void QualityTablesFormatter::removeKindNameEntry(enum StatisticKind kind) {
   openKindNameTable(true);
-  casacore::ScalarColumn<casacore::String> nameColumn(*_kindNameTable,
-                                                      ColumnNameName);
+  const casacore::ScalarColumn<casacore::String> nameColumn(*_kindNameTable,
+                                                            ColumnNameName);
 
   const unsigned nrRow = _kindNameTable->nrow();
   const casacore::String kindName(KindToName(kind));
@@ -494,7 +537,7 @@ void QualityTablesFormatter::removeKindNameEntry(enum StatisticKind kind) {
 }
 
 void QualityTablesFormatter::removeEntries(enum QualityTable table) {
-  casacore::Table &casaTable = getTable(table, true);
+  casacore::Table& casaTable = getTable(table, true);
   const unsigned nrRow = casaTable.nrow();
   for (int i = nrRow - 1; i >= 0; --i) {
     casaTable.removeRow(i);
@@ -503,8 +546,9 @@ void QualityTablesFormatter::removeEntries(enum QualityTable table) {
 
 unsigned QualityTablesFormatter::QueryStatisticEntryCount(
     enum StatisticDimension dimension, unsigned kindIndex) {
-  casacore::Table &casaTable(getTable(DimensionToTable(dimension), false));
-  casacore::ROScalarColumn<int> kindColumn(casaTable, ColumnNameKind);
+  const casacore::Table& casaTable(
+      getTable(DimensionToTable(dimension), false));
+  const casacore::ROScalarColumn<int> kindColumn(casaTable, ColumnNameKind);
 
   const unsigned nrRow = casaTable.nrow();
   size_t count = 0;
@@ -516,25 +560,26 @@ unsigned QualityTablesFormatter::QueryStatisticEntryCount(
 }
 
 unsigned QualityTablesFormatter::GetPolarizationCount() {
-  casacore::Table &table(getTable(TimeStatisticTable, false));
-  casacore::ROArrayColumn<casacore::Complex> valueColumn(table,
-                                                         ColumnNameValue);
+  const casacore::Table& table(getTable(TimeStatisticTable, false));
+  const casacore::ROArrayColumn<casacore::Complex> valueColumn(table,
+                                                               ColumnNameValue);
   return valueColumn.columnDesc().shape()[0];
 }
 
 void QualityTablesFormatter::QueryTimeStatistic(
     unsigned kindIndex,
-    std::vector<std::pair<TimePosition, StatisticalValue> > &entries) {
-  casacore::Table &table(getTable(TimeStatisticTable, false));
+    std::vector<std::pair<TimePosition, StatisticalValue>>& entries) {
+  const casacore::Table& table(getTable(TimeStatisticTable, false));
   const unsigned nrRow = table.nrow();
 
-  casacore::ROScalarColumn<double> timeColumn(table, ColumnNameTime);
-  casacore::ROScalarColumn<double> frequencyColumn(table, ColumnNameFrequency);
-  casacore::ROScalarColumn<int> kindColumn(table, ColumnNameKind);
-  casacore::ROArrayColumn<casacore::Complex> valueColumn(table,
-                                                         ColumnNameValue);
+  const casacore::ROScalarColumn<double> timeColumn(table, ColumnNameTime);
+  const casacore::ROScalarColumn<double> frequencyColumn(table,
+                                                         ColumnNameFrequency);
+  const casacore::ROScalarColumn<int> kindColumn(table, ColumnNameKind);
+  const casacore::ROArrayColumn<casacore::Complex> valueColumn(table,
+                                                               ColumnNameValue);
 
-  int polarizationCount = valueColumn.columnDesc().shape()[0];
+  const int polarizationCount = valueColumn.columnDesc().shape()[0];
 
   for (unsigned i = 0; i < nrRow; ++i) {
     if (kindColumn(i) == (int)kindIndex) {
@@ -557,16 +602,17 @@ void QualityTablesFormatter::QueryTimeStatistic(
 
 void QualityTablesFormatter::QueryFrequencyStatistic(
     unsigned kindIndex,
-    std::vector<std::pair<FrequencyPosition, StatisticalValue> > &entries) {
-  casacore::Table &table(getTable(FrequencyStatisticTable, false));
+    std::vector<std::pair<FrequencyPosition, StatisticalValue>>& entries) {
+  const casacore::Table& table(getTable(FrequencyStatisticTable, false));
   const unsigned nrRow = table.nrow();
 
-  casacore::ROScalarColumn<double> frequencyColumn(table, ColumnNameFrequency);
-  casacore::ROScalarColumn<int> kindColumn(table, ColumnNameKind);
-  casacore::ROArrayColumn<casacore::Complex> valueColumn(table,
-                                                         ColumnNameValue);
+  const casacore::ROScalarColumn<double> frequencyColumn(table,
+                                                         ColumnNameFrequency);
+  const casacore::ROScalarColumn<int> kindColumn(table, ColumnNameKind);
+  const casacore::ROArrayColumn<casacore::Complex> valueColumn(table,
+                                                               ColumnNameValue);
 
-  int polarizationCount = valueColumn.columnDesc().shape()[0];
+  const int polarizationCount = valueColumn.columnDesc().shape()[0];
 
   for (unsigned i = 0; i < nrRow; ++i) {
     if (kindColumn(i) == (int)kindIndex) {
@@ -588,18 +634,19 @@ void QualityTablesFormatter::QueryFrequencyStatistic(
 
 void QualityTablesFormatter::QueryBaselineStatistic(
     unsigned kindIndex,
-    std::vector<std::pair<BaselinePosition, StatisticalValue> > &entries) {
-  casacore::Table &table(getTable(BaselineStatisticTable, false));
+    std::vector<std::pair<BaselinePosition, StatisticalValue>>& entries) {
+  const casacore::Table& table(getTable(BaselineStatisticTable, false));
   const unsigned nrRow = table.nrow();
 
-  casacore::ROScalarColumn<int> antenna1Column(table, ColumnNameAntenna1);
-  casacore::ROScalarColumn<int> antenna2Column(table, ColumnNameAntenna2);
-  casacore::ROScalarColumn<double> frequencyColumn(table, ColumnNameFrequency);
-  casacore::ROScalarColumn<int> kindColumn(table, ColumnNameKind);
-  casacore::ROArrayColumn<casacore::Complex> valueColumn(table,
-                                                         ColumnNameValue);
+  const casacore::ROScalarColumn<int> antenna1Column(table, ColumnNameAntenna1);
+  const casacore::ROScalarColumn<int> antenna2Column(table, ColumnNameAntenna2);
+  const casacore::ROScalarColumn<double> frequencyColumn(table,
+                                                         ColumnNameFrequency);
+  const casacore::ROScalarColumn<int> kindColumn(table, ColumnNameKind);
+  const casacore::ROArrayColumn<casacore::Complex> valueColumn(table,
+                                                               ColumnNameValue);
 
-  int polarizationCount = valueColumn.columnDesc().shape()[0];
+  const int polarizationCount = valueColumn.columnDesc().shape()[0];
 
   for (unsigned i = 0; i < nrRow; ++i) {
     if (kindColumn(i) == (int)kindIndex) {
