@@ -1,6 +1,8 @@
 #include "imagecomparisoncontroller.h"
 
-using namespace aocommon;
+#include "../plotimage.h"
+
+using aocommon::Polarization;
 
 ImageComparisonController::ImageComparisonController()
     : _showPP(true),
@@ -19,12 +21,11 @@ TimeFrequencyData ImageComparisonController::GetActiveDataFullSize() const {
 
 TimeFrequencyData ImageComparisonController::GetActiveData() const {
   TimeFrequencyData data(GetActiveDataFullSize());
-  if (_plot.StartHorizontal() != 0.0 || _plot.EndHorizontal() != 1.0 ||
-      _plot.StartVertical() != 0.0 || _plot.EndVertical() != 1.0) {
-    data.Trim(round(_plot.StartHorizontal() * data.ImageWidth()),
-              round(_plot.StartVertical() * data.ImageHeight()),
-              round(_plot.EndHorizontal() * data.ImageWidth()),
-              round(_plot.EndVertical() * data.ImageHeight()));
+  if (!_plot.IsZoomedOut()) {
+    data.Trim(round(_plot.XZoomStart() * data.ImageWidth()),
+              round(_plot.YZoomStart() * data.ImageHeight()),
+              round(_plot.XZoomEnd() * data.ImageWidth()),
+              round(_plot.YZoomEnd() * data.ImageHeight()));
   }
   return data;
 }
@@ -166,11 +167,11 @@ void ImageComparisonController::TryVisualizePolarizations(bool& pp, bool& pq,
 
 Mask2DCPtr ImageComparisonController::getSelectedPolarizationMask(
     const TimeFrequencyData& data) const {
-  if (data.MaskCount() == 0)
+  if (data.MaskCount() == 0) {
     return Mask2DCPtr();
-  else if (data.MaskCount() == 1)
+  } else if (data.MaskCount() == 1) {
     return data.GetSingleMask();
-  else {
+  } else {
     if (data.MaskCount() == 4) {
       if (_showPP && _showQQ) {
         Mask2DPtr mask = Mask2D::MakePtr(*data.GetMask(0));
@@ -180,24 +181,25 @@ Mask2DCPtr ImageComparisonController::getSelectedPolarizationMask(
         Mask2DPtr mask = Mask2D::MakePtr(*data.GetMask(1));
         mask->Join(*data.GetMask(2));
         return mask;
-      } else if (_showPP)
+      } else if (_showPP) {
         return data.GetMask(0);
-      else if (_showPQ)
+      } else if (_showPQ) {
         return data.GetMask(1);
-      else if (_showQP)
+      } else if (_showQP) {
         return data.GetMask(2);
-      else  // if(_showQQ)
+      } else {  // if(_showQQ)
         return data.GetMask(3);
-    } else  // data->MaskCount() == 2
-    {
+      }
+    } else {  // data->MaskCount() == 2
       if (_showPP && _showQQ) {
         Mask2DPtr mask = Mask2D::MakePtr(*data.GetMask(0));
         mask->Join(*data.GetMask(1));
         return mask;
-      } else if (_showPP)
+      } else if (_showPP) {
         return data.GetMask(0);
-      else  // if(_showQQ)
+      } else {  // if(_showQQ)
         return data.GetMask(1);
+      }
     }
   }
 }
@@ -267,7 +269,7 @@ void ImageComparisonController::updateVisualizedImage() {
   if (image == nullptr)
     _plot.Clear();
   else
-    _plot.SetImage(image);
+    _plot.SetImage(std::unique_ptr<PlotImage>(new PlotImage(std::move(image))));
 }
 
 void ImageComparisonController::ClearAllButOriginal() {
