@@ -11,7 +11,7 @@
 #include "../../structures/timefrequencymetadata.h"
 #include "../../structures/segmentedimage.h"
 
-#include "../../plot/heatmapplot.h"
+#include "../maskedheatmap.h"
 
 class ImageComparisonController {
  public:
@@ -53,15 +53,16 @@ class ImageComparisonController {
    */
   TimeFrequencyData AltMaskData() const {
     if (_visualizedImage == 0) {
-      if (_dataList.size() > 1)
+      if (_dataList.size() > 1) {
         return _dataList.back().data;
-      else {
+      } else {
         TimeFrequencyData empty = _dataList.back().data;
         empty.SetNoMask();
         return empty;
       }
-    } else
+    } else {
       return _dataList[_visualizedImage].data;
+    }
   }
 
   size_t AddVisualization(const std::string& label,
@@ -127,8 +128,8 @@ class ImageComparisonController {
 
   void ClearAllButOriginal();
 
-  HeatMapPlot& Plot() { return _plot; }
-  const HeatMapPlot& Plot() const { return _plot; }
+  MaskedHeatMap& Plot() { return _plot; }
+  const MaskedHeatMap& Plot() const { return _plot; }
 
   sigc::signal<void>& VisualizationListChange() {
     return _visualizationListChange;
@@ -150,14 +151,15 @@ class ImageComparisonController {
     if (orActive && altActive) {
       data.SetMask(_dataList[0].data);
       data.JoinMask(_dataList[altMaskIndex].data);
-    } else if (orActive)
+    } else if (orActive) {
       data.SetMask(_dataList[0].data);
-    else if (altActive)
+    } else if (altActive) {
       data.SetMask(_dataList[altMaskIndex].data);
-    else
+    } else {
       data.SetMasksToValue<false>();
+    }
   }
-  HeatMapPlot _plot;
+  MaskedHeatMap _plot;
   bool _showPP, _showPQ, _showQP, _showQQ;
   size_t _visualizedImage;
   struct DataEntry {
