@@ -1,15 +1,16 @@
 #include "rfiguicontroller.h"
 
-#include "../../algorithms/fringestoppingfitter.h"
 #include "../../algorithms/svdmitigater.h"
 #include "../../algorithms/testsetgenerator.h"
 
 #include "../../python/pythonstrategy.h"
 
+#include "../../imagesets/h5imageset.h"
 #include "../../imagesets/imageset.h"
+#include "../../imagesets/joinedspwset.h"
 #include "../../imagesets/msimageset.h"
 #include "../../imagesets/msoptions.h"
-#include "../../imagesets/joinedspwset.h"
+#include "../../imagesets/multibandmsimageset.h"
 
 #include "../../lua/luastrategy.h"
 #include "../../lua/scriptdata.h"
@@ -24,17 +25,28 @@
 #include "../../structures/spatialmatrixmetadata.h"
 
 #include "../../util/multiplot.h"
-#include "../../util/progresslistener.h"
+#include "../../util/progress/progresslistener.h"
 #include "../../util/process.h"
 #include "../../util/rfiplots.h"
 
 #include "../rfiguiwindow.h"
 
+#include "../../external/npy.hpp"
+
 #include "imagecomparisoncontroller.h"
 
+#include <aocommon/system.h>
+
 #include <gtkmm/messagedialog.h>
 
-#include <boost/filesystem/operations.hpp>
+#include <algorithm>
+#include <array>
+#include <filesystem>
+#include <system_error>
+#include <thread>
+
+using algorithms::SVDMitigater;
+using algorithms::TestSetGenerator;
 
 RFIGuiController::RFIGuiController()
     : _showOriginalFlags(true),
@@ -77,13 +89,13 @@ TimeFrequencyMetaDataCPtr RFIGuiController::SelectedMetaData() const {
 
 void RFIGuiController::plotMeanSpectrum(bool weight) {
   if (IsImageLoaded()) {
-    std::string title = weight ? "Sum spectrum" : "Mean spectrum";
-    Plot2D& plot = _plotManager->NewPlot2D(title);
+    const std::string title = weight ? "Sum spectrum" : "Mean spectrum";
+    XYPlot& plot = _plotManager->NewPlot2D(title);
 
-    TimeFrequencyData data = ActiveData();
+    const TimeFrequencyData data = ActiveData();
     Mask2DCPtr mask =
         Mask2D::CreateSetMaskPtr<false>(data.ImageWidth(), data.ImageHeight());
-    Plot2DPointSet& beforeSet = plot.StartLine("Without flagging");
+    XYPointSet& beforeSet = plot.StartLine("Without flagging");
     if (weight)
       RFIPlots::MakeMeanSpectrumPlot<true>(beforeSet, data, mask,
                                            SelectedMetaData());
@@ -93,7 +105,7 @@ void RFIGuiController::plotMeanSpectrum(bool weight) {
 
     mask.reset(new Mask2D(*data.GetSingleMask()));
     if (!mask->AllFalse()) {
-      Plot2DPointSet& afterSet = plot.StartLine("Flagged");
+      XYPointSet& afterSet = plot.StartLine("Flagged");
       if (weight)
         RFIPlots::MakeMeanSpectrumPlot<true>(afterSet, data, mask,
                                              SelectedMetaData());
@@ -108,21 +120,21 @@ void RFIGuiController::plotMeanSpectrum(bool weight) {
 
 void RFIGuiController::PlotDist() {
   if (IsImageLoaded()) {
-    Plot2D& plot = _plotManager->NewPlot2D("Distribution");
+    XYPlot& plot = _plotManager->NewPlot2D("Distribution");
 
-    TimeFrequencyData activeData = ActiveData();
-    Image2DCPtr image = activeData.GetSingleImage();
+    const TimeFrequencyData activeData = ActiveData();
+    const Image2DCPtr image = activeData.GetSingleImage();
     Mask2DPtr mask =
         Mask2D::CreateSetMaskPtr<false>(image->Width(), image->Height());
-    Plot2DPointSet& totalSet = plot.StartLine("Total");
+    XYPointSet& totalSet = plot.StartLine("Total");
     RFIPlots::MakeDistPlot(totalSet, image, mask);
 
-    Plot2DPointSet& uncontaminatedSet = plot.StartLine("Uncontaminated");
+    XYPointSet& uncontaminatedSet = plot.StartLine("Uncontaminated");
     mask.reset(new Mask2D(*activeData.GetSingleMask()));
     RFIPlots::MakeDistPlot(uncontaminatedSet, image, mask);
 
     mask->Invert();
-    Plot2DPointSet& rfiSet = plot.StartLine("RFI");
+    XYPointSet& rfiSet = plot.StartLine("RFI");
     RFIPlots::MakeDistPlot(rfiSet, image, mask);
 
     _plotManager->Update();
@@ -131,12 +143,12 @@ void RFIGuiController::PlotDist() {
 
 void RFIGuiController::PlotLogLogDist() {
   if (IsImageLoaded()) {
-    TimeFrequencyData activeData = ActiveData();
+    const TimeFrequencyData activeData = ActiveData();
     HistogramCollection histograms(activeData.PolarizationCount());
     for (unsigned p = 0; p != activeData.PolarizationCount(); ++p) {
-      TimeFrequencyData polData(activeData.MakeFromPolarizationIndex(p));
-      Image2DCPtr image = polData.GetSingleImage();
-      Mask2DCPtr mask = Mask2D::MakePtr(*polData.GetSingleMask());
+      const TimeFrequencyData polData(activeData.MakeFromPolarizationIndex(p));
+      const Image2DCPtr image = polData.GetSingleImage();
+      const Mask2DCPtr mask = Mask2D::MakePtr(*polData.GetSingleMask());
       histograms.Add(0, 1, p, image, mask);
     }
     _rfiGuiWindow->ShowHistogram(histograms);
@@ -145,26 +157,26 @@ void RFIGuiController::PlotLogLogDist() {
 
 void RFIGuiController::PlotPowerSpectrum() {
   if (IsImageLoaded()) {
-    Plot2D& plot = _plotManager->NewPlot2D("Power spectrum");
-    plot.SetLogarithmicYAxis(true);
+    XYPlot& plot = _plotManager->NewPlot2D("Power spectrum");
+    plot.YAxis().SetLogarithmic(true);
 
-    TimeFrequencyData data = ActiveData();
+    const TimeFrequencyData data = ActiveData();
     std::array<Image2DCPtr, 2> images;
-    if (data.ComplexRepresentation() == TimeFrequencyData::ComplexParts)
+    if (data.ComplexRepresentation() == TimeFrequencyData::ComplexParts) {
       images = data.GetSingleComplexImage();
-    else {
+    } else {
       images[0] = data.GetSingleImage();
       images[1] = images[0];
     }
     Mask2DPtr mask = Mask2D::CreateSetMaskPtr<false>(images[0]->Width(),
                                                      images[0]->Height());
-    Plot2DPointSet& beforeSet = plot.StartLine("Flags not applied");
+    XYPointSet& beforeSet = plot.StartLine("Flags not applied");
     RFIPlots::MakePowerSpectrumPlot(beforeSet, *images[0], *images[1], *mask,
                                     SelectedMetaData().get());
 
     mask = Mask2D::MakePtr(*data.GetSingleMask());
     if (!mask->AllFalse()) {
-      Plot2DPointSet& afterSet = plot.StartLine("Flags applied");
+      XYPointSet& afterSet = plot.StartLine("Flags applied");
       RFIPlots::MakePowerSpectrumPlot(afterSet, *images[0], *images[1], *mask,
                                       SelectedMetaData().get());
     }
@@ -182,20 +194,21 @@ void RFIGuiController::PlotFrequencyScatter() {
   }
 }
 
-void RFIGuiController::DrawTimeMean(Plot2D& plot) {
+void RFIGuiController::DrawTimeMean(XYPlot& plot) {
   plot.SetTitle("Mean over time");
-  plot.SetLogarithmicYAxis(true);
+  plot.YAxis().SetLogarithmic(true);
+  plot.XAxis().SetType(AxisType::kTime);
 
-  TimeFrequencyData activeData = ActiveData();
-  Image2DCPtr image = activeData.GetSingleImage();
+  const TimeFrequencyData activeData = ActiveData();
+  const Image2DCPtr image = activeData.GetSingleImage();
   Mask2DPtr mask =
       Mask2D::CreateSetMaskPtr<false>(image->Width(), image->Height());
-  Plot2DPointSet& totalPlot = plot.StartLine("Without flagging");
+  XYPointSet& totalPlot = plot.StartLine("Without flagging");
   RFIPlots::MakePowerTimePlot(totalPlot, image, mask, SelectedMetaData());
 
   mask = Mask2D::MakePtr(*activeData.GetSingleMask());
   if (!mask->AllFalse()) {
-    Plot2DPointSet& uncontaminatedPlot = plot.StartLine("With flagging");
+    XYPointSet& uncontaminatedPlot = plot.StartLine("With flagging");
     RFIPlots::MakePowerTimePlot(uncontaminatedPlot, image, mask,
                                 SelectedMetaData());
   }
@@ -203,7 +216,7 @@ void RFIGuiController::DrawTimeMean(Plot2D& plot) {
 
 void RFIGuiController::PlotTimeMean() {
   if (IsImageLoaded()) {
-    Plot2D& plot = _plotManager->NewPlot2D("Mean over time");
+    XYPlot& plot = _plotManager->NewPlot2D("Mean over time");
     DrawTimeMean(plot);
     _plotManager->Update();
   }
@@ -220,14 +233,14 @@ void RFIGuiController::PlotTimeScatter() {
 
 void RFIGuiController::PlotSingularValues() {
   if (IsImageLoaded()) {
-    Plot2D& plot = _plotManager->NewPlot2D("Singular values");
+    XYPlot& plot = _plotManager->NewPlot2D("Singular values");
 
     SVDMitigater::CreateSingularValueGraph(ActiveData(), plot);
     _plotManager->Update();
   }
 }
 
-void RFIGuiController::open(std::unique_ptr<rfiStrategy::ImageSet> imageSet) {
+void RFIGuiController::open(std::unique_ptr<imagesets::ImageSet> imageSet) {
   std::vector<std::string> filenames = imageSet->Files();
   if (filenames.size() == 1)
     Logger::Info << "Opened " << filenames[0] << '\n';
@@ -244,22 +257,47 @@ void RFIGuiController::Open(const std::vector<std::string>& filenames) {
   MSOptions options;
   options.ioMode = DirectReadMode;
   options.baselineIntegration.enable = false;
-  std::unique_ptr<rfiStrategy::ImageSet> imageSet(
-      rfiStrategy::ImageSet::Create(filenames, options));
+  std::unique_ptr<imagesets::ImageSet> imageSet(
+      imagesets::ImageSet::Create(filenames, options));
   imageSet->Initialize();
   lock.unlock();
 
   open(std::move(imageSet));
 }
 
+void RFIGuiController::OpenMsConcatenated(
+    const std::vector<std::string>& filenames, const MSOptions& options) {
+  constexpr size_t kMaxIoThreads = 16;
+  const size_t n_io_threads = std::min<size_t>(
+      {kMaxIoThreads, aocommon::system::ProcessorCount(), filenames.size()});
+
+  std::unique_ptr<imagesets::ImageSet> image_set =
+      std::make_unique<imagesets::MultiBandMsImageSet>(
+          filenames, options.ioMode, options.intervalStart,
+          options.intervalStart, n_io_threads);
+
+  image_set->Initialize();
+
+  open(std::move(image_set));
+}
+
 void RFIGuiController::OpenMS(const std::vector<std::string>& filenames,
                               const MSOptions& options) {
-  std::unique_ptr<rfiStrategy::ImageSet> imageSet(
-      rfiStrategy::ImageSet::Create(filenames, options));
-  rfiStrategy::MSImageSet* msImageSet =
-      dynamic_cast<rfiStrategy::MSImageSet*>(imageSet.get());
-  if (msImageSet != nullptr) {
-    msImageSet->SetSubtractModel(options.subtractModel);
+  if (options.concatenateFrequency) {
+    OpenMsConcatenated(filenames, options);
+    return;
+  }
+
+  std::unique_ptr<imagesets::ImageSet> imageSet(
+      imagesets::ImageSet::Create(filenames, options));
+
+  if (imagesets::H5ImageSet* h5ImageSet =
+          dynamic_cast<imagesets::H5ImageSet*>(imageSet.get());
+      h5ImageSet != nullptr) {
+    h5ImageSet->SetInterval(options.intervalStart, options.intervalEnd);
+  } else if (imagesets::MSImageSet* msImageSet =
+                 dynamic_cast<imagesets::MSImageSet*>(imageSet.get());
+             msImageSet != nullptr) {
     msImageSet->SetDataColumnName(options.dataColumnName);
     msImageSet->SetInterval(options.intervalStart, options.intervalEnd);
 
@@ -268,8 +306,8 @@ void RFIGuiController::OpenMS(const std::vector<std::string>& filenames,
     if (options.combineSPWs) {
       msImageSet->Initialize();
       imageSet.release();
-      std::unique_ptr<rfiStrategy::MSImageSet> msImageSetPtr(msImageSet);
-      imageSet.reset(new rfiStrategy::JoinedSPWSet(std::move(msImageSetPtr)));
+      std::unique_ptr<imagesets::MSImageSet> msImageSetPtr(msImageSet);
+      imageSet.reset(new imagesets::JoinedSPWSet(std::move(msImageSetPtr)));
     }
   }
   imageSet->Initialize();
@@ -284,14 +322,14 @@ void RFIGuiController::SaveBaselineFlags() {
 }
 
 void RFIGuiController::setRecentFile(const std::string& filename) {
-  std::string absFilename = boost::filesystem::absolute(filename).string();
+  std::string absFilename = std::filesystem::absolute(filename).string();
   std::vector<std::string> files = _settings.RecentFiles();
   files.emplace(files.begin(), absFilename);
   if (files.size() > 10) files.resize(10);
   for (size_t i = 1; i != files.size(); ++i) {
-    boost::system::error_code ec;
+    std::error_code ec;
     if (files[i] == absFilename ||
-        boost::filesystem::equivalent(files[i], absFilename, ec)) {
+        std::filesystem::equivalent(files[i], absFilename, ec)) {
       files.erase(files.begin() + i);
       break;
     }
@@ -307,22 +345,24 @@ std::vector<std::string> RFIGuiController::RecentFiles() const {
   for (size_t i = 0; i != files.size(); ++i) {
     if (!files[i].empty()) {
       // Don't return the current open file as a recent file
-      boost::system::error_code ec;
-      bool isOpen =
-          (HasImageSet() && (files[i] == _imageSet->Files()[0] ||
-                             boost::filesystem::equivalent(
-                                 files[i], _imageSet->Files()[0], ec)));
+      std::error_code ec;
+      const bool isOpen =
+          (HasImageSet() &&
+           (files[i] == _imageSet->Files()[0] ||
+            std::filesystem::equivalent(files[i], _imageSet->Files()[0], ec)));
       if (!isOpen) shownFiles.emplace_back(files[i]);
     }
   }
   return shownFiles;
 }
 
-void RFIGuiController::OpenTestSet(unsigned index, bool gaussianTestSets) {
-  unsigned width = 1024, height = 512;
+void RFIGuiController::OpenTestSet(
+    algorithms::RFITestSet rfiSet,
+    algorithms::BackgroundTestSet backgroundSet) {
+  size_t width = 1024, height = 512;
   TimeFrequencyMetaDataCPtr metaData;
   if (IsImageLoaded()) {
-    TimeFrequencyData activeData = ActiveData();
+    const TimeFrequencyData activeData = ActiveData();
     width = activeData.ImageWidth();
     height = activeData.ImageHeight();
     metaData = SelectedMetaData();
@@ -331,22 +371,8 @@ void RFIGuiController::OpenTestSet(unsigned index, bool gaussianTestSets) {
   }
   CloseImageSet();
 
-  TimeFrequencyData data;
-  if (index >= 1000) {
-    data = TestSetGenerator::MakeSpike();
-    metaData.reset(new TimeFrequencyMetaData());
-  } else {
-    Mask2D rfi = Mask2D::MakeSetMask<false>(width, height);
-    Image2D testSetReal(TestSetGenerator::MakeTestSet(index, rfi, width, height,
-                                                      gaussianTestSets));
-    Image2D testSetImaginary(
-        TestSetGenerator::MakeTestSet(2, rfi, width, height, gaussianTestSets));
-    data = TimeFrequencyData(aocommon::Polarization::StokesI,
-                             Image2D::MakePtr(testSetReal),
-                             Image2D::MakePtr(testSetImaginary));
-    data.SetGlobalMask(Mask2D::MakePtr(rfi));
-  }
-
+  const TimeFrequencyData data =
+      TestSetGenerator::MakeTestSet(rfiSet, backgroundSet, width, height);
   _tfController.SetNewData(data, metaData);
   const char* name = "Simulated test set";
   _tfController.Plot().SetTitleText(name);
@@ -379,7 +405,7 @@ void RFIGuiController::ExecuteLuaStrategy(class ProgressListener& listener) {
   _processingThread = std::thread([&]() {
     try {
       _scriptTFData = OriginalData();
-      TimeFrequencyMetaDataCPtr metaData =
+      const TimeFrequencyMetaDataCPtr metaData =
           _tfController.Plot().GetFullMetaData();
 
       _scriptData.reset(new ScriptData());
@@ -411,13 +437,13 @@ void RFIGuiController::JoinLuaThread() {
 }
 
 void RFIGuiController::SetImageSet(
-    std::unique_ptr<rfiStrategy::ImageSet> newImageSet) {
+    std::unique_ptr<imagesets::ImageSet> newImageSet) {
   _imageSetIndex = newImageSet->StartIndex();
   _imageSet = std::move(newImageSet);
 }
 
 void RFIGuiController::SetImageSetIndex(
-    const rfiStrategy::ImageSetIndex& newImageSetIndex) {
+    const imagesets::ImageSetIndex& newImageSetIndex) {
   _imageSetIndex = newImageSetIndex;
 }
 
@@ -434,7 +460,7 @@ void RFIGuiController::CloseImageSet() {
 void RFIGuiController::LoadCurrentTFDataAsync(ProgressListener& progress) {
   try {
     if (HasImageSet()) {
-      std::lock_guard<std::mutex> lock(_ioMutex);
+      const std::lock_guard<std::mutex> lock(_ioMutex);
       _imageSet->AddReadRequest(_imageSetIndex);
       _imageSet->PerformReadRequests(progress);
       _tempLoadedBaseline = _imageSet->GetNextRequested();
@@ -466,9 +492,9 @@ void RFIGuiController::LoadCurrentTFDataFinish(bool success) {
 
     if (_rfiGuiWindow != nullptr) {
       // Disable forward/back buttons when only one baseline is available
-      rfiStrategy::ImageSetIndex firstIndex = _imageSet->StartIndex();
+      imagesets::ImageSetIndex firstIndex = _imageSet->StartIndex();
       firstIndex.Next();
-      bool multipleBaselines = !firstIndex.HasWrapped();
+      const bool multipleBaselines = !firstIndex.HasWrapped();
 
       _rfiGuiWindow->SetBaselineInfo(false, multipleBaselines, name,
                                      description);
@@ -514,7 +540,7 @@ void RFIGuiController::GetAvailablePolarizations(bool& pp, bool& pq, bool& qp,
   }
 }
 
-void RFIGuiController::SaveBaseline(const std::string& filename) {
+void RFIGuiController::SaveBaselineAsRfibl(const std::string& filename) {
   SingleBaselineFile file;
   file.data = _tfController.OriginalData();
   file.metaData = *_tfController.Plot().GetFullMetaData();
@@ -523,13 +549,21 @@ void RFIGuiController::SaveBaseline(const std::string& filename) {
   file.Write(stream);
 }
 
+void RFIGuiController::SaveBaselineAsNpy(const std::string& filename) {
+  const TimeFrequencyData& tf_data = _tfController.OriginalData();
+  std::vector<std::complex<num_t>> data = ToComplexVector(tf_data);
+  const std::array<unsigned long, 3> shape = {
+      tf_data.PolarizationCount(), tf_data.ImageHeight(), tf_data.ImageWidth()};
+  npy::SaveArrayAsNumpy(filename, false, shape.size(), shape.data(), data);
+}
+
 void RFIGuiController::NewDefaultStrategy() {
   _settings.InitializeWorkStrategy();
   _openStrategyFilename.clear();
 }
 
 void RFIGuiController::NewEmptyStrategy() {
-  std::ofstream file(_settings.GetStrategyFilename());
+  const std::ofstream file(_settings.GetStrategyFilename());
   if (!file)
     throw std::runtime_error("Error writing new strategy to work file");
   _openStrategyFilename.clear();
@@ -544,31 +578,29 @@ void RFIGuiController::NewTemplateStrategy() {
 }
 
 void RFIGuiController::OpenStrategy(const std::string& filename) {
-  boost::system::error_code ec;
-  if (boost::filesystem::equivalent(_settings.GetStrategyFilename(), filename,
-                                    ec))
+  std::error_code ec;
+  if (std::filesystem::equivalent(_settings.GetStrategyFilename(), filename,
+                                  ec))
     throw std::runtime_error("Can't open working Lua strategy");
-  boost::filesystem::copy_file(
-      filename, _settings.GetStrategyFilename(),
-      boost::filesystem::copy_option::overwrite_if_exists);
+  std::filesystem::copy_file(filename, _settings.GetStrategyFilename(),
+                             std::filesystem::copy_options::overwrite_existing);
   _openStrategyFilename = filename;
 }
 
 void RFIGuiController::SaveStrategy() {
-  boost::filesystem::copy_file(
-      _settings.GetStrategyFilename(), _openStrategyFilename,
-      boost::filesystem::copy_option::overwrite_if_exists);
+  std::filesystem::copy_file(_settings.GetStrategyFilename(),
+                             _openStrategyFilename,
+                             std::filesystem::copy_options::overwrite_existing);
 }
 
 void RFIGuiController::SaveStrategyAs(const std::string& filename) {
-  boost::filesystem::copy_file(
-      _settings.GetStrategyFilename(), filename,
-      boost::filesystem::copy_option::overwrite_if_exists);
+  std::filesystem::copy_file(_settings.GetStrategyFilename(), filename,
+                             std::filesystem::copy_options::overwrite_existing);
   _openStrategyFilename = filename;
 }
 
 std::string RFIGuiController::GetWorkStrategyText() const {
-  std::ifstream file(_settings.GetStrategyFilename());
+  const std::ifstream file(_settings.GetStrategyFilename());
   if (!file) throw std::runtime_error("Error reading work strategy from file");
   std::ostringstream text;
   text << file.rdbuf();
