@@ -4,13 +4,15 @@
 #include <gtkmm/filechooserdialog.h>
 #include "../util/gtkmm-compat.h"
 
-#include "imagepropertieswindow.h"
-#include "heatmapwidget.h"
+#include "../plot/plotwidget.h"
 
-ImagePropertiesWindow::ImagePropertiesWindow(HeatMapWidget &imageWidget,
-                                             const std::string &title)
+#include "imagepropertieswindow.h"
+#include "maskedheatmap.h"
+
+ImagePropertiesWindow::ImagePropertiesWindow(PlotWidget& imageWidget,
+                                             const std::string& title)
     : Gtk::Window(),
-      _imageWidget(imageWidget),
+      _plotWidget(imageWidget),
       _applyButton("_Apply", true),
       _exportButton("_Export", true),
       _exportDataButton("Export _data", true),
@@ -30,7 +32,6 @@ ImagePropertiesWindow::ImagePropertiesWindow(HeatMapWidget &imageWidget,
       _optionsFrame("Options"),
       _normalOptionsButton("Normal scale"),
       _logScaleButton("Logarithmic scale"),
-      _zeroSymmetricButton("Symmetric around zero"),
 
       _filterFrame("Interpolation"),
       _bestFilterButton("Best"),
@@ -43,10 +44,15 @@ ImagePropertiesWindow::ImagePropertiesWindow(HeatMapWidget &imageWidget,
       _showXAxisDescriptionButton("x-axis desc"),
       _showYAxisDescriptionButton("y-axis desc"),
       _showZAxisDescriptionButton("z-axis desc"),
-      _manualTitle("manual"),
       _manualXAxisDescription("manual"),
       _manualYAxisDescription("manual"),
       _manualZAxisDescription("manual") {
+  _maskedHeatMap = dynamic_cast<MaskedHeatMap*>(&_plotWidget.Plot());
+  if (!_maskedHeatMap) {
+    throw std::invalid_argument(
+        "ImagePropertiesWindow called for a plot that is not a heat map");
+  }
+
   set_title(title);
 
   initColorMapButtons();
@@ -102,8 +108,8 @@ void ImagePropertiesWindow::initColorMapButtons() {
   _colorMapCombo.set_model(_colorMapStore);
   _colorMapCombo.pack_start(_colorMapColumns.name);
 
-  ColorMap::Type selectedMap = _imageWidget.Plot().GetColorMap();
-  Gtk::ListStore::Children children = _colorMapStore->children();
+  const ColorMap::Type selectedMap = _maskedHeatMap->GetColorMap();
+  const Gtk::ListStore::Children children = _colorMapStore->children();
   for (auto row : children) {
     if (row[_colorMapColumns.colorMap] == selectedMap) {
       _colorMapCombo.set_active(row);
@@ -138,15 +144,15 @@ void ImagePropertiesWindow::initScaleWidgets() {
   _specifiedScaleButton.signal_clicked().connect(
       sigc::mem_fun(*this, &ImagePropertiesWindow::onScaleChanged));
 
-  switch (_imageWidget.Plot().Range()) {
+  switch (_maskedHeatMap->ZRange().minimum) {
     default:
-    case HeatMapPlot::MinMax:
+    case RangeLimit::Extreme:
       _minMaxScaleButton.set_active(true);
       break;
-    case HeatMapPlot::Winsorized:
+    case RangeLimit::Winsorized:
       _winsorizedScaleButton.set_active(true);
       break;
-    case HeatMapPlot::Specified:
+    case RangeLimit::Specified:
       _specifiedScaleButton.set_active(true);
       break;
   }
@@ -172,20 +178,10 @@ void ImagePropertiesWindow::initOptionsWidgets() {
   _optionsBox.pack_start(_logScaleButton);
   _logScaleButton.set_group(group);
 
-  _optionsBox.pack_start(_zeroSymmetricButton);
-  _zeroSymmetricButton.set_group(group);
-
-  switch (_imageWidget.Plot().ScaleOption()) {
-    default:
-    case HeatMapPlot::NormalScale:
-      _normalOptionsButton.set_active(true);
-      break;
-    case HeatMapPlot::LogScale:
-      _logScaleButton.set_active(true);
-      break;
-    case HeatMapPlot::ZeroSymmetricScale:
-      _zeroSymmetricButton.set_active(true);
-      break;
+  if (_maskedHeatMap->LogZScale()) {
+    _logScaleButton.set_active(true);
+  } else {
+    _normalOptionsButton.set_active(true);
   }
 
   _optionsFrame.add(_optionsBox);
@@ -202,7 +198,7 @@ void ImagePropertiesWindow::initFilterWidgets() {
   _filterBox.pack_start(_nearestFilterButton);
   _nearestFilterButton.set_group(group);
 
-  switch (_imageWidget.Plot().CairoFilter()) {
+  switch (_maskedHeatMap->CairoFilter()) {
     default:
     case Cairo::FILTER_BEST:
       _bestFilterButton.set_active(true);
@@ -218,58 +214,53 @@ void ImagePropertiesWindow::initFilterWidgets() {
 }
 
 void ImagePropertiesWindow::initAxisWidgets() {
-  _showXYAxes.set_active(_imageWidget.Plot().ShowXYAxes());
+  const MaskedHeatMap& maskedHeatMap =
+      static_cast<const MaskedHeatMap&>(_plotWidget.Plot());
+  _showXYAxes.set_active(maskedHeatMap.ShowXAxis() ||
+                         maskedHeatMap.ShowYAxis());
   _axesGeneralBox.pack_start(_showXYAxes);
 
-  _showColorScale.set_active(_imageWidget.Plot().ShowColorScale());
+  _showColorScale.set_active(maskedHeatMap.ShowColorScale());
   _axesGeneralBox.pack_start(_showColorScale);
 
   _axesHBox.pack_start(_axesGeneralBox);
 
-  _showTitleButton.set_active(_imageWidget.Plot().ShowTitle());
+  _showTitleButton.set_active(maskedHeatMap.ShowTitle());
   _titleBox.pack_start(_showTitleButton);
-  _manualTitle.set_active(_imageWidget.Plot().ManualTitle());
-  _titleBox.pack_start(_manualTitle);
-  _titleEntry.set_text(_imageWidget.Plot().ManualTitleText());
+  _titleEntry.set_text(maskedHeatMap.TitleText());
   _titleBox.pack_start(_titleEntry);
 
   _axesVisibilityBox.pack_start(_titleBox);
 
-  _showXAxisDescriptionButton.set_active(
-      _imageWidget.Plot().ShowXAxisDescription());
+  _showXAxisDescriptionButton.set_active(maskedHeatMap.ShowXAxisDescription());
   _xAxisBox.pack_start(_showXAxisDescriptionButton);
 
-  _manualXAxisDescription.set_active(
-      _imageWidget.Plot().ManualXAxisDescription());
+  _manualXAxisDescription.set_active(maskedHeatMap.ManualXAxisDescription());
   _xAxisBox.pack_start(_manualXAxisDescription);
 
-  _xAxisDescriptionEntry.set_text(_imageWidget.Plot().XAxisDescription());
+  _xAxisDescriptionEntry.set_text(maskedHeatMap.XAxisDescription());
   _xAxisBox.pack_start(_xAxisDescriptionEntry);
 
   _axesVisibilityBox.pack_start(_xAxisBox);
 
-  _showYAxisDescriptionButton.set_active(
-      _imageWidget.Plot().ShowYAxisDescription());
+  _showYAxisDescriptionButton.set_active(maskedHeatMap.ShowYAxisDescription());
   _yAxisBox.pack_start(_showYAxisDescriptionButton);
 
-  _manualYAxisDescription.set_active(
-      _imageWidget.Plot().ManualYAxisDescription());
+  _manualYAxisDescription.set_active(maskedHeatMap.ManualYAxisDescription());
   _yAxisBox.pack_start(_manualYAxisDescription);
 
-  _yAxisDescriptionEntry.set_text(_imageWidget.Plot().YAxisDescription());
+  _yAxisDescriptionEntry.set_text(maskedHeatMap.YAxisDescription());
   _yAxisBox.pack_start(_yAxisDescriptionEntry);
 
   _axesVisibilityBox.pack_start(_yAxisBox);
 
-  _showZAxisDescriptionButton.set_active(
-      _imageWidget.Plot().ShowZAxisDescription());
+  _showZAxisDescriptionButton.set_active(maskedHeatMap.ShowZAxisDescription());
   _zAxisBox.pack_start(_showZAxisDescriptionButton);
 
-  _manualZAxisDescription.set_active(
-      _imageWidget.Plot().ManualZAxisDescription());
+  _manualZAxisDescription.set_active(maskedHeatMap.ManualZAxisDescription());
   _zAxisBox.pack_start(_manualZAxisDescription);
 
-  _zAxisDescriptionEntry.set_text(_imageWidget.Plot().ZAxisDescription());
+  _zAxisDescriptionEntry.set_text(maskedHeatMap.ZAxisDescription());
   _zAxisBox.pack_start(_zAxisDescriptionEntry);
 
   _axesVisibilityBox.pack_start(_zAxisBox);
@@ -282,71 +273,66 @@ void ImagePropertiesWindow::initAxisWidgets() {
 
 void ImagePropertiesWindow::updateMinMaxEntries() {
   std::stringstream minStr;
-  minStr << _imageWidget.Plot().Min();
+  minStr << _maskedHeatMap->Min();
   _scaleMinEntry.set_text(minStr.str());
 
   std::stringstream maxStr;
-  maxStr << _imageWidget.Plot().Max();
+  maxStr << _maskedHeatMap->Max();
   _scaleMaxEntry.set_text(maxStr.str());
 }
 
 void ImagePropertiesWindow::onApplyClicked() {
-  _imageWidget.Plot().SetColorMap(
+  MaskedHeatMap& maskedHeatMap =
+      static_cast<MaskedHeatMap&>(_plotWidget.Plot());
+  maskedHeatMap.SetColorMap(
       (*_colorMapCombo.get_active())[_colorMapColumns.colorMap]);
 
-  if (_minMaxScaleButton.get_active())
-    _imageWidget.Plot().SetRange(HeatMapPlot::MinMax);
-  else if (_winsorizedScaleButton.get_active())
-    _imageWidget.Plot().SetRange(HeatMapPlot::Winsorized);
-  else if (_specifiedScaleButton.get_active()) {
-    _imageWidget.Plot().SetRange(HeatMapPlot::Specified);
-    _imageWidget.Plot().SetMin(atof(_scaleMinEntry.get_text().c_str()));
-    _imageWidget.Plot().SetMax(atof(_scaleMaxEntry.get_text().c_str()));
+  if (_minMaxScaleButton.get_active()) {
+    maskedHeatMap.SetZRange(FullRange());
+  } else if (_winsorizedScaleButton.get_active()) {
+    maskedHeatMap.SetZRange(WinsorizedRange());
+  } else if (_specifiedScaleButton.get_active()) {
+    RangeConfiguration range;
+    range.minimum = RangeLimit::Specified;
+    range.maximum = RangeLimit::Specified;
+    range.specified_min = atof(_scaleMinEntry.get_text().c_str());
+    range.specified_max = atof(_scaleMaxEntry.get_text().c_str());
+    maskedHeatMap.SetZRange(range);
   }
 
-  if (_normalOptionsButton.get_active())
-    _imageWidget.Plot().SetScaleOption(HeatMapPlot::NormalScale);
-  else if (_logScaleButton.get_active())
-    _imageWidget.Plot().SetScaleOption(HeatMapPlot::LogScale);
-  else if (_zeroSymmetricButton.get_active())
-    _imageWidget.Plot().SetScaleOption(HeatMapPlot::ZeroSymmetricScale);
+  maskedHeatMap.SetLogZScale(_logScaleButton.get_active());
 
   if (_bestFilterButton.get_active())
-    _imageWidget.Plot().SetCairoFilter(Cairo::FILTER_BEST);
+    maskedHeatMap.SetCairoFilter(Cairo::FILTER_BEST);
   else if (_nearestFilterButton.get_active())
-    _imageWidget.Plot().SetCairoFilter(Cairo::FILTER_NEAREST);
+    maskedHeatMap.SetCairoFilter(Cairo::FILTER_NEAREST);
 
-  _imageWidget.Plot().SetShowTitle(_showTitleButton.get_active());
-  _imageWidget.Plot().SetManualTitle(_manualTitle.get_active());
-  if (_manualTitle.get_active())
-    _imageWidget.Plot().SetManualTitleText(_titleEntry.get_text());
-
-  _imageWidget.Plot().SetShowXYAxes(_showXYAxes.get_active());
-  _imageWidget.Plot().SetShowXAxisDescription(
+  maskedHeatMap.SetShowTitle(_showTitleButton.get_active());
+  maskedHeatMap.SetTitleText(_titleEntry.get_text());
+  maskedHeatMap.SetShowXAxis(_showXYAxes.get_active());
+  maskedHeatMap.SetShowYAxis(_showXYAxes.get_active());
+  maskedHeatMap.SetShowXAxisDescription(
       _showXAxisDescriptionButton.get_active());
-  _imageWidget.Plot().SetShowYAxisDescription(
+  maskedHeatMap.SetShowYAxisDescription(
       _showYAxisDescriptionButton.get_active());
-  _imageWidget.Plot().SetShowZAxisDescription(
+  maskedHeatMap.SetShowZAxisDescription(
       _showZAxisDescriptionButton.get_active());
 
-  _imageWidget.Plot().SetManualXAxisDescription(
-      _manualXAxisDescription.get_active());
+  maskedHeatMap.SetManualXAxisDescription(_manualXAxisDescription.get_active());
   if (_manualXAxisDescription.get_active())
-    _imageWidget.Plot().SetXAxisDescription(_xAxisDescriptionEntry.get_text());
+    maskedHeatMap.SetXAxisDescription(_xAxisDescriptionEntry.get_text());
 
-  _imageWidget.Plot().SetManualYAxisDescription(
-      _manualYAxisDescription.get_active());
+  maskedHeatMap.SetManualYAxisDescription(_manualYAxisDescription.get_active());
   if (_manualYAxisDescription.get_active())
-    _imageWidget.Plot().SetYAxisDescription(_yAxisDescriptionEntry.get_text());
+    maskedHeatMap.SetYAxisDescription(_yAxisDescriptionEntry.get_text());
 
-  _imageWidget.Plot().SetManualZAxisDescription(
-      _manualZAxisDescription.get_active());
+  maskedHeatMap.SetManualZAxisDescription(_manualZAxisDescription.get_active());
   if (_manualZAxisDescription.get_active())
-    _imageWidget.Plot().SetZAxisDescription(_zAxisDescriptionEntry.get_text());
+    maskedHeatMap.SetZAxisDescription(_zAxisDescriptionEntry.get_text());
 
-  _imageWidget.Plot().SetShowColorScale(_showColorScale.get_active());
+  maskedHeatMap.SetShowColorScale(_showColorScale.get_active());
 
-  _imageWidget.Update();
+  _plotWidget.Update();
 
   updateMinMaxEntries();
 }
@@ -354,7 +340,7 @@ void ImagePropertiesWindow::onApplyClicked() {
 void ImagePropertiesWindow::onCloseClicked() { hide(); }
 
 void ImagePropertiesWindow::onExportClicked() {
-  if (_imageWidget.Plot().HasImage()) {
+  if (_maskedHeatMap->HasImage()) {
     Gtk::FileChooserDialog dialog("Specify image filename",
                                   Gtk::FILE_CHOOSER_ACTION_SAVE);
     dialog.set_transient_for(*this);
@@ -363,43 +349,43 @@ void ImagePropertiesWindow::onExportClicked() {
     dialog.add_button("_Cancel", Gtk::RESPONSE_CANCEL);
     dialog.add_button("_Save", Gtk::RESPONSE_OK);
 
-    Glib::RefPtr<Gtk::FileFilter> pdfFilter = Gtk::FileFilter::create();
-    std::string pdfName = "Portable Document Format (*.pdf)";
+    const Glib::RefPtr<Gtk::FileFilter> pdfFilter = Gtk::FileFilter::create();
+    const std::string pdfName = "Portable Document Format (*.pdf)";
     pdfFilter->set_name(pdfName);
     pdfFilter->add_pattern("*.pdf");
     pdfFilter->add_mime_type("application/pdf");
     dialog.add_filter(pdfFilter);
 
-    Glib::RefPtr<Gtk::FileFilter> svgFilter = Gtk::FileFilter::create();
-    std::string svgName = "Scalable Vector Graphics (*.svg)";
+    const Glib::RefPtr<Gtk::FileFilter> svgFilter = Gtk::FileFilter::create();
+    const std::string svgName = "Scalable Vector Graphics (*.svg)";
     svgFilter->set_name(svgName);
     svgFilter->add_pattern("*.svg");
     svgFilter->add_mime_type("image/svg+xml");
     dialog.add_filter(svgFilter);
 
-    Glib::RefPtr<Gtk::FileFilter> pngFilter = Gtk::FileFilter::create();
-    std::string pngName = "Portable Network Graphics (*.png)";
+    const Glib::RefPtr<Gtk::FileFilter> pngFilter = Gtk::FileFilter::create();
+    const std::string pngName = "Portable Network Graphics (*.png)";
     pngFilter->set_name(pngName);
     pngFilter->add_pattern("*.png");
     pngFilter->add_mime_type("image/png");
     dialog.add_filter(pngFilter);
 
-    int result = dialog.run();
+    const int result = dialog.run();
 
     if (result == Gtk::RESPONSE_OK) {
-      Glib::RefPtr<const Gtk::FileFilter> filter = dialog.get_filter();
+      const Glib::RefPtr<const Gtk::FileFilter> filter = dialog.get_filter();
       if (filter->get_name() == pdfName)
-        _imageWidget.SavePdf(dialog.get_filename());
+        _plotWidget.SavePdf(dialog.get_filename());
       else if (filter->get_name() == svgName)
-        _imageWidget.SaveSvg(dialog.get_filename());
+        _plotWidget.SaveSvg(dialog.get_filename());
       else
-        _imageWidget.SavePng(dialog.get_filename());
+        _plotWidget.SavePng(dialog.get_filename());
     }
   }
 }
 
 void ImagePropertiesWindow::onExportDataClicked() {
-  if (_imageWidget.Plot().HasImage()) {
+  if (_maskedHeatMap->HasImage()) {
     Gtk::FileChooserDialog dialog("Specify data filename",
                                   Gtk::FILE_CHOOSER_ACTION_SAVE);
     dialog.set_transient_for(*this);
@@ -408,16 +394,19 @@ void ImagePropertiesWindow::onExportDataClicked() {
     dialog.add_button("_Cancel", Gtk::RESPONSE_CANCEL);
     dialog.add_button("_Save", Gtk::RESPONSE_OK);
 
-    Glib::RefPtr<Gtk::FileFilter> pdfFilter = Gtk::FileFilter::create();
-    std::string pdfName = "Text format: width; height; data1; data2... (*.txt)";
+    const Glib::RefPtr<Gtk::FileFilter> pdfFilter = Gtk::FileFilter::create();
+    const std::string pdfName =
+        "Text format: width; height; data1; data2... (*.txt)";
     pdfFilter->set_name(pdfName);
     pdfFilter->add_pattern("*.txt");
     pdfFilter->add_mime_type("text/plain");
     dialog.add_filter(pdfFilter);
-    int result = dialog.run();
+    const int result = dialog.run();
 
     if (result == Gtk::RESPONSE_OK) {
-      _imageWidget.Plot().SaveText(dialog.get_filename());
+      const MaskedHeatMap& maskedHeatMap =
+          static_cast<MaskedHeatMap&>(_plotWidget.Plot());
+      maskedHeatMap.SaveText(dialog.get_filename());
     }
   }
 }
