@@ -7,12 +7,14 @@
 
 #include "../plot/plotwidget.h"
 
+class XYPlot;
+
 class PlotFrame : public Gtk::HBox {
  public:
   PlotFrame();
   ~PlotFrame();
 
-  void SetTimeFrequencyData(const TimeFrequencyData &data) { _data = data; }
+  void SetTimeFrequencyData(const TimeFrequencyData& data) { _data = data; }
   void SetSelectedSample(size_t x, size_t y) {
     _selectedXStart = x;
     _selectedYStart = y;
@@ -24,15 +26,15 @@ class PlotFrame : public Gtk::HBox {
  private:
   TimeFrequencyData _data;
   PlotWidget _plot;
-  class Plot2D *_plotData;
+  XYPlot* _plotData;
 
   size_t _selectedXStart, _selectedYStart;
   size_t _selectedXEnd, _selectedYEnd;
 
   void plot();
-  void plotTimeGraph(const TimeFrequencyData &data, const std::string &label,
+  void plotTimeGraph(const TimeFrequencyData& data, const std::string& label,
                      aocommon::PolarizationEnum polarisation);
-  void plotTimeGraph(const TimeFrequencyData &data, const std::string &label);
+  void plotTimeGraph(const TimeFrequencyData& data, const std::string& label);
 };
 
 #endif
