@@ -2,14 +2,13 @@
 
 #include <glibmm/miscutils.h>
 
-#include <boost/filesystem/path.hpp>
-#include <boost/filesystem/operations.hpp>
-
 #include <boost/algorithm/string.hpp>
 
+#include <filesystem>
 #include <fstream>
 
 #include "../lua/default-strategy.h"
+#include "../util/logger.h"
 
 Settings::Settings() {
   initStrArray("recent-files", std::vector<std::string>(10));
@@ -17,25 +16,31 @@ Settings::Settings() {
 }
 
 std::string Settings::getConfigFilename() {
-  return (boost::filesystem::path(GetConfigDir()) / "settings").string();
+  return (std::filesystem::path(GetConfigDir()) / "settings").string();
 }
 
 std::string Settings::GetStrategyFilename() const {
-  return (boost::filesystem::path(GetConfigDir()) / "strategy.lua").string();
+  return (std::filesystem::path(GetConfigDir()) / "strategy.lua").string();
 }
 
 std::string Settings::GetConfigDir() {
-  boost::filesystem::path configPath =
-      boost::filesystem::path(Glib::get_user_config_dir()) / "aoflagger";
-  if (!boost::filesystem::is_directory(configPath))
-    boost::filesystem::create_directory(configPath);
+  std::filesystem::path configPath =
+      std::filesystem::path(Glib::get_user_config_dir()) / "aoflagger";
+  if (!std::filesystem::is_directory(configPath)) {
+    // We don't want to crash if the dir can't be created; we will just report
+    // an error to the cmd line
+    try {
+      std::filesystem::create_directories(configPath);
+    } catch (std::exception& exception) {
+      Logger::Error << "Failed to create config directory: " << exception.what()
+                    << '\n';
+    }
+  }
   return configPath.string();
 }
 
 void Settings::InitializeWorkStrategy() {
   std::string filename = GetStrategyFilename();
-  // if(!boost::filesystem::exists(filename))
-  //{
   std::ofstream str(filename);
   str.write(reinterpret_cast<const char*>(data_strategies_generic_default_lua),
             data_strategies_generic_default_lua_len);
@@ -43,12 +48,11 @@ void Settings::InitializeWorkStrategy() {
     throw std::runtime_error(
         "Failed to write working file for Lua strategy: " + filename +
         ", size " + std::to_string(data_strategies_generic_default_lua_len));
-  //}
 }
 
 void Settings::Load() {
   std::string configFilename = getConfigFilename();
-  if (boost::filesystem::exists(configFilename)) {
+  if (std::filesystem::exists(configFilename)) {
     std::ifstream file(configFilename);
     std::string line;
     std::getline(file, line);
