@@ -12,6 +12,7 @@
 
 #include <cmath>
 #include <exception>
+#include <initializer_list>
 #include <memory>
 
 typedef boost::intrusive_ptr<class Image2D> Image2DPtr;
@@ -26,11 +27,16 @@ void swap(Image2D&& left, Image2D& right);
  * can be read from and written to a @c .fits file and written to a @c .png
  * file. A new Image2D can be constructed with e.g. the MakeFromFits(),
  * MakeUnsetImage() or MakeFromDiff() static methods.
+ *
+ * Internally, the data is stored such that the x-axis is moving the fastest,
+ * so "y-major".
  */
 class Image2D : public boost::intrusive_ref_counter<Image2D> {
  public:
   Image2D() noexcept;
 
+  Image2D(size_t width, size_t height, std::initializer_list<num_t> values);
+
   Image2D(const Image2D& source);
 
   Image2D(Image2D&& source) noexcept;
@@ -47,6 +53,13 @@ class Image2D : public boost::intrusive_ref_counter<Image2D> {
     return Image2DPtr(new Image2D(std::forward<Args>(args)...));
   }
 
+  static Image2DPtr MakePtr(size_t width, size_t height,
+                            std::initializer_list<num_t> values) {
+    // The above function using forwarding reference does not automatically
+    // capture std::initializer_list, hence an explicit overload.
+    return Image2DPtr(new Image2D(width, height, values));
+  }
+
   /**
    * Destructor.
    */
@@ -67,6 +80,12 @@ class Image2D : public boost::intrusive_ref_counter<Image2D> {
     return image;
   }
 
+  /**
+   * Construct an image with initialized values.
+   * @param widthCapacity Minimum capacity to which the image can be
+   * horizontally resized without reallocation; see also
+   * @ref ResizeWithoutReallocation().
+   */
   static Image2D MakeSetImage(size_t width, size_t height, num_t initialValue,
                               size_t widthCapacity) {
     Image2D image(width, height, widthCapacity);
@@ -74,6 +93,12 @@ class Image2D : public boost::intrusive_ref_counter<Image2D> {
     return image;
   }
 
+  /**
+   * Return a copy of this image in which non-finite values have been
+   * replaced by zero.
+   */
+  Image2D MakeFiniteCopy() const;
+
   /**
    * Creates an image containing unset values.
    * @param width Width of the new image.
@@ -262,6 +287,11 @@ class Image2D : public boost::intrusive_ref_counter<Image2D> {
     _dataPtr[y][x] += addValue;
   }
 
+  /**
+   * Returns true if object contains no non-finite values.
+   */
+  bool AllFinite() const;
+
   /**
    * Check whether this image is completely zero.
    * @return @c true if the value only contains zeros.
@@ -343,9 +373,9 @@ class Image2D : public boost::intrusive_ref_counter<Image2D> {
   void SubtractAsRHS(const Image2DCPtr& lhs);
 
   /**
-   * Flips the image round the diagonal, i.e., x becomes y and y becomes x.
+   * Flips the image w.r.t. the diagonal, i.e., x becomes y and y becomes x.
    */
-  Image2D CreateXYFlipped() const {
+  Image2D GetTransposed() const {
     Image2D image(_height, _width);
     for (unsigned y = 0; y < _height; ++y) {
       for (unsigned x = 0; x < _width; ++x)
@@ -354,7 +384,7 @@ class Image2D : public boost::intrusive_ref_counter<Image2D> {
     return image;
   }
 
-  void SwapXY() { *this = CreateXYFlipped(); }
+  void Transpose() { *this = GetTransposed(); }
 
   /**
    * Resample the image horizontally by decreasing the width
@@ -434,7 +464,7 @@ class Image2D : public boost::intrusive_ref_counter<Image2D> {
   /**
    * This value specifies the intrinsic width of one row. It is
    * normally the first number that is >= Width() and divisable by
-   * four. When using the ValuePtr(unsigned, unsigned) method,
+   * 8. When using the ValuePtr(unsigned, unsigned) method,
    * this value can be used to step over one row.
    *
    * @see ValuePtr(unsigned, unsigned)
@@ -461,11 +491,23 @@ class Image2D : public boost::intrusive_ref_counter<Image2D> {
   friend void swap(Image2D&, Image2D&&);
   friend void swap(Image2D&&, Image2D&);
 
+  friend bool operator==(const Image2D& lhs, const Image2D& rhs);
+
   Image2D(size_t width, size_t height) : Image2D(width, height, width) {}
   Image2D(size_t width, size_t height, size_t widthCapacity);
 
   void allocate();
 
+  /**
+   * Calculate the space taken up by one row of data. This is rounded
+   * upwards to make SSE/AVX operations faster. See the image factory
+   * functions (like @ref MakeSetImage() ) for an explanation of
+   * @c width_capacity.
+   */
+  static size_t CalculateStride(size_t width_capacity) {
+    return width_capacity == 0 ? 0 : (((width_capacity - 1) / 8) + 1) * 8;
+  }
+
   size_t _width, _height;
   size_t _stride;
   num_t **_dataPtr, *_dataConsecutive;
