@@ -1,6 +1,7 @@
 #include "mask2d.h"
 #include "image2d.h"
 
+#include <algorithm>
 #include <iostream>
 
 Mask2D::Mask2D()
@@ -106,8 +107,24 @@ template Mask2D* Mask2D::CreateSetMask<false>(
 template Mask2D* Mask2D::CreateSetMask<true>(
     const class Image2D& templateImage);
 
+Mask2DPtr Mask2D::CreatePtrFromRows(const Mask2D& source, size_t offset,
+                                    size_t count) {
+  assert(offset <= source._height && offset + count <= source._height &&
+         "The selected rows exceed the height of the source.");
+
+  Mask2DPtr result = Mask2D::CreateUnsetMaskPtr(source._width, count);
+
+  assert(result->_valuesConsecutive && source._valuesConsecutive &&
+         "The construction of a mask should always allocate memory.");
+
+  std::copy_n(source._valuesConsecutive + result->_stride * offset,
+              result->_stride * count, result->_valuesConsecutive);
+
+  return result;
+}
+
 Mask2D Mask2D::ShrinkHorizontally(int factor) const {
-  size_t newWidth = (_width + factor - 1) / factor;
+  const size_t newWidth = (_width + factor - 1) / factor;
 
   Mask2D newMask(newWidth, _height);
 
@@ -118,7 +135,7 @@ Mask2D Mask2D::ShrinkHorizontally(int factor) const {
     for (size_t y = 0; y < _height; ++y) {
       bool value = false;
       for (size_t binX = 0; binX < binSize; ++binX) {
-        size_t curX = x * factor + binX;
+        const size_t curX = x * factor + binX;
         value = value | Value(curX, y);
       }
       newMask.SetValue(x, y, value);
@@ -128,7 +145,7 @@ Mask2D Mask2D::ShrinkHorizontally(int factor) const {
 }
 
 Mask2D Mask2D::ShrinkHorizontallyForAveraging(int factor) const {
-  size_t newWidth = (_width + factor - 1) / factor;
+  const size_t newWidth = (_width + factor - 1) / factor;
 
   Mask2D newMask(newWidth, _height);
 
@@ -139,7 +156,7 @@ Mask2D Mask2D::ShrinkHorizontallyForAveraging(int factor) const {
     for (size_t y = 0; y < _height; ++y) {
       bool value = true;
       for (size_t binX = 0; binX < binSize; ++binX) {
-        size_t curX = x * factor + binX;
+        const size_t curX = x * factor + binX;
         value = value & Value(curX, y);
       }
       newMask.SetValue(x, y, value);
@@ -149,7 +166,7 @@ Mask2D Mask2D::ShrinkHorizontallyForAveraging(int factor) const {
 }
 
 Mask2D Mask2D::ShrinkVertically(int factor) const {
-  size_t newHeight = (_height + factor - 1) / factor;
+  const size_t newHeight = (_height + factor - 1) / factor;
 
   Mask2D newMask(_width, newHeight);
 
@@ -160,7 +177,7 @@ Mask2D Mask2D::ShrinkVertically(int factor) const {
     for (size_t x = 0; x < _width; ++x) {
       bool value = false;
       for (size_t binY = 0; binY < binSize; ++binY) {
-        size_t curY = y * factor + binY;
+        const size_t curY = y * factor + binY;
         value = value | Value(x, curY);
       }
       newMask.SetValue(x, y, value);
@@ -170,7 +187,7 @@ Mask2D Mask2D::ShrinkVertically(int factor) const {
 }
 
 Mask2D Mask2D::ShrinkVerticallyForAveraging(int factor) const {
-  size_t newHeight = (_height + factor - 1) / factor;
+  const size_t newHeight = (_height + factor - 1) / factor;
 
   Mask2D newMask(_width, newHeight);
 
@@ -181,7 +198,7 @@ Mask2D Mask2D::ShrinkVerticallyForAveraging(int factor) const {
     for (size_t x = 0; x != _width; ++x) {
       bool value = true;
       for (size_t binY = 0; binY != binSize; ++binY) {
-        size_t curY = y * factor + binY;
+        const size_t curY = y * factor + binY;
         value = value & Value(x, curY);
       }
       newMask.SetValue(x, y, value);
@@ -197,7 +214,7 @@ void Mask2D::EnlargeHorizontallyAndSet(const Mask2D& smallMask, int factor) {
 
     for (size_t y = 0; y < _height; ++y) {
       for (size_t binX = 0; binX < binSize; ++binX) {
-        size_t curX = x * factor + binX;
+        const size_t curX = x * factor + binX;
         SetValue(curX, y, smallMask.Value(x, y));
       }
     }
@@ -211,7 +228,7 @@ void Mask2D::EnlargeVerticallyAndSet(const Mask2D& smallMask, int factor) {
 
     for (size_t x = 0; x < _width; ++x) {
       for (size_t binY = 0; binY < binSize; ++binY) {
-        size_t curY = y * factor + binY;
+        const size_t curY = y * factor + binY;
         SetValue(x, curY, smallMask.Value(x, y));
       }
     }
