@@ -9,7 +9,7 @@
 
 MSMetaData::~MSMetaData() {}
 
-size_t MSMetaData::BandCount(const std::string &location) {
+size_t MSMetaData::BandCount(const std::string& location) {
   casacore::MeasurementSet ms(location);
   return ms.spectralWindow().nrow();
 }
@@ -21,14 +21,17 @@ void MSMetaData::initializeOtherData() {
   initializeFields(ms);
 }
 
-void MSMetaData::initializeAntennas(casacore::MeasurementSet &ms) {
-  casacore::MSAntenna antennaTable = ms.antenna();
-  size_t count = antennaTable.nrow();
-  casacore::ArrayColumn<double> positionCol(antennaTable, "POSITION");
-  casacore::ScalarColumn<casacore::String> nameCol(antennaTable, "NAME");
-  casacore::ScalarColumn<double> diameterCol(antennaTable, "DISH_DIAMETER");
-  casacore::ScalarColumn<casacore::String> mountCol(antennaTable, "MOUNT");
-  casacore::ScalarColumn<casacore::String> stationCol(antennaTable, "STATION");
+void MSMetaData::initializeAntennas(casacore::MeasurementSet& ms) {
+  const casacore::MSAntenna antennaTable = ms.antenna();
+  const size_t count = antennaTable.nrow();
+  const casacore::ArrayColumn<double> positionCol(antennaTable, "POSITION");
+  const casacore::ScalarColumn<casacore::String> nameCol(antennaTable, "NAME");
+  const casacore::ScalarColumn<double> diameterCol(antennaTable,
+                                                   "DISH_DIAMETER");
+  const casacore::ScalarColumn<casacore::String> mountCol(antennaTable,
+                                                          "MOUNT");
+  const casacore::ScalarColumn<casacore::String> stationCol(antennaTable,
+                                                            "STATION");
 
   _antennas.resize(count);
   for (size_t row = 0; row != count; ++row) {
@@ -49,19 +52,20 @@ void MSMetaData::initializeAntennas(casacore::MeasurementSet &ms) {
   }
 }
 
-void MSMetaData::initializeBands(casacore::MeasurementSet &ms) {
-  casacore::MSSpectralWindow spectralWindowTable = ms.spectralWindow();
-  casacore::ScalarColumn<int> numChanCol(spectralWindowTable, "NUM_CHAN");
-  casacore::ArrayColumn<double> frequencyCol(spectralWindowTable, "CHAN_FREQ");
+void MSMetaData::initializeBands(casacore::MeasurementSet& ms) {
+  const casacore::MSSpectralWindow spectralWindowTable = ms.spectralWindow();
+  const casacore::ScalarColumn<int> numChanCol(spectralWindowTable, "NUM_CHAN");
+  const casacore::ArrayColumn<double> frequencyCol(spectralWindowTable,
+                                                   "CHAN_FREQ");
 
   _bands.resize(spectralWindowTable.nrow());
   for (size_t bandIndex = 0; bandIndex != spectralWindowTable.nrow();
        ++bandIndex) {
     BandInfo band;
     band.windowIndex = bandIndex;
-    size_t channelCount = numChanCol(bandIndex);
+    const size_t channelCount = numChanCol(bandIndex);
 
-    const casacore::Array<double> &frequencies = frequencyCol(bandIndex);
+    const casacore::Array<double>& frequencies = frequencyCol(bandIndex);
     casacore::Array<double>::const_iterator frequencyIterator =
         frequencies.begin();
 
@@ -81,16 +85,16 @@ void MSMetaData::initializeBands(casacore::MeasurementSet &ms) {
   }
 }
 
-void MSMetaData::initializeFields(casacore::MeasurementSet &ms) {
-  casacore::MSField fieldTable = ms.field();
-  casacore::ArrayColumn<double> delayDirectionCol(
+void MSMetaData::initializeFields(casacore::MeasurementSet& ms) {
+  const casacore::MSField fieldTable = ms.field();
+  const casacore::ArrayColumn<double> delayDirectionCol(
       fieldTable, fieldTable.columnName(casacore::MSFieldEnums::DELAY_DIR));
-  casacore::ScalarColumn<casacore::String> nameCol(
+  const casacore::ScalarColumn<casacore::String> nameCol(
       fieldTable, fieldTable.columnName(casacore::MSFieldEnums::NAME));
 
   _fields.resize(fieldTable.nrow());
   for (size_t row = 0; row != fieldTable.nrow(); ++row) {
-    const casacore::Array<double> &delayDirection = delayDirectionCol(row);
+    const casacore::Array<double>& delayDirection = delayDirectionCol(row);
     casacore::Array<double>::const_iterator delayDirectionIterator =
         delayDirection.begin();
 
@@ -105,9 +109,9 @@ void MSMetaData::initializeFields(casacore::MeasurementSet &ms) {
   }
 }
 
-std::string MSMetaData::GetTelescopeName(casacore::MeasurementSet &ms) {
-  casacore::MSObservation obsTable = ms.observation();
-  casacore::ScalarColumn<casacore::String> telescopeNameCol(
+std::string MSMetaData::GetTelescopeName(casacore::MeasurementSet& ms) {
+  const casacore::MSObservation obsTable = ms.observation();
+  const casacore::ScalarColumn<casacore::String> telescopeNameCol(
       obsTable,
       obsTable.columnName(casacore::MSObservationEnums::TELESCOPE_NAME));
   if (obsTable.nrow() != 0) {
@@ -123,10 +127,10 @@ std::string MSMetaData::GetTelescopeName(casacore::MeasurementSet &ms) {
   throw std::runtime_error("Measurement set contains no observations");
 }
 
-void MSMetaData::GetDataDescToBandVector(std::vector<size_t> &dataDescToBand) {
+void MSMetaData::GetDataDescToBandVector(std::vector<size_t>& dataDescToBand) {
   casacore::MeasurementSet ms(_path);
-  casacore::MSDataDescription dataDescTable = ms.dataDescription();
-  casacore::ScalarColumn<int> spwIdCol(
+  const casacore::MSDataDescription dataDescTable = ms.dataDescription();
+  const casacore::ScalarColumn<int> spwIdCol(
       dataDescTable, dataDescTable.columnName(
                          casacore::MSDataDescriptionEnums::SPECTRAL_WINDOW_ID));
   dataDescToBand.resize(dataDescTable.nrow());
@@ -136,37 +140,37 @@ void MSMetaData::GetDataDescToBandVector(std::vector<size_t> &dataDescToBand) {
   }
 }
 
-void MSMetaData::initializeMainTableData() {
+void MSMetaData::InitializeMainTableData() {
   if (!_isMainTableDataInitialized) {
     Logger::Debug << "Initializing ms metadata cache data...\n";
 
-    casacore::MeasurementSet ms(_path);
-    casacore::ScalarColumn<int> antenna1Col(
+    const casacore::MeasurementSet ms(_path);
+    const casacore::ScalarColumn<int> antenna1Col(
         ms, casacore::MeasurementSet::columnName(
                 casacore::MeasurementSet::ANTENNA1));
-    casacore::ScalarColumn<int> antenna2Col(
+    const casacore::ScalarColumn<int> antenna2Col(
         ms, casacore::MeasurementSet::columnName(
                 casacore::MeasurementSet::ANTENNA2));
-    casacore::ScalarColumn<int> fieldIdCol(
+    const casacore::ScalarColumn<int> fieldIdCol(
         ms, casacore::MeasurementSet::columnName(
                 casacore::MeasurementSet::FIELD_ID));
-    casacore::ScalarColumn<int> dataDescIdCol(
+    const casacore::ScalarColumn<int> dataDescIdCol(
         ms, casacore::MeasurementSet::columnName(
                 casacore::MeasurementSet::DATA_DESC_ID));
-    casacore::ScalarColumn<double> timeCol(
+    const casacore::ScalarColumn<double> timeCol(
         ms,
         casacore::MeasurementSet::columnName(casacore::MeasurementSet::TIME));
 
     double time = -1.0;
-    std::set<std::pair<size_t, size_t> > baselineSet;
+    std::set<std::pair<size_t, size_t>> baselineSet;
     std::set<Sequence> sequenceSet;
     size_t prevFieldId = size_t(-1), sequenceId = size_t(-1);
     for (size_t row = 0; row != ms.nrow(); ++row) {
       size_t a1 = antenna1Col(row), a2 = antenna2Col(row),
              fieldId = fieldIdCol(row), spw = dataDescIdCol(row);
-      double cur_time = timeCol(row);
+      const double cur_time = timeCol(row);
 
-      bool isNewTime = cur_time != time;
+      const bool isNewTime = cur_time != time;
       if (fieldId != prevFieldId) {
         prevFieldId = fieldId;
         sequenceId++;
@@ -186,35 +190,35 @@ void MSMetaData::initializeMainTableData() {
     _sequences.assign(sequenceSet.begin(), sequenceSet.end());
 
     if (_intervalEnd) {
-      for (std::set<double> &seq : _observationTimesPerSequence) {
-        if (seq.size() > _intervalEnd.get())
-          seq.erase(std::next(seq.begin(), _intervalEnd.get()), seq.end());
+      for (std::set<double>& seq : _observationTimesPerSequence) {
+        if (seq.size() > *_intervalEnd)
+          seq.erase(std::next(seq.begin(), *_intervalEnd), seq.end());
       }
       _observationTimes.erase(
-          std::next(_observationTimes.begin(), _intervalEnd.get()),
+          std::next(_observationTimes.begin(), *_intervalEnd),
           _observationTimes.end());
     }
     if (_intervalStart) {
-      for (std::set<double> &seq : _observationTimesPerSequence) {
-        if (seq.size() > _intervalStart.get())
-          seq.erase(seq.begin(), std::next(seq.begin(), _intervalStart.get()));
+      for (std::set<double>& seq : _observationTimesPerSequence) {
+        if (seq.size() > *_intervalStart)
+          seq.erase(seq.begin(), std::next(seq.begin(), *_intervalStart));
         else
           seq.clear();
       }
       _observationTimes.erase(
           _observationTimes.begin(),
-          std::next(_observationTimes.begin(), _intervalStart.get()));
+          std::next(_observationTimes.begin(), *_intervalStart));
     }
     _isMainTableDataInitialized = true;
   }
 }
 
-size_t MSMetaData::PolarizationCount(const std::string &filename) {
+size_t MSMetaData::PolarizationCount(const std::string& filename) {
   casacore::MeasurementSet ms(filename);
-  casacore::Table polTable = ms.polarization();
-  casacore::ArrayColumn<int> corTypeColumn(polTable, "CORR_TYPE");
+  const casacore::Table polTable = ms.polarization();
+  const casacore::ArrayColumn<int> corTypeColumn(polTable, "CORR_TYPE");
   casacore::Array<int> corType = corTypeColumn(0);
-  casacore::Array<int>::iterator iterend(corType.end());
+  const casacore::Array<int>::iterator iterend(corType.end());
   size_t polarizationCount = 0;
   for (casacore::Array<int>::iterator iter = corType.begin(); iter != iterend;
        ++iter) {
@@ -225,21 +229,23 @@ size_t MSMetaData::PolarizationCount(const std::string &filename) {
 
 bool MSMetaData::HasAOFlaggerHistory() {
   casacore::MeasurementSet ms(_path);
-  casacore::Table histtab(ms.history());
-  casacore::ScalarColumn<casacore::String> application(histtab, "APPLICATION");
+  const casacore::Table histtab(ms.history());
+  const casacore::ScalarColumn<casacore::String> application(histtab,
+                                                             "APPLICATION");
   for (unsigned i = 0; i < histtab.nrow(); ++i) {
     if (application(i) == "AOFlagger") return true;
   }
   return false;
 }
 
-void MSMetaData::GetAOFlaggerHistory(std::ostream &stream) {
+void MSMetaData::GetAOFlaggerHistory(std::ostream& stream) {
   casacore::MeasurementSet ms(_path);
-  casacore::MSHistory histtab(ms.history());
-  casacore::ScalarColumn<double> time(histtab, "TIME");
-  casacore::ScalarColumn<casacore::String> application(histtab, "APPLICATION");
-  casacore::ArrayColumn<casacore::String> cli(histtab, "CLI_COMMAND");
-  casacore::ArrayColumn<casacore::String> parms(histtab, "APP_PARAMS");
+  const casacore::MSHistory histtab(ms.history());
+  const casacore::ScalarColumn<double> time(histtab, "TIME");
+  const casacore::ScalarColumn<casacore::String> application(histtab,
+                                                             "APPLICATION");
+  const casacore::ArrayColumn<casacore::String> cli(histtab, "CLI_COMMAND");
+  const casacore::ArrayColumn<casacore::String> parms(histtab, "APP_PARAMS");
   for (unsigned i = 0; i < histtab.nrow(); ++i) {
     if (application(i) == "AOFlagger") {
       stream << "====================\n"
@@ -264,8 +270,8 @@ void MSMetaData::GetAOFlaggerHistory(std::ostream &stream) {
   }
 }
 
-void MSMetaData::AddAOFlaggerHistory(const std::string &strategy,
-                                     const std::string &commandline) {
+void MSMetaData::AddAOFlaggerHistory(const std::string& strategy,
+                                     const std::string& commandline) {
   // This has been copied from MSWriter.cc of NDPPP and altered (thanks, Ger!)
   casacore::MeasurementSet ms(_path);
   casacore::Table histtab(ms.history());
@@ -281,7 +287,7 @@ void MSMetaData::AddAOFlaggerHistory(const std::string &strategy,
   // Put all parset entries in a Vector<String>.
   // Some WSRT MSs have a FixedShape APP_PARAMS and CLI_COMMAND column.
   // For them, put the xml file in a single vector element (with newlines).
-  bool fixedShaped =
+  const bool fixedShaped =
       (parms.columnDesc().options() & casacore::ColumnDesc::FixedShape) != 0;
 
   casacore::Vector<casacore::String> appParamsVec;
@@ -294,12 +300,12 @@ void MSMetaData::AddAOFlaggerHistory(const std::string &strategy,
   } else {
     // Tokenize the string on '\n'
     const std::string str = strategy;
-    size_t lineCount = std::count(str.begin(), str.end(), '\n');
+    const size_t lineCount = std::count(str.begin(), str.end(), '\n');
     appParamsVec.resize(lineCount + 1);
     casacore::Array<casacore::String>::contiter viter = appParamsVec.cbegin();
     size_t curStringPos = 0;
     for (size_t i = 0; i < lineCount; ++i) {
-      size_t endPos = str.find('\n', curStringPos);
+      const size_t endPos = str.find('\n', curStringPos);
       *viter = str.substr(curStringPos, endPos - curStringPos);
       ++viter;
       curStringPos = endPos + 1;
@@ -308,7 +314,7 @@ void MSMetaData::AddAOFlaggerHistory(const std::string &strategy,
       *viter = str.substr(curStringPos, str.size() - curStringPos);
     }
   }
-  uint rownr = histtab.nrow();
+  const uint rownr = histtab.nrow();
   histtab.addRow();
   time.put(rownr, casacore::Time().modifiedJulianDay() * 24.0 * 3600.0);
   obsId.put(rownr, 0);
@@ -322,11 +328,11 @@ void MSMetaData::AddAOFlaggerHistory(const std::string &strategy,
 
 std::string MSMetaData::GetStationName() const {
   casacore::MeasurementSet ms(_path);
-  casacore::Table antennaTable(ms.antenna());
+  const casacore::Table antennaTable(ms.antenna());
   if (antennaTable.nrow() == 0)
     throw std::runtime_error("GetStationName() : no rows in Antenna table");
-  casacore::ScalarColumn<casacore::String> stationColumn(antennaTable,
-                                                         "STATION");
+  const casacore::ScalarColumn<casacore::String> stationColumn(antennaTable,
+                                                               "STATION");
   return stationColumn(0);
 }
 
@@ -338,7 +344,7 @@ bool MSMetaData::IsChannelZeroRubish() {
     // (easily)
     const BandInfo bandInfo = GetBandInfo(0);
     return (bandInfo.channels.size() == 256 || bandInfo.channels.size() == 64);
-  } catch (std::exception &e) {
+  } catch (std::exception& e) {
     return false;
   }
 }
