@@ -1,20 +1,19 @@
 #include <boost/test/unit_test.hpp>
 
 #include "../../algorithms/highpassfilter.h"
-#include "../../algorithms/localfitmethod.h"
 
 #include "../../util/rng.h"
 #include "../../util/stopwatch.h"
 
 #include <iostream>
 
-using namespace aocommon;
+using algorithms::HighPassFilter;
 
 BOOST_AUTO_TEST_SUITE(high_pass_filter_experiment,
                       *boost::unit_test::label("experiment") *
                           boost::unit_test::disabled())
 
-static void Initialize(Image2DPtr &image, Mask2DPtr &mask) {
+static void Initialize(Image2DPtr& image, Mask2DPtr& mask) {
   const size_t width = 10000, height = 256;
   image = Image2D::CreateUnsetImagePtr(width, height);
   mask = Mask2D::CreateUnsetMaskPtr(width, height);
@@ -28,7 +27,7 @@ static void Initialize(Image2DPtr &image, Mask2DPtr &mask) {
   }
 }
 
-static void InitializeFlagged(Image2DPtr &image, Mask2DPtr &mask) {
+static void InitializeFlagged(Image2DPtr& image, Mask2DPtr& mask) {
   const size_t width = 10000 / 3, height = 256 / 3;
   image = Image2D::CreateUnsetImagePtr(width, height);
   mask = Mask2D::CreateUnsetMaskPtr(width, height);
@@ -42,21 +41,6 @@ static void InitializeFlagged(Image2DPtr &image, Mask2DPtr &mask) {
   }
 }
 
-BOOST_AUTO_TEST_CASE(time_fitting) {
-  Image2DPtr image;
-  Mask2DPtr mask;
-  Initialize(image, mask);
-
-  LocalFitMethod fitMethod;
-  TimeFrequencyData data(TimeFrequencyData::AmplitudePart,
-                         Polarization::StokesI, image);
-  fitMethod.SetToWeightedAverage(10, 20, 2.5, 5.0);
-  fitMethod.Initialize(data);
-  Stopwatch watch(true);
-  for (size_t i = 0; i < fitMethod.TaskCount(); ++i) fitMethod.PerformFit(i);
-  std::cout << " time token: " << watch.ToString() << ' ';
-}
-
 BOOST_AUTO_TEST_CASE(time_high_pass_filter) {
   Image2DPtr image;
   Mask2DPtr mask;
@@ -72,21 +56,6 @@ BOOST_AUTO_TEST_CASE(time_high_pass_filter) {
   std::cout << " time token: " << watch.ToString() << ' ';
 }
 
-BOOST_AUTO_TEST_CASE(time_flagged_fitting) {
-  Image2DPtr image;
-  Mask2DPtr mask;
-  InitializeFlagged(image, mask);
-
-  LocalFitMethod fitMethod;
-  TimeFrequencyData data(TimeFrequencyData::AmplitudePart,
-                         Polarization::StokesI, image);
-  fitMethod.SetToWeightedAverage(10, 20, 2.5, 5.0);
-  fitMethod.Initialize(data);
-  Stopwatch watch(true);
-  for (size_t i = 0; i < fitMethod.TaskCount(); ++i) fitMethod.PerformFit(i);
-  std::cout << " time token: " << watch.ToString() << ' ';
-}
-
 BOOST_AUTO_TEST_CASE(time_flagged_high_pass_filter) {
   Image2DPtr image;
   Mask2DPtr mask;
