@@ -7,7 +7,14 @@
 
 #include "../../algorithms/testsetgenerator.h"
 
-using namespace aocommon;
+#include <aocommon/polarization.h>
+
+using aocommon::Polarization;
+using aocommon::PolarizationEnum;
+
+using algorithms::BackgroundTestSet;
+using algorithms::RFITestSet;
+using algorithms::TestSetGenerator;
 
 BOOST_AUTO_TEST_SUITE(default_strategy, *boost::unit_test::label("lua"))
 
@@ -20,18 +27,20 @@ static void initStrategy(LuaStrategy& strategy) {
 }
 
 static std::pair<double, double> checkResult(TimeFrequencyData& data,
-                                             Mask2D& groundTruth) {
+                                             const Mask2D& groundTruth) {
   LuaStrategy strategy;
   initStrategy(strategy);
   ScriptData scriptData;
   TimeFrequencyMetaDataCPtr metaData(new TimeFrequencyMetaData());
-  strategy.Execute(data, metaData, scriptData, "execute");
+  TimeFrequencyData result = data;
+  result.SetNoMask();
+  strategy.Execute(result, metaData, scriptData, "execute");
 
-  BOOST_REQUIRE_GT(data.MaskCount(), 0);
+  BOOST_REQUIRE_GT(result.MaskCount(), 0);
   size_t width = groundTruth.Width(), height = groundTruth.Height();
-  size_t posCount = data.GetSingleMask()->GetCount<true>();
+  size_t posCount = result.GetSingleMask()->GetCount<true>();
   Mask2D intersect(groundTruth);
-  intersect.Intersect(*data.GetSingleMask());
+  intersect.Intersect(*result.GetSingleMask());
 
   size_t truePosCount = intersect.GetCount<true>();
   size_t falsePosCount = posCount - truePosCount;
@@ -44,42 +53,42 @@ static std::pair<double, double> checkResult(TimeFrequencyData& data,
 
 BOOST_AUTO_TEST_CASE(stokesi_complex) {
   size_t width = 200, height = 50;
-  Mask2D mask = Mask2D::MakeSetMask<false>(width, height);
-  Image2D real = TestSetGenerator::MakeTestSet(3, mask, width, height),
-          imag = TestSetGenerator::MakeTestSet(3, mask, width, height);
+  TimeFrequencyData data = TestSetGenerator::MakeTestSet(
+      RFITestSet::FullBandBursts, BackgroundTestSet::Empty, width, height);
 
-  TimeFrequencyData tfData(Polarization::StokesI, Image2D::MakePtr(real),
-                           Image2D::MakePtr(imag));
-
-  auto fpfn = checkResult(tfData, mask);
-  BOOST_CHECK_LT(fpfn.first, 5e-3);   // False positives-ratio should be < 0.5 %
-  BOOST_CHECK_LT(fpfn.second, 5e-3);  // False negatives-ratio should be < 0.5 %
+  auto fpfn = checkResult(data, *data.GetSingleMask());
+  BOOST_CHECK_LT(fpfn.first, 5e-3);  // False positives-ratio should be < 0.5 %
+  BOOST_CHECK_LT(fpfn.second,
+                 0.015);  // False negatives-ratio should be < 1.5 %
 }
 
 BOOST_AUTO_TEST_CASE(stokesi_amplitude) {
   size_t width = 200, height = 50;
   Mask2D mask = Mask2D::MakeSetMask<false>(width, height);
-  Image2D amplitude = TestSetGenerator::MakeTestSet(3, mask, width, height);
+  TimeFrequencyData data = TestSetGenerator::MakeTestSet(
+      RFITestSet::FullBandBursts, BackgroundTestSet::Empty, width, height);
+  Image2DCPtr amplitude = data.GetImage(0);
 
   TimeFrequencyData tfData(TimeFrequencyData::AmplitudePart,
-                           Polarization::StokesI, Image2D::MakePtr(amplitude));
+                           Polarization::StokesI, amplitude);
 
-  auto fpfn = checkResult(tfData, mask);
+  auto fpfn = checkResult(tfData, *data.GetSingleMask());
   BOOST_CHECK_LT(fpfn.first, 5e-3);   // False positives-ratio should be < 0.5 %
   BOOST_CHECK_LT(fpfn.second, 5e-3);  // False negatives-ratio should be < 0.5 %
 }
 
 BOOST_AUTO_TEST_CASE(full_polarization) {
   size_t width = 200, height = 50;
-  Mask2D mask = Mask2D::MakeSetMask<false>(width, height);
   TimeFrequencyData allData;
   PolarizationEnum pols[4] = {Polarization::XX, Polarization::XY,
                               Polarization::YX, Polarization::YY};
   for (size_t i = 0; i != 4; ++i) {
-    Image2D real = TestSetGenerator::MakeTestSet(3, mask, width, height),
-            imag = TestSetGenerator::MakeTestSet(3, mask, width, height);
-    TimeFrequencyData tfData(pols[i], Image2D::MakePtr(real),
-                             Image2D::MakePtr(imag));
+    TimeFrequencyData real = TestSetGenerator::MakeTestSet(
+        RFITestSet::FullBandBursts, BackgroundTestSet::Empty, width, height);
+    TimeFrequencyData imag = TestSetGenerator::MakeTestSet(
+        RFITestSet::FullBandBursts, BackgroundTestSet::Empty, width, height);
+    TimeFrequencyData tfData(pols[i], real.GetImage(0), imag.GetImage(0));
+    tfData.SetGlobalMask(real.GetMask(0));
     if (i == 0)
       allData = tfData;
     else
@@ -87,7 +96,7 @@ BOOST_AUTO_TEST_CASE(full_polarization) {
           TimeFrequencyData::MakeFromPolarizationCombination(allData, tfData);
   }
 
-  auto fpfn = checkResult(allData, mask);
+  auto fpfn = checkResult(allData, *allData.GetSingleMask());
   BOOST_CHECK_LT(fpfn.first, 2e-2);   // False positives-ratio should be < 2 %
   BOOST_CHECK_LT(fpfn.second, 2e-3);  // False negatives-ratio should be < 0.2 %
 }
