@@ -1,6 +1,6 @@
-#include <stdexcept>
-
 #include <cmath>
+#include <stdexcept>
+#include <string>
 
 #ifndef HAVE_EXP10
 #define exp10(x) exp((2.3025850929940456840179914546844) * (x))
@@ -8,7 +8,7 @@
 
 class NumberParsingException : public std::runtime_error {
  public:
-  explicit NumberParsingException(const std::string &str)
+  explicit NumberParsingException(const std::string& str)
       : std::runtime_error(std::string("Failed to parse number: ") + str) {}
 };
 
@@ -24,19 +24,19 @@ class NumberParser {
   /**
    * @throws NumberParsingException when @c str can not be parsed.
    */
-  static double ToDouble(const char *str) { return toNumber<double>(str); }
+  static double ToDouble(const char* str) { return toNumber<double>(str); }
 
   /**
    * @throws NumberParsingException when @c str can not be parsed.
    */
-  static short ToShort(const char *str) { return toSignedInteger<short>(str); }
+  static short ToShort(const char* str) { return toSignedInteger<short>(str); }
 
  private:
   /**
    * @throws NumberParsingException when @c str can not be parsed.
    */
   template <typename T>
-  static T toNumber(const char *str) {
+  static T toNumber(const char* str) {
     if (*str == 0) throw NumberParsingException("Supplied string is empty");
 
     // Read optional sign
@@ -47,8 +47,9 @@ class NumberParser {
     } else if (isPositiveSymbol(*str)) {
       isNegative = false;
       ++str;
-    } else
+    } else {
       isNegative = false;
+    }
 
     // Read everything before decimal point
     if (!isDigit(*str))
@@ -80,7 +81,7 @@ class NumberParser {
       try {
         short e = ToShort(str);
         val = val * intPow10(e);
-      } catch (NumberParsingException &e) {
+      } catch (NumberParsingException& e) {
         throw NumberParsingException("Could not parse exponent");
       }
     }
@@ -100,7 +101,7 @@ class NumberParser {
    * @throws NumberParsingException when @c str can not be parsed.
    */
   template <typename T>
-  static T toSignedInteger(const char *str) {
+  static T toSignedInteger(const char* str) {
     if (*str == 0) throw NumberParsingException("Supplied string is empty");
 
     // Read optional sign
@@ -111,8 +112,9 @@ class NumberParser {
     } else if (isPositiveSymbol(*str)) {
       isNegative = false;
       ++str;
-    } else
+    } else {
       isNegative = false;
+    }
 
     // Read digits
     if (!isDigit(*str))
@@ -132,9 +134,10 @@ class NumberParser {
         return -val;
       else
         return val;
-    } else
+    } else {
       throw NumberParsingException(
           "The integer contains invalid characters after its digits");
+    }
   }
 
   static double intPow10(int par) {
