@@ -3,22 +3,27 @@
 #include <cmath>
 #include <iostream>
 
-#include "../../util/plot.h"
-#include "../../util/multiplot.h"
+#include "../util/plot.h"
+#include "../util/multiplot.h"
 
-#include "../../structures/timefrequencydata.h"
-#include "../../structures/timefrequencymetadata.h"
+#include "../structures/timefrequencydata.h"
+#include "../structures/timefrequencymetadata.h"
 
 #include "../algorithms/sinusfitter.h"
 #include "../algorithms/thresholdtools.h"
 
-#include "../../plot/plot2d.h"
+#include "../plot/axis.h"
+#include "../plot/xyplot.h"
 
-using namespace aocommon;
+using aocommon::Polarization;
+using aocommon::PolarizationEnum;
+
+using algorithms::SinusFitter;
+using algorithms::ThresholdTools;
 
 void RFIPlots::Bin(Image2DCPtr image, Mask2DCPtr mask,
-                   std::vector<size_t> &valuesOutput,
-                   std::vector<long double> &binsOutput, size_t binCount,
+                   std::vector<size_t>& valuesOutput,
+                   std::vector<long double>& binsOutput, size_t binCount,
                    long double start, long double end, long double factor,
                    long double stretch) throw() {
   const long double min =
@@ -35,8 +40,8 @@ void RFIPlots::Bin(Image2DCPtr image, Mask2DCPtr mask,
   for (size_t y = 0; y < image->Height(); ++y) {
     for (size_t x = 0; x < image->Width(); ++x) {
       if (!mask->Value(x, y)) {
-        long double value = image->Value(x, y);
-        size_t index = (size_t)((value * stretch - min) / binsize);
+        const long double value = image->Value(x, y);
+        const size_t index = (size_t)((value * stretch - min) / binsize);
         if (index < binCount) valuesOutput[index] += 1;
       }
     }
@@ -48,7 +53,7 @@ void RFIPlots::Bin(Image2DCPtr image, Mask2DCPtr mask,
   }
 }
 
-void RFIPlots::MakeDistPlot(Plot2DPointSet &pointSet, Image2DCPtr image,
+void RFIPlots::MakeDistPlot(XYPointSet& pointSet, Image2DCPtr image,
                             Mask2DCPtr mask) {
   std::vector<size_t> valuesOutput;
   std::vector<long double> binsOutput;
@@ -68,11 +73,11 @@ void RFIPlots::MakeDistPlot(Plot2DPointSet &pointSet, Image2DCPtr image,
 }
 
 template <bool Weight>
-void RFIPlots::MakeMeanSpectrumPlot(Plot2DPointSet &pointSet,
-                                    const TimeFrequencyData &data,
-                                    const Mask2DCPtr &mask,
-                                    const TimeFrequencyMetaDataCPtr &metaData) {
-  bool hasBandInfo = metaData != 0 && metaData->HasBand();
+void RFIPlots::MakeMeanSpectrumPlot(XYPointSet& pointSet,
+                                    const TimeFrequencyData& data,
+                                    const Mask2DCPtr& mask,
+                                    const TimeFrequencyMetaDataCPtr& metaData) {
+  const bool hasBandInfo = metaData != nullptr && metaData->HasBand();
   if (hasBandInfo) {
     pointSet.SetXDesc("Frequency (MHz)");
     std::stringstream yDesc;
@@ -96,7 +101,7 @@ void RFIPlots::MakeMeanSpectrumPlot(Plot2DPointSet &pointSet,
     long double sum = 0.0L;
     size_t count = 0;
     for (size_t i = 0; i < displayData.ImageCount(); ++i) {
-      Image2DCPtr image = displayData.GetImage(i);
+      const Image2DCPtr image = displayData.GetImage(i);
       for (size_t x = 0; x < width; ++x) {
         if (!mask->Value(x, y) && std::isnormal(image->Value(x, y))) {
           sum += image->Value(x, y);
@@ -119,20 +124,18 @@ void RFIPlots::MakeMeanSpectrumPlot(Plot2DPointSet &pointSet,
         pointSet.PushDataPoint(y, v);
     }
   }
-  pointSet.SetYRange(min * 0.9, max / 0.9);
 }
 template void RFIPlots::MakeMeanSpectrumPlot<true>(
-    class Plot2DPointSet &pointSet, const TimeFrequencyData &data,
-    const Mask2DCPtr &mask, const TimeFrequencyMetaDataCPtr &metaData);
+    XYPointSet& pointSet, const TimeFrequencyData& data, const Mask2DCPtr& mask,
+    const TimeFrequencyMetaDataCPtr& metaData);
 template void RFIPlots::MakeMeanSpectrumPlot<false>(
-    class Plot2DPointSet &pointSet, const TimeFrequencyData &data,
-    const Mask2DCPtr &mask, const TimeFrequencyMetaDataCPtr &metaData);
+    XYPointSet& pointSet, const TimeFrequencyData& data, const Mask2DCPtr& mask,
+    const TimeFrequencyMetaDataCPtr& metaData);
 
-void RFIPlots::MakePowerSpectrumPlot(Plot2DPointSet &pointSet,
-                                     const Image2D &real, const Image2D &imag,
-                                     const Mask2D &mask,
-                                     const TimeFrequencyMetaData *metaData) {
-  bool hasBandInfo = metaData != nullptr && metaData->HasBand();
+void RFIPlots::MakePowerSpectrumPlot(XYPointSet& pointSet, const Image2D& real,
+                                     const Image2D& imag, const Mask2D& mask,
+                                     const TimeFrequencyMetaData* metaData) {
+  const bool hasBandInfo = metaData != nullptr && metaData->HasBand();
   if (hasBandInfo) {
     pointSet.SetXDesc("Frequency (MHz)");
     std::stringstream yDesc;
@@ -149,7 +152,7 @@ void RFIPlots::MakePowerSpectrumPlot(Plot2DPointSet &pointSet,
     size_t count = 0;
     for (size_t x = 0; x < real.Width(); ++x) {
       if (!mask.Value(x, y) && std::isfinite(real.Value(x, y))) {
-        std::complex<num_t> val(real.Value(x, y), imag.Value(x, y));
+        const std::complex<num_t> val(real.Value(x, y), imag.Value(x, y));
         sum += (val * std::conj(val)).real();
         ++count;
       }
@@ -167,7 +170,7 @@ void RFIPlots::MakePowerSpectrumPlot(Plot2DPointSet &pointSet,
   }
 }
 
-void RFIPlots::MakePowerTimePlot(Plot2DPointSet &pointSet, Image2DCPtr image,
+void RFIPlots::MakePowerTimePlot(XYPointSet& pointSet, Image2DCPtr image,
                                  Mask2DCPtr mask,
                                  TimeFrequencyMetaDataCPtr metaData) {
   pointSet.SetXDesc("Time");
@@ -175,12 +178,11 @@ void RFIPlots::MakePowerTimePlot(Plot2DPointSet &pointSet, Image2DCPtr image,
   bool useMeta;
   if (metaData != nullptr && metaData->HasObservationTimes()) {
     useMeta = true;
-    pointSet.SetXIsTime(true);
   } else {
     useMeta = false;
   }
 
-  size_t binSize = (size_t)ceil(image->Width() / 256.0L);
+  const size_t binSize = (size_t)ceil(image->Width() / 256.0L);
 
   unsigned index = 0;
   for (size_t x = 0; x < image->Width(); x += binSize) {
@@ -203,8 +205,8 @@ void RFIPlots::MakePowerTimePlot(Plot2DPointSet &pointSet, Image2DCPtr image,
   }
 }
 
-void RFIPlots::MakeComplexPlanePlot(Plot2DPointSet &pointSet,
-                                    const TimeFrequencyData &data,
+void RFIPlots::MakeComplexPlanePlot(XYPointSet& pointSet,
+                                    const TimeFrequencyData& data,
                                     size_t xStart, size_t length, size_t y,
                                     size_t yAvgSize, Mask2DCPtr mask,
                                     bool realVersusImaginary,
@@ -218,8 +220,8 @@ void RFIPlots::MakeComplexPlanePlot(Plot2DPointSet &pointSet,
     pointSet.SetYDesc("real/imaginary visibility");
   }
 
-  Image2DCPtr real = data.GetRealPart();
-  Image2DCPtr imaginary = data.GetImaginaryPart();
+  const Image2DCPtr real = data.GetRealPart();
+  const Image2DCPtr imaginary = data.GetImaginaryPart();
 
   for (size_t x = xStart; x < xStart + length; ++x) {
     long double r = 0.0L, i = 0.0L;
@@ -239,8 +241,8 @@ void RFIPlots::MakeComplexPlanePlot(Plot2DPointSet &pointSet,
   }
 }
 
-void RFIPlots::MakeFittedComplexPlot(Plot2DPointSet &pointSet,
-                                     const TimeFrequencyData &data,
+void RFIPlots::MakeFittedComplexPlot(XYPointSet& pointSet,
+                                     const TimeFrequencyData& data,
                                      size_t xStart, size_t length, size_t y,
                                      size_t yAvgSize, Mask2DCPtr mask,
                                      num_t frequency, bool realVersusImaginary,
@@ -253,8 +255,8 @@ void RFIPlots::MakeFittedComplexPlot(Plot2DPointSet &pointSet,
     pointSet.SetXDesc("time");
     pointSet.SetYDesc("real/imaginary visibility");
   }
-  Image2DCPtr real = data.GetRealPart();
-  Image2DCPtr imaginary = data.GetImaginaryPart();
+  const Image2DCPtr real = data.GetRealPart();
+  const Image2DCPtr imaginary = data.GetImaginaryPart();
 
   std::vector<num_t> xReal(length);
   std::vector<num_t> xImag(length);
@@ -319,14 +321,14 @@ void RFIPlots::MakeFittedComplexPlot(Plot2DPointSet &pointSet,
   }
 }
 
-void RFIPlots::MakeTimeScatterPlot(class MultiPlot &plot, size_t plotIndex,
-                                   const Image2DCPtr &image,
-                                   const Mask2DCPtr &mask,
-                                   const TimeFrequencyMetaDataCPtr &metaData) {
+void RFIPlots::MakeTimeScatterPlot(class MultiPlot& plot, size_t plotIndex,
+                                   const Image2DCPtr& image,
+                                   const Mask2DCPtr& mask,
+                                   const TimeFrequencyMetaDataCPtr& metaData) {
   plot.SetXAxisText("Time (s)");
   plot.SetYAxisText("Visibility");
   bool useMeta;
-  if (metaData != 0 && metaData->HasObservationTimes())
+  if (metaData != nullptr && metaData->HasObservationTimes())
     useMeta = true;
   else
     useMeta = false;
@@ -357,11 +359,11 @@ void RFIPlots::MakeTimeScatterPlot(class MultiPlot &plot, size_t plotIndex,
 }
 
 void RFIPlots::MakeFrequencyScatterPlot(
-    class MultiPlot &plot, size_t plotIndex, const Image2DCPtr &image,
-    const Mask2DCPtr &mask, const TimeFrequencyMetaDataCPtr &metaData) {
+    class MultiPlot& plot, size_t plotIndex, const Image2DCPtr& image,
+    const Mask2DCPtr& mask, const TimeFrequencyMetaDataCPtr& metaData) {
   plot.SetYAxisText("Visibility");
   bool useMeta;
-  if (metaData != 0 && metaData->HasBand())
+  if (metaData != nullptr && metaData->HasBand())
     useMeta = true;
   else
     useMeta = false;
@@ -390,13 +392,13 @@ void RFIPlots::MakeFrequencyScatterPlot(
   }
 }
 
-void RFIPlots::MakeTimeScatterPlot(class MultiPlot &plot,
-                                   const TimeFrequencyData &data,
-                                   const TimeFrequencyMetaDataCPtr &metaData,
+void RFIPlots::MakeTimeScatterPlot(class MultiPlot& plot,
+                                   const TimeFrequencyData& data,
+                                   const TimeFrequencyMetaDataCPtr& metaData,
                                    unsigned startIndex) {
   for (size_t polIndex = 0; polIndex != data.PolarizationCount(); ++polIndex) {
-    PolarizationEnum pol = data.GetPolarization(polIndex);
-    TimeFrequencyData polTF = data.Make(pol);
+    const PolarizationEnum pol = data.GetPolarization(polIndex);
+    const TimeFrequencyData polTF = data.Make(pol);
     MakeTimeScatterPlot(plot, startIndex + polIndex, polTF.GetSingleImage(),
                         polTF.GetSingleMask(), metaData);
     if (data.PolarizationCount() == 1)
@@ -408,11 +410,11 @@ void RFIPlots::MakeTimeScatterPlot(class MultiPlot &plot,
 }
 
 void RFIPlots::MakeFrequencyScatterPlot(
-    class MultiPlot &plot, const TimeFrequencyData &data,
-    const TimeFrequencyMetaDataCPtr &metaData, unsigned startIndex) {
+    class MultiPlot& plot, const TimeFrequencyData& data,
+    const TimeFrequencyMetaDataCPtr& metaData, unsigned startIndex) {
   for (size_t polIndex = 0; polIndex != data.PolarizationCount(); ++polIndex) {
-    PolarizationEnum pol = data.GetPolarization(polIndex);
-    TimeFrequencyData polTF = data.Make(pol);
+    const PolarizationEnum pol = data.GetPolarization(polIndex);
+    const TimeFrequencyData polTF = data.Make(pol);
     MakeFrequencyScatterPlot(plot, startIndex + polIndex,
                              polTF.GetSingleImage(), polTF.GetSingleMask(),
                              metaData);
